@@ -2,7 +2,7 @@
  *
  * $Id: classdef.cpp,v 1.54 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -86,6 +86,7 @@ ClassDef::ClassDef(
   m_innerClasses = new ClassSDict(17);
   m_subGrouping=Config_getBool("SUBGROUPING");
   m_templateInstances = 0;
+  m_variableInstances = 0;
   m_templateMaster =0;
   m_templBaseClassNames = 0;
   m_artificial = FALSE;
@@ -93,6 +94,7 @@ ClassDef::ClassDef(
   m_isStatic = FALSE;
   m_isObjC = FALSE;
   m_membersMerged = FALSE;
+  m_categoryOf = 0;
   QCString ns;
   extractNamespaceName(m_name,m_className,ns);
   //printf("m_name=%s m_className=%s ns=%s\n",m_name.data(),m_className.data(),ns.data());
@@ -122,14 +124,17 @@ ClassDef::~ClassDef()
   delete memberGroupSDict;
   delete m_innerClasses;
   delete m_templateInstances;
+  delete m_variableInstances;
   delete m_templBaseClassNames;
   delete m_tempArgs;
 }
 
 QCString ClassDef::displayName() const
 {
+  static bool hideScopeNames = Config_getBool("HIDE_SCOPE_NAMES");
+  static bool optimizeOutputForJava = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
   QCString n;
-  if (Config_getBool("HIDE_SCOPE_NAMES"))
+  if (hideScopeNames)
   {
     n=m_className;
   }
@@ -137,10 +142,14 @@ QCString ClassDef::displayName() const
   {
     n=qualifiedNameWithTemplateParameters();
   }
-  if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+  if (optimizeOutputForJava)
   {
     n=substitute(n,"::",".");
   }
+  if (m_compType==ClassDef::Protocol && n.right(2)=="-p")
+  {
+    n="< "+n.left(n.length()-2)+" >";
+  }
   return n;
 }
 
@@ -927,28 +936,108 @@ void ClassDef::writeDetailedDescription(OutputList &ol, const QCString &pageType
   }
 }
     
+void ClassDef::showUsedFiles(OutputList &ol)
+{
+  if (Config_getBool("SHOW_USED_FILES"))
+  {
+    ol.writeRuler();
+    ol.parseText(theTranslator->trGeneratedFromFiles(
+          m_isObjC && m_compType==Interface ? Class : m_compType,
+          m_files.count()==1));
+
+    bool first=TRUE;
+    const char *file = m_files.first();
+    while (file)
+    {
+      bool ambig;
+      FileDef *fd=findFileDef(Doxygen::inputNameDict,file,ambig);
+      if (fd)
+      {
+        if (first)
+        {
+          first=FALSE;   
+          ol.startItemList();
+        }
+
+        ol.writeListItem();
+        QCString path=fd->getPath().copy();
+        if (Config_getBool("FULL_PATH_NAMES"))
+        {
+          ol.docify(stripFromPath(path));
+        }
+
+        QCString fname = fd->name();
+        if (!fd->getVersion().isEmpty()) // append version if available
+        {
+          fname += " (" + fd->getVersion() + ")";
+        }
+
+        // for HTML 
+        ol.pushGeneratorState();
+        ol.disableAllBut(OutputGenerator::Html);
+        if (fd->generateSourceFile())
+        {
+          ol.writeObjectLink(0,fd->getSourceFileBase(),0,fname);
+        }
+        else if (fd->isLinkable())
+        {
+          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
+              fname);
+        }
+        else
+        {
+          ol.docify(fname);
+        }
+        ol.popGeneratorState();
+
+        // for other output formats
+        ol.pushGeneratorState();
+        ol.disable(OutputGenerator::Html);
+        if (fd->isLinkable())
+        {
+          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
+              fname);
+        }
+        else
+        {
+          ol.docify(fname);
+        }
+
+        ol.popGeneratorState();
+
+        
+      }
+      file=m_files.next();
+    }
+    if (!first) ol.endItemList();
+  }
+}
+
+
 // write all documentation for this class
 void ClassDef::writeDocumentation(OutputList &ol)
 {
-  // write title
-  QCString pageTitle=displayName().copy();
-  QCString pageType;
-  QCString cType=compoundTypeString();
-  toupper(cType.at(0));
-  pageType+=" ";
-  pageType+=cType;
-  pageTitle+=pageType+" Reference";
-  if (m_tempArgs) pageTitle.prepend(" Template");
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  QCString pageType = " ";
+  pageType += compoundTypeString();
+  toupper(pageType.at(1));
+  QCString pageTitle = theTranslator->trCompoundReference(displayName(),
+              m_compType == Interface && m_isObjC ? Class : m_compType,
+              m_tempArgs != 0);
+  
+  startFile(ol,getOutputFileBase(),name(),pageTitle);  
+  if (getOuterScope()!=Doxygen::globalScope)
+  {
+    writeNavigationPath(ol);
+  }
   startTitle(ol,getOutputFileBase());
-  ol.parseText(theTranslator->trCompoundReference(displayName(),m_compType,m_tempArgs!=0));
+  ol.parseText(pageTitle);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),name());
 
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
 
   ol.startTextBlock();
@@ -976,7 +1065,11 @@ void ClassDef::writeDocumentation(OutputList &ol)
       }
       ol.endTextLink();
       ol.popGeneratorState();
+
+      ol.pushGeneratorState();
+      ol.disable(OutputGenerator::RTF);
       ol.newParagraph();
+      ol.popGeneratorState();
     }
   }
   ol.writeSynopsis();
@@ -1039,7 +1132,9 @@ void ClassDef::writeDocumentation(OutputList &ol)
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
   {
     Doxygen::tagFile << "  <compound kind=\"" << compoundTypeString();
-    Doxygen::tagFile << "\">" << endl;
+    Doxygen::tagFile << "\"";
+    if (isObjectiveC()) { Doxygen::tagFile << " objc=\"yes\""; }
+    Doxygen::tagFile << ">" << endl;
     Doxygen::tagFile << "    <name>" << convertToXML(name()) << "</name>" << endl;
     Doxygen::tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << Doxygen::htmlFileExtension << "</filename>" << endl;
     if (m_tempArgs)
@@ -1181,7 +1276,7 @@ void ClassDef::writeDocumentation(OutputList &ol)
         ol.pushGeneratorState();
         ol.disableAllBut(OutputGenerator::Html);
         ol.writeString("<center><font size=\"2\">[");
-        ol.startHtmlLink("graph_legend"+Doxygen::htmlFileExtension);
+        ol.startHtmlLink(relativePathToRoot(0)+"graph_legend"+Doxygen::htmlFileExtension);
         ol.docify(theTranslator->trLegend());
         ol.endHtmlLink();
         ol.writeString("]</font></center>");
@@ -1215,7 +1310,7 @@ void ClassDef::writeDocumentation(OutputList &ol)
       {
         ol.disableAllBut(OutputGenerator::Html);
         ol.writeString("<center><font size=\"2\">[");
-        ol.startHtmlLink("graph_legend"+Doxygen::htmlFileExtension);
+        ol.startHtmlLink(relativePathToRoot(0)+"graph_legend"+Doxygen::htmlFileExtension);
         ol.docify(theTranslator->trLegend());
         ol.endHtmlLink();
         ol.writeString("]</font></center>");
@@ -1330,6 +1425,10 @@ void ClassDef::writeDocumentation(OutputList &ol)
                   theTranslator->trRelatedFunctions(),
                   theTranslator->trRelatedSubscript()
                  ); 
+
+  // nested classes
+  m_innerClasses->writeDeclaration(ol,0,0,TRUE);
+  
   ol.endMemberSections();
     
   // write detailed description
@@ -1366,73 +1465,9 @@ void ClassDef::writeDocumentation(OutputList &ol)
 
   // write the list of used files (not for man pages)
   ol.pushGeneratorState();
+  ol.disable(OutputGenerator::Man);
 
-  if (Config_getBool("SHOW_USED_FILES"))
-  {
-    ol.disable(OutputGenerator::Man);
-    ol.writeRuler();
-    ol.parseText(theTranslator->trGeneratedFromFiles(m_compType,m_files.count()==1));
-
-    bool first=TRUE;
-    const char *file = m_files.first();
-    while (file)
-    {
-      bool ambig;
-      FileDef *fd=findFileDef(Doxygen::inputNameDict,file,ambig);
-      if (fd)
-      {
-        if (first)
-        {
-          first=FALSE;   
-          ol.startItemList();
-        }
-
-        ol.writeListItem();
-        QCString path=fd->getPath().copy();
-        if (Config_getBool("FULL_PATH_NAMES"))
-        {
-          ol.docify(stripFromPath(path));
-        }
-
-        // for HTML 
-        ol.pushGeneratorState();
-        ol.disableAllBut(OutputGenerator::Html);
-        if (fd->generateSourceFile())
-        {
-          ol.writeObjectLink(0,fd->getSourceFileBase(),0,fd->name());
-        }
-        else if (fd->isLinkable())
-        {
-          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
-              fd->name());
-        }
-        else
-        {
-          ol.docify(fd->name());
-        }
-        ol.popGeneratorState();
-
-        // for other output formats
-        ol.pushGeneratorState();
-        ol.disable(OutputGenerator::Html);
-        if (fd->isLinkable())
-        {
-          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
-              fd->name());
-        }
-        else
-        {
-          ol.docify(fd->name());
-        }
-
-        ol.popGeneratorState();
-
-        
-      }
-      file=m_files.next();
-    }
-    if (!first) ol.endItemList();
-  }
+  showUsedFiles(ol);
 
   // write Author section (Man only)
   ol.enable(OutputGenerator::Man);
@@ -1498,7 +1533,7 @@ void ClassDef::writeMemberList(OutputList &ol)
   ol.parseText(theTranslator->trIncludingInheritedMembers());
   
   //ol.startItemList();
-  ol.writeString("<table>\n");
+  ol.writeString("<p><table>\n");
   
   //MemberNameInfo *mni=m_allMemberNameInfoList->first();
   MemberNameInfoSDict::Iterator mnii(*m_allMemberNameInfoSDict); 
@@ -1526,24 +1561,45 @@ void ClassDef::writeMemberList(OutputList &ol)
           QCString name=mi->ambiguityResolutionScope+md->name();
           //ol.writeListItem();
           ol.writeString("  <tr class=\"memlist\"><td>");
-          //Definition *bd = md->getGroupDef();
-          //if (bd==0) bd=cd;
-          ol.writeObjectLink(md->getReference(),
-                             md->getOutputFileBase(),
-                             md->anchor(),name);
+          if (cd->isObjectiveC())
+          {
+            if (md->isObjCMethod())
+            {
+              if (md->isStatic())
+                ol.writeString("+&nbsp;</td><td>");
+              else
+                ol.writeString("-&nbsp;</td><td>");
+            }
+            else
+              ol.writeString("</td><td>");
+          }
+          if (md->isObjCMethod())
+          {
+            ol.writeObjectLink(md->getReference(),
+                md->getOutputFileBase(),
+                md->anchor(),md->name());
+          }
+          else
+          {
+            //Definition *bd = md->getGroupDef();
+            //if (bd==0) bd=cd;
+            ol.writeObjectLink(md->getReference(),
+                md->getOutputFileBase(),
+                md->anchor(),name);
 
-          if ( md->isFunction() || md->isSignal() || md->isSlot() ||
-               (md->isFriend() && md->argsString())) 
-            ol.docify(md->argsString());
-          else if (md->isEnumerate())
-            ol.parseText(" "+theTranslator->trEnumName());
-          else if (md->isEnumValue())
-            ol.parseText(" "+theTranslator->trEnumValue());
-          else if (md->isTypedef())
-            ol.docify(" typedef");
-          else if (md->isFriend() && !strcmp(md->typeString(),"friend class"))
-            ol.docify(" class");
-          //ol.writeString("\n");
+            if ( md->isFunction() || md->isSignal() || md->isSlot() ||
+                (md->isFriend() && md->argsString())) 
+              ol.docify(md->argsString());
+            else if (md->isEnumerate())
+              ol.parseText(" "+theTranslator->trEnumName());
+            else if (md->isEnumValue())
+              ol.parseText(" "+theTranslator->trEnumValue());
+            else if (md->isTypedef())
+              ol.docify(" typedef");
+            else if (md->isFriend() && !strcmp(md->typeString(),"friend class"))
+              ol.docify(" class");
+            //ol.writeString("\n");
+          }
           ol.writeString("</td>");
           memberWritten=TRUE;
         }
@@ -1554,17 +1610,32 @@ void ClassDef::writeMemberList(OutputList &ol)
         {
           //ol.writeListItem();
           ol.writeString("  <tr bgcolor=\"#f0f0f0\"><td>");
+          if (cd->isObjectiveC())
+          {
+            if (md->isObjCMethod())
+            {
+              if (md->isStatic())
+                ol.writeString("+&nbsp;</td><td>");
+              else
+                ol.writeString("-&nbsp;</td><td>");
+            }
+            else
+              ol.writeString("</td><td>");
+          }
           ol.startBold();
           ol.docify(md->name());
           ol.endBold();
-          if ( md->isFunction() || md->isSignal() || md->isSlot() ) 
-            ol.docify(md->argsString());
-          else if (md->isEnumerate())
-            ol.parseText(" "+theTranslator->trEnumName());
-          else if (md->isEnumValue())
-            ol.parseText(" "+theTranslator->trEnumValue());
-          else if (md->isTypedef())
-            ol.docify(" typedef");
+          if (!md->isObjCMethod())
+          {
+            if ( md->isFunction() || md->isSignal() || md->isSlot() ) 
+              ol.docify(md->argsString());
+            else if (md->isEnumerate())
+              ol.parseText(" "+theTranslator->trEnumName());
+            else if (md->isEnumValue())
+              ol.parseText(" "+theTranslator->trEnumValue());
+            else if (md->isTypedef())
+              ol.docify(" typedef");
+          }
           ol.writeString(" (");
           ol.parseText(theTranslator->trDefinedIn()+" ");
           if (cd->isLinkable())
@@ -1589,7 +1660,8 @@ void ClassDef::writeMemberList(OutputList &ol)
           ol.writeString("</td>");
           ol.writeString("<td>");
         }
-        if ((prot!=Public || virt!=Normal || 
+        if (
+            (prot!=Public || (virt!=Normal && !m_isObjC) || 
              md->isFriend() || md->isRelated() || md->isExplicit() ||
              md->isMutable() || (md->isInline() && Config_getBool("INLINE_INFO")) ||
              md->isSignal() || md->isSlot() ||
@@ -1611,7 +1683,8 @@ void ClassDef::writeMemberList(OutputList &ol)
             if (prot==Protected)       sl.append("protected");
             else if (prot==Private)    sl.append("private");
             else if (prot==Package)    sl.append("package");
-            if (virt==Virtual)         sl.append("virtual");
+            if (virt==Virtual && 
+                !m_isObjC)             sl.append("virtual");
             else if (virt==Pure)       sl.append("pure virtual");
             if (md->isStatic())        sl.append("static");
             if (md->isSignal())        sl.append("signal");
@@ -1882,10 +1955,15 @@ bool ClassDef::hasDocumentation() const
 // returns TRUE iff class definition `bcd' represents an (in)direct base 
 // class of class definition `cd'.
 
-bool ClassDef::isBaseClass(ClassDef *bcd, bool followInstances)
+bool ClassDef::isBaseClass(ClassDef *bcd, bool followInstances,int level)
 {
   bool found=FALSE;
   //printf("isBaseClass(cd=%s) looking for %s\n",cd->name().data(),bcd->name().data());
+  if (level>256)
+  {
+    err("Possible recursive class relation while inside %s and looking for %s\n",name().data(),bcd->name().data());
+    return FALSE;
+  }
   BaseClassListIterator bcli(*baseClasses());
   for ( ; bcli.current() && !found ; ++bcli)
   {
@@ -1895,7 +1973,7 @@ bool ClassDef::isBaseClass(ClassDef *bcd, bool followInstances)
     if (ccd==bcd) 
       found=TRUE;
     else 
-      found=ccd->isBaseClass(bcd,followInstances);
+      found=ccd->isBaseClass(bcd,followInstances,level+1);
   }
   return found;
 }
@@ -1999,7 +2077,7 @@ void ClassDef::mergeMembers()
               //printf("same member found srcMi->virt=%d dstMi->virt=%d\n",srcMi->virt,dstMi->virt);
               if ((srcMi->virt!=Normal && dstMi->virt!=Normal) ||
                   bClass->name()+"::"+srcMi->scopePath == dstMi->scopePath ||
-                  dstMd->getClassDef()->compoundType()==ClassDef::Interface
+                  dstMd->getClassDef()->compoundType()==Interface
                  ) 
               {
                 found=TRUE;
@@ -2139,6 +2217,52 @@ void ClassDef::mergeMembers()
 
 //----------------------------------------------------------------------------
 
+/*! Merges the members of a Objective-C category into this class.
+ */
+void ClassDef::mergeCategory(ClassDef *category)
+{
+  category->m_categoryOf = this;
+    
+  MemberNameInfoSDict *srcMnd  = category->m_allMemberNameInfoSDict;
+  MemberNameInfoSDict *dstMnd  =           m_allMemberNameInfoSDict;
+
+  MemberNameInfoSDict::Iterator srcMnili(*srcMnd);
+  MemberNameInfo *srcMni;
+  for ( ; (srcMni=srcMnili.current()) ; ++srcMnili)
+  {
+    MemberNameInfo *dstMni=dstMnd->find(srcMni->memberName());
+    if (dstMni) // method is already defined in the class
+    {
+      // TODO: we should remove the other member and insert this one.
+    }
+    else // new method name
+    {
+      // create a deep copy of the list (only the MemberInfo's will be 
+      // copied, not the actual MemberDef's)
+      MemberNameInfo *newMni = 0;
+      newMni = new MemberNameInfo(srcMni->memberName()); 
+
+      // copy the member(s) from the category to this class
+      MemberNameInfoIterator mnii(*srcMni);
+      MemberInfo *mi;
+      for (;(mi=mnii.current());++mnii)
+      {
+        //printf("Adding!\n");
+        MemberInfo *newMi=new MemberInfo(mi->memberDef,mi->prot,mi->virt,mi->inherited);
+        newMi->scopePath=mi->scopePath;
+        newMi->ambigClass=mi->ambigClass;
+        newMi->ambiguityResolutionScope=mi->ambiguityResolutionScope.copy();
+        newMni->append(newMi);
+      }
+
+      // add it to the dictionary
+      dstMnd->append(newMni->memberName(),newMni);
+    }
+  }
+}
+
+//----------------------------------------------------------------------------
+
 void ClassDef::addUsedClass(ClassDef *cd,const char *accessName)
 {
   if (m_usesImplClassDict==0) 
@@ -2373,13 +2497,9 @@ void ClassDef::determineIntfUsageRelation()
 }
 #endif
 
-//PackageDef *ClassDef::packageDef() const
-//{
-//  return m_fileDef ? m_fileDef->packageDef() : 0;
-//}
-
 QCString ClassDef::compoundTypeString() const
 {
+  if (m_compType==Interface && m_isObjC) return "class";
   switch (m_compType)
   {
     case Class:     return "class";
@@ -2389,8 +2509,8 @@ QCString ClassDef::compoundTypeString() const
     case Protocol:  return "protocol";
     case Category:  return "category";
     case Exception: return "exception";
+    default:        return "unknown";
   }
-  return "unknown";
 }
 
 QCString ClassDef::getOutputFileBase() const 
@@ -2528,7 +2648,7 @@ ClassDef *ClassDef::insertTemplateInstance(const QCString &fileName,
   ClassDef *templateClass=m_templateInstances->find(templSpec);
   if (templateClass==0)
   {
-    Debug::print(Debug::Classes,0,"  New template instance class %s%s\n",name().data(),templSpec.data());
+    Debug::print(Debug::Classes,0,"      New template instance class `%s'`%s'\n",name().data(),templSpec.data());
     templateClass = new ClassDef(
         fileName,startLine,name()+templSpec,ClassDef::Class);
     templateClass->setTemplateMaster(this);
@@ -2539,6 +2659,26 @@ ClassDef *ClassDef::insertTemplateInstance(const QCString &fileName,
   return templateClass;
 }
 
+ClassDef *ClassDef::getVariableInstance(const char *templSpec)
+{
+  if (m_variableInstances==0) 
+  {
+    m_variableInstances = new QDict<ClassDef>(17);
+    m_variableInstances->setAutoDelete(TRUE);
+  }
+  ClassDef *templateClass=m_variableInstances->find(templSpec);
+  if (templateClass==0)
+  {
+    Debug::print(Debug::Classes,0,"      New template variable instance class `%s'`%s'\n",name().data(),templSpec);
+    templateClass = new ClassDef("<code>",1,name()+templSpec,
+                        ClassDef::Class,0,0,FALSE);
+    templateClass->addMembersToTemplateInstance( this, templSpec );
+    templateClass->setTemplateMaster(this);
+    m_variableInstances->insert(templSpec,templateClass);
+  }
+  return templateClass;
+}
+
 void ClassDef::setTemplateBaseClassNames(QDict<int> *templateNames)
 {
   if (templateNames==0) return;
@@ -2703,6 +2843,8 @@ QCString ClassDef::className() const
 
 void ClassDef::addListReferences()
 {
+  if (!isLinkableInProject()) return;
+  //printf("ClassDef(%s)::addListReferences()\n",name().data());
   addRefItem(xrefListItems(),
              theTranslator->trClass(TRUE,TRUE),
              getOutputFileBase(),displayName()
@@ -2728,7 +2870,6 @@ MemberDef *ClassDef::getMemberByName(const QCString &name)
 {
   MemberDef *xmd = 0;
   MemberNameInfo *mni = m_allMemberNameInfoSDict->find(name);
-  //printf("getMemberByName(%s)=%p\n",name.data(),mni);
   if (mni)
   {
     const int maxInheritanceDepth = 100000;
@@ -2738,8 +2879,9 @@ MemberDef *ClassDef::getMemberByName(const QCString &name)
     for (mnii.toFirst();(mi=mnii.current());++mnii)
     {
       ClassDef *mcd=mi->memberDef->getClassDef();
-      //printf("found member in %s\n",mcd->name().data());
       int m=minClassDistance(this,mcd);
+      //printf("found member in %s linkable=%d m=%d\n",
+      //    mcd->name().data(),mcd->isLinkable(),m);
       if (m<mdist && mcd->isLinkable())
       {
         mdist=m;
@@ -2747,7 +2889,7 @@ MemberDef *ClassDef::getMemberByName(const QCString &name)
       }
     }
   }
+  //printf("getMemberByName(%s)=%p\n",name.data(),xmd);
   return xmd;
 }
 
-
