@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -99,10 +99,13 @@ CommandMap cmdMap[] =
   { "$",             CMD_DOLLAR },
   { "#",             CMD_HASH },
   { "%",             CMD_PERCENT },
-  { "~",             CMD_LANGSWITCH },
+  //{ "~",             CMD_LANGSWITCH },
   { "_internalref",  CMD_INTERNALREF },
   { "dot",           CMD_DOT },
   { "enddot",        CMD_ENDDOT },
+  { "manonly",       CMD_MANONLY },
+  { "endmanonly",    CMD_ENDMANONLY },
+  { "includelineno", CMD_INCWITHLINES },
   { 0,               0 }
 };
 
