@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -66,7 +66,7 @@ enum CommandType
   CMD_INTERNAL     = 32,         
   CMD_INTERNALREF  = 33,
   CMD_INVARIANT    = 34 | SIMPLESECT_BIT ,
-  CMD_LANGSWITCH   = 35,
+  //CMD_LANGSWITCH   = 35,
   CMD_LATEXONLY    = 36,
   CMD_LESS         = 37,
   CMD_LI           = 38,
@@ -103,7 +103,10 @@ enum CommandType
   CMD_XREFITEM     = 69 | SIMPLESECT_BIT,
   CMD_XMLONLY      = 70,
   CMD_DOT          = 71,
-  CMD_ENDDOT       = 72
+  CMD_ENDDOT       = 72,
+  CMD_MANONLY      = 73,
+  CMD_ENDMANONLY   = 74,
+  CMD_INCWITHLINES = 75
 };
 
 enum HtmlTagType
