@@ -2,7 +2,7 @@
  *
  * $Id: debug.cpp,v 1.7 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -57,6 +57,8 @@ static int labelToEnumValue(const char *l)
     return Debug::PrintTree;
   else if (label=="time")
     return Debug::Time;
+  else if (label=="extcmd")
+    return Debug::ExtCmd;
   else
     return 0;
 }
