@@ -3,7 +3,7 @@
  * $Id: debug.h,v 1.6 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -31,7 +31,8 @@ class Debug
                      CommentCnv   = 0x00000020,
                      Validate     = 0x00000040,
                      PrintTree    = 0x00000080,
-                     Time         = 0x00000100
+                     Time         = 0x00000100,
+                     ExtCmd       = 0x00000200
                    };
     static void print(DebugMask mask,int prio,const char *fmt,...);
     static void setFlag(const char *label);
