@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,12 +34,18 @@
 #include "searchindex.h"
 //#include "xml.h"
 
+#if defined(_MSC_VER) || defined(__BORLANDC__)
+#define popen _popen
+#define pclose _pclose
+#endif
+
 class DevNullCodeDocInterface : public BaseCodeDocInterface
 {
   public:
     virtual void codify(const char *) {}
-    virtual void writeCodeLink(const char *,const char *,
-                               const char *,const char *) {}
+    virtual void writeCodeLink(const char *ref,const char *file,
+                               const char *anchor,const char *name) 
+    { ref=ref; file=file; anchor=anchor; name=name; }
     virtual void writeLineNumber(const char *,const char *,
                                  const char *,int) {}
     virtual void startCodeLine() {}
@@ -54,7 +60,7 @@ class DevNullCodeDocInterface : public BaseCodeDocInterface
 
 
 /*! create a new file definition, where \a p is the file path, 
-    \a the file name, and \a ref is an HTML anchor name if the
+    \a nm the file name, and \a ref is an HTML anchor name if the
     file was read from a tag file or 0 otherwise
 */
 FileDef::FileDef(const char *p,const char *nm,
@@ -83,12 +89,14 @@ FileDef::FileDef(const char *p,const char *nm,
   package = 0;
   isSource = FALSE; 
   docname = nm;
+  dir = 0;
   if (Config_getBool("FULL_PATH_NAMES"))
   {
     docname.prepend(stripFromPath(path.copy()));
   }
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
+  acquireFileVersion();
 }
 
 /*! destroy the file definition */
@@ -149,12 +157,9 @@ void FileDef::writeDetailedDocumentation(OutputList &ol)
   {
     ol.writeRuler();
     ol.pushGeneratorState();
-    //bool latexOn = ol.isEnabled(OutputGenerator::Latex);
-    //if (latexOn) ol.disable(OutputGenerator::Latex);
     ol.disable(OutputGenerator::Latex);
     ol.disable(OutputGenerator::RTF);
     ol.writeAnchor(0,"_details"); 
-    //if (latexOn) ol.enable(OutputGenerator::Latex);
     ol.popGeneratorState();
     ol.startGroupHeader();
     ol.parseText(theTranslator->trDetailedDescription());
@@ -213,18 +218,50 @@ void FileDef::writeDocumentation(OutputList &ol)
 
   //printf("WriteDocumentation diskname=%s\n",diskname.data());
   
-  QCString pageTitle=name()+" File Reference";
+  QCString versionTitle;
+  if (!fileVersion.isEmpty())
+  {
+    versionTitle=("("+fileVersion+")");
+  }
+  QCString title = docname+versionTitle;
+  QCString pageTitle=theTranslator->trFileReference(docname);
   startFile(ol,getOutputFileBase(),name(),pageTitle);
-  startTitle(ol,getOutputFileBase());
-  ol.parseText(theTranslator->trFileReference(docname));
-  addGroupListToTitle(ol,this);
-  endTitle(ol,getOutputFileBase(),docName());
-  //ol.newParagraph();
+
+  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
+  {
+    getDirDef()->writeNavigationPath(ol);
+    QCString pageTitleShort=theTranslator->trFileReference(name());
+    startTitle(ol,getOutputFileBase());
+    ol.pushGeneratorState();
+      ol.disableAllBut(OutputGenerator::Html);
+      ol.parseText(pageTitleShort); // Html only
+      ol.enableAll();
+      ol.disable(OutputGenerator::Html);
+      ol.parseText(pageTitle); // other output formats
+    ol.popGeneratorState();
+    addGroupListToTitle(ol,this);
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  else
+  {
+    startTitle(ol,getOutputFileBase());
+    ol.parseText(pageTitle);
+    addGroupListToTitle(ol,this);
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  if (!fileVersion.isEmpty())
+  {
+    ol.disableAllBut(OutputGenerator::Html);
+    ol.startProjectNumber();
+    ol.docify(versionTitle);
+    ol.endProjectNumber();
+    ol.enableAll();
+  }
   
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
   
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
@@ -237,28 +274,37 @@ void FileDef::writeDocumentation(OutputList &ol)
                      << "</filename>" << endl;
   }
   
-  ol.startTextBlock();
   if (Config_getBool("DETAILS_AT_TOP"))
   {
+    ol.startTextBlock(); 
     writeDetailedDocumentation(ol);
+    ol.endTextBlock();
+
+    ol.pushGeneratorState();
+    ol.disable(OutputGenerator::Man);
+    ol.disable(OutputGenerator::RTF);
     ol.newParagraph();
+    ol.popGeneratorState();
   }
-  else if (briefDescription()) 
+  else if (!briefDescription().isEmpty()) 
   {
     ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
-    ol.writeString(" \n");
+    //ol.writeString(" \n");
     ol.disableAllBut(OutputGenerator::Html);
     ol.startTextLink(0,"_details");
     ol.parseText(theTranslator->trMore());
     ol.endTextLink();
     ol.enableAll();
+
+    ol.pushGeneratorState();
     ol.disable(OutputGenerator::Man);
+    ol.disable(OutputGenerator::RTF);
     ol.newParagraph();
-    ol.enable(OutputGenerator::Man);
+    ol.popGeneratorState();
   }
   ol.writeSynopsis();
  
-  if (Config_getBool("SHOW_INCLUDE_FILES"))
+  if (Config_getBool("SHOW_INCLUDE_FILES") && includeList->count()>0)
   {
     ol.startTextBlock(TRUE);
     QListIterator<IncludeInfo> ili(*includeList);
@@ -274,11 +320,15 @@ void FileDef::writeDocumentation(OutputList &ol)
                       fd->name().right(5)==".java";
       }
       ol.startTypewriter();
-      if (isIDLorJava)
+      if (isIDLorJava) // IDL/Java include
       {
         ol.docify("import ");
       }
-      else
+      else if (ii->imported) // Objective-C include
+      {
+        ol.docify("#import ");
+      }
+      else // C/C++ include
       {
         ol.docify("#include ");
       }
@@ -301,12 +351,13 @@ void FileDef::writeDocumentation(OutputList &ol)
             0,ii->includeName);
         if (!Config_getString("GENERATE_TAGFILE").isEmpty() && !fd->isReference()) 
         {
-          const char *locStr = (ii->local || isIDLorJava) ? "yes" : "no";
+          const char *locStr = (ii->local    || isIDLorJava) ? "yes" : "no";
+          const char *impStr = (ii->imported || isIDLorJava) ? "yes" : "no";
           Doxygen::tagFile << "    <includes id=\"" 
-                           << convertToXML(fd->getOutputFileBase()) 
-                           << "\" name=\"" 
-                           << convertToXML(fd->name())
-                           << "\" local=\"" << locStr << "\">" 
+                           << convertToXML(fd->getOutputFileBase()) << "\" "
+                           << "name=\"" << convertToXML(fd->name()) << "\" "
+                           << "local=\"" << locStr << "\" "
+                           << "imported=\"" << impStr << "\">"
                            << convertToXML(ii->includeName)
                            << "</includes>" 
                            << endl;
@@ -325,12 +376,7 @@ void FileDef::writeDocumentation(OutputList &ol)
       if (isIDLorJava) 
         ol.docify(";");
       ol.endTypewriter();
-      ol.disable(OutputGenerator::RTF);
       ol.lineBreak();
-      ol.enableAll();
-      ol.disableAllBut(OutputGenerator::RTF);
-      ol.newParagraph();
-      ol.enableAll();
     }
     ol.endTextBlock();
   }
@@ -341,12 +387,14 @@ void FileDef::writeDocumentation(OutputList &ol)
     DotInclDepGraph incDepGraph(this,Config_getInt("MAX_DOT_GRAPH_DEPTH"),FALSE);
     if (!incDepGraph.isTrivial())
     {
+      ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
       ol.newParagraph();
       ol.startInclDepGraph();
       ol.parseText(theTranslator->trInclDepGraph(name()));
       ol.endInclDepGraph(incDepGraph);
       ol.enableAll();
+      ol.endTextBlock(TRUE);
     }
     //incDepGraph.writeGraph(Config_getString("HTML_OUTPUT"),fd->getOutputFileBase());
   }
@@ -357,12 +405,14 @@ void FileDef::writeDocumentation(OutputList &ol)
     DotInclDepGraph incDepGraph(this,Config_getInt("MAX_DOT_GRAPH_DEPTH"),TRUE);
     if (!incDepGraph.isTrivial())
     {
+      ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
       ol.newParagraph();
       ol.startInclDepGraph();
       ol.parseText(theTranslator->trInclByDepGraph());
       ol.endInclDepGraph(incDepGraph);
       ol.enableAll();
+      ol.endTextBlock(TRUE);
     }
     //incDepGraph.writeGraph(Config_getString("HTML_OUTPUT"),fd->getOutputFileBase());
   }
@@ -378,8 +428,6 @@ void FileDef::writeDocumentation(OutputList &ol)
     ol.enableAll();
   }
   
-  ol.endTextBlock();
-  
   ol.startMemberSections();
 
   if (namespaceSDict->count()>0)
@@ -491,11 +539,28 @@ void FileDef::writeDocumentation(OutputList &ol)
 /*! Write a source listing of this file to the output */
 void FileDef::writeSource(OutputList &ol)
 {
+  QCString title = docname;
+  if (!fileVersion.isEmpty())
+  {
+    title+=(" ("+fileVersion+")");
+  }
+  QCString pageTitle = theTranslator->trSourceFile(title);
   ol.disableAllBut(OutputGenerator::Html);
-  startFile(ol,getSourceFileBase(),0,docname+" Source File");
-  startTitle(ol,0);
-  ol.parseText(docname);
-  endTitle(ol,0,0);
+  startFile(ol,getSourceFileBase(),0,pageTitle);
+
+  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
+  {
+    getDirDef()->writeNavigationPath(ol);
+    startTitle(ol,getOutputFileBase());
+    ol.parseText(name());
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  else
+  {
+    startTitle(ol,0);
+    ol.parseText(title);
+    endTitle(ol,0,0);
+  }
 
   if (isLinkable())
   {
@@ -539,53 +604,36 @@ void FileDef::insertMember(MemberDef *md)
 {
   //printf("%s:FileDef::insertMember(%s)\n",name().data(),md->name().data());
   allMemberList.append(md); 
+  bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
   switch(md->memberType())
   {
     case MemberDef::Variable:     
     case MemberDef::Property:     
-      decVarMembers.append(md);
-      if (sortMemberDocs)
-        docVarMembers.inSort(md); 
-      else
-        docVarMembers.append(md);
+      if (sortBriefDocs)  decVarMembers.inSort(md); else decVarMembers.append(md);
+      if (sortMemberDocs) docVarMembers.inSort(md); else docVarMembers.append(md);
       break;
     case MemberDef::Function: 
-      decFuncMembers.append(md);
-      if (sortMemberDocs)    
-        docFuncMembers.inSort(md); 
-      else
-        docFuncMembers.append(md);
+      if (sortBriefDocs)  decFuncMembers.inSort(md); else decFuncMembers.append(md);
+      if (sortMemberDocs) docFuncMembers.inSort(md); else docFuncMembers.append(md);
       break;
     case MemberDef::Typedef:      
-      decTypedefMembers.append(md);
-      if (sortMemberDocs)
-        docTypedefMembers.inSort(md); 
-      else
-        docTypedefMembers.append(md);
+      if (sortBriefDocs)  decTypedefMembers.inSort(md); else decTypedefMembers.append(md);
+      if (sortMemberDocs) docTypedefMembers.inSort(md); else docTypedefMembers.append(md);
       break;
     case MemberDef::Enumeration:  
-      decEnumMembers.append(md);
-      if (sortMemberDocs)
-        docEnumMembers.inSort(md); 
-      else
-        docEnumMembers.append(md);
+      if (sortBriefDocs)  decEnumMembers.inSort(md); else decEnumMembers.append(md);
+      if (sortMemberDocs) docEnumMembers.inSort(md); else docEnumMembers.append(md);
       break;
     case MemberDef::EnumValue:    // enum values are shown inside their enums
       break;
     case MemberDef::Prototype:    
-      decProtoMembers.append(md);
-      if (sortMemberDocs)
-        docProtoMembers.inSort(md); 
-      else
-        docProtoMembers.append(md);
+      if (sortBriefDocs)  decProtoMembers.inSort(md); else decProtoMembers.append(md);
+      if (sortMemberDocs) docProtoMembers.inSort(md); else docProtoMembers.append(md);
       break;
     case MemberDef::Define:       
-      decDefineMembers.append(md);
-      if (sortMemberDocs)
-        docDefineMembers.inSort(md); 
-      else
-        docDefineMembers.append(md);
+      if (sortBriefDocs)  decDefineMembers.inSort(md); else decDefineMembers.append(md);
+      if (sortMemberDocs) docDefineMembers.inSort(md); else docDefineMembers.append(md);
       break;
     default:
        err("FileDef::insertMembers(): "
@@ -600,7 +648,7 @@ void FileDef::insertMember(MemberDef *md)
 /*! Adds compound definition \a cd to the list of all compounds of this file */
 void FileDef::insertClass(ClassDef *cd)
 {
-  if (Config_getBool("SORT_MEMBER_DOCS"))
+  if (Config_getBool("SORT_BRIEF_DOCS"))
     classSDict->inSort(cd->name(),cd);
   else
     classSDict->append(cd->name(),cd);
@@ -611,7 +659,7 @@ void FileDef::insertNamespace(NamespaceDef *nd)
 {
   if (!nd->name().isEmpty() && namespaceSDict->find(nd->name())==0)
   {
-    if (Config_getBool("SORT_MEMBER_DOCS"))
+    if (Config_getBool("SORT_BRIEF_DOCS"))
       namespaceSDict->inSort(nd->name(),nd);
     else
       namespaceSDict->append(nd->name(),nd);
@@ -664,19 +712,20 @@ void FileDef::addUsingDirective(NamespaceDef *nd)
   }
 }
 
-void FileDef::addUsingDeclaration(ClassDef *cd)
+void FileDef::addUsingDeclaration(Definition *d)
 {
   if (usingDeclList==0)
   {
-    usingDeclList = new ClassSDict;
+    usingDeclList = new SDict<Definition>(17);
   }
-  if (usingDeclList->find(cd->qualifiedName())==0)
+  if (usingDeclList->find(d->qualifiedName())==0)
   {
-    usingDeclList->append(cd->qualifiedName(),cd);
+    usingDeclList->append(d->qualifiedName(),d);
   }
 }
 
-void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local)
+void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local,
+                                   bool imported)
 {
   //printf("FileDef::addIncludeDependency(%p,%s,%d)\n",fd,incName,local);
   QCString iName = fd ? fd->absFilePath().data() : incName;
@@ -686,6 +735,7 @@ void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local)
     ii->fileDef     = fd;
     ii->includeName = incName;
     ii->local       = local;
+    ii->imported    = imported;
     includeList->append(ii);
     includeDict->insert(iName,ii);
   }
@@ -742,7 +792,8 @@ void FileDef::addIncludedUsingDirectives()
 }
 
 
-void FileDef::addIncludedByDependency(FileDef *fd,const char *incName,bool local)
+void FileDef::addIncludedByDependency(FileDef *fd,const char *incName,
+                                      bool local,bool imported)
 {
   //printf("FileDef::addIncludedByDependency(%p,%s,%d)\n",fd,incName,local);
   QCString iName = fd ? fd->absFilePath().data() : incName;
@@ -752,6 +803,7 @@ void FileDef::addIncludedByDependency(FileDef *fd,const char *incName,bool local
     ii->fileDef     = fd;
     ii->includeName = incName;
     ii->local       = local;
+    ii->imported    = imported;
     includedByList->append(ii);
     includedByDict->insert(iName,ii);
   }
@@ -908,6 +960,7 @@ static void mergeFileDef(Directory *root,FileDef *fd)
   dirNode->addChild(e);
 }
 
+#if 0
 static void generateIndent(QTextStream &t,DirEntry *de,int level)
 {
   if (de->parent())
@@ -953,7 +1006,6 @@ static void generateIndent(QTextStream &t,DirEntry *de,int level)
   }
 }
 
-
 static void writeDirTreeNode(QTextStream &t,Directory *root,int level)
 {
   QCString indent;
@@ -984,12 +1036,44 @@ static void writeDirTreeNode(QTextStream &t,Directory *root,int level)
     }
   }
 }
+#endif
 
-void generateFileTree(QTextStream &t)
+static void addDirsAsGroups(Directory *root,GroupDef *parent,int level)
+{
+  GroupDef *gd=0;
+  if (root->kind()==DirEntry::Dir)
+  {
+    gd = new GroupDef("<generated>",
+                      1,
+                      root->path(), // name
+                      root->name()  // title
+                     );
+    if (parent) 
+    {
+      parent->addGroup(gd);
+      gd->makePartOfGroup(parent);
+    }
+    else
+    {
+      Doxygen::groupSDict.append(root->path(),gd);
+    }
+  }
+  QListIterator<DirEntry> dli(root->children());
+  DirEntry *de;
+  for (dli.toFirst();(de=dli.current());++dli)
+  {
+    if (de->kind()==DirEntry::Dir)
+    {
+      addDirsAsGroups((Directory *)de,gd,level+1);
+    }
+  }
+}
+
+void generateFileTree()
 {
   FTVHelp::generateTreeViewImages();
   
-  Directory *root=new Directory(0,"");
+  Directory *root=new Directory(0,"root");
   root->setLast(TRUE);
   FileNameListIterator fnli(Doxygen::inputNameList); 
   FileName *fn;
@@ -1002,12 +1086,15 @@ void generateFileTree(QTextStream &t)
       mergeFileDef(root,fd);
     }
   }
-  t << "<div class=\"directory\">\n";
-  writeDirTreeNode(t,root,0);
-  t << "</div>\n";
+  //t << "<div class=\"directory\">\n";
+  //writeDirTreeNode(t,root,0);
+  //t << "</div>\n";
+  addDirsAsGroups(root,0,0);
   delete root;
 }
 
+//-------------------------------------------------------------------
+
 void FileDef::combineUsingRelations()
 {
   if (visited) return; // already done
@@ -1036,8 +1123,8 @@ void FileDef::combineUsingRelations()
       // add used classes of namespace nd to this namespace
       if (nd->getUsedClasses())
       {
-        ClassSDict::Iterator cli(*nd->getUsedClasses());
-        ClassDef *ucd;
+        SDict<Definition>::Iterator cli(*nd->getUsedClasses());
+        Definition *ucd;
         for (cli.toFirst();(ucd=cli.current());++cli)
         {
           //printf("Adding class %s to the using list of %s\n",cd->qualifiedName().data(),qualifiedName().data());
@@ -1048,4 +1135,39 @@ void FileDef::combineUsingRelations()
   }
 }
 
+bool FileDef::isDocumentationFile() const
+{
+  return name().right(4)==".doc" ||
+         name().right(4)==".txt" ||
+         name().right(4)==".dox";
+}
+
+void FileDef::acquireFileVersion()
+{
+  QCString vercmd = Config_getString("FILE_VERSION_FILTER");
+  if (!vercmd.isEmpty()) 
+  {
+    msg("Version of %s : ",filepath.data());
+    FILE *f=popen(vercmd+" "+filepath,"r");
+    if (!f)
+    {
+      err("Error: could not execute %s\n",vercmd.data());
+      return;
+    }
+    const int bufSize=1024;
+    char buf[bufSize];
+    int numRead = fread(buf,1,bufSize,f);
+    pclose(f);
+    if (numRead > 0) 
+    {
+      fileVersion = QCString(buf,numRead).stripWhiteSpace();
+      msg("%s\n",fileVersion.data());
+    }
+    else 
+    {
+      msg("no version available\n");
+    }
+  }
+}
+
 
