@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,6 +26,12 @@
 #include "dot.h"
 #include "message.h"
 #include "config.h"
+#include "htmlgen.h"
+
+
+static const int NUM_HTML_LIST_TYPES = 4;
+static const char types[][NUM_HTML_LIST_TYPES] = {"1", "a", "i", "A"};
+
 
 static QString htmlAttribsToString(const HtmlAttribList &attribs)
 {
@@ -61,7 +67,7 @@ void HtmlDocVisitor::visit(DocWord *w)
 void HtmlDocVisitor::visit(DocLinkedWord *w)
 {
   if (m_hide) return;
-  startLink(w->ref(),w->file(),w->anchor());
+  startLink(w->ref(),w->file(),w->relPath(),w->anchor());
   filter(w->word());
   endLink();
 }
@@ -171,6 +177,7 @@ void HtmlDocVisitor::visit(DocStyleChange *s)
         m_insidePre=FALSE;
         m_t << "</pre>";
       }
+      break;
     case DocStyleChange::Div:
       if (s->enable()) m_t << "<div" << htmlAttribsToString(s->attribs()) << ">";  else m_t << "</div>";
       break;
@@ -188,18 +195,19 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
   switch(s->type())
   {
     case DocVerbatim::Code: // fall though
-      m_t << "<pre class=\"fragment\"><div>"; 
+      m_t << PREFRAG_START;
       parseCode(m_ci,s->context(),s->text().latin1(),s->isExample(),s->exampleFile());
-      m_t << "</div></pre>"; 
+      m_t << PREFRAG_END;
       break;
     case DocVerbatim::Verbatim: 
-      m_t << "<pre class=\"fragment\"><div>";
+      m_t << PREFRAG_START;
       filter(s->text());
-      m_t << "</div></pre>"; 
+      m_t << PREFRAG_END;
       break;
     case DocVerbatim::HtmlOnly: 
       m_t << s->text(); 
       break;
+    case DocVerbatim::ManOnly: 
     case DocVerbatim::LatexOnly: 
     case DocVerbatim::XmlOnly: 
       /* nothing */ 
@@ -223,7 +231,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
         file.close();
 
         m_t << "<div align=\"center\">" << endl;
-        writeDotFile(fileName);
+        writeDotFile(fileName,s->relPath());
         m_t << "</div>" << endl;
 
         file.remove();
@@ -244,9 +252,18 @@ void HtmlDocVisitor::visit(DocInclude *inc)
   switch(inc->type())
   {
     case DocInclude::Include: 
-      m_t << "<div class=\"fragment\"><pre>";
+      m_t << PREFRAG_START;
       parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile());
-      m_t << "</pre></div>"; 
+      m_t << PREFRAG_END;
+      break;
+    case DocInclude::IncWithLines:
+      { 
+         m_t << PREFRAG_START;
+         QFileInfo cfi( inc->file() );
+         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
+         m_t << PREFRAG_END;
+      }
       break;
     case DocInclude::DontInclude: 
       break;
@@ -254,9 +271,9 @@ void HtmlDocVisitor::visit(DocInclude *inc)
       m_t << inc->text(); 
       break;
     case DocInclude::VerbInclude: 
-      m_t << "<div class=\"fragment\"><pre>";
+      m_t << PREFRAG_START;
       filter(inc->text());
-      m_t << "</pre></div>"; 
+      m_t << PREFRAG_END;
       break;
   }
 }
@@ -267,7 +284,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
   //    op->type(),op->isFirst(),op->isLast(),op->text().data());
   if (op->isFirst()) 
   {
-    if (!m_hide) m_t << "<div class=\"fragment\"><pre>";
+    if (!m_hide) m_t << PREFRAG_START;
     pushEnabled();
     m_hide=TRUE;
   }
@@ -281,7 +298,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
   if (op->isLast())  
   {
     popEnabled();
-    if (!m_hide) m_t << "</pre></div>"; 
+    if (!m_hide) m_t << PREFRAG_END;
   }
   else
   {
@@ -294,13 +311,14 @@ void HtmlDocVisitor::visit(DocFormula *f)
   if (m_hide) return;
   bool bDisplay = f->text().at(0)=='\\';
   if (bDisplay) m_t << "<p class=\"formulaDsp\">" << endl;
-  m_t << "<img class=\"formula" << (bDisplay ? "Dsp" : "Inl");
+  m_t << "<img class=\"formula" 
+      << (bDisplay ? "Dsp" : "Inl");
   m_t << "\" alt=\"";
   filterQuotedCdataAttr(f->text());
   m_t << "\"";
   /// @todo cache image dimensions on formula generation and give height/width
   /// for faster preloading and better rendering of the page
-  m_t << " src=\"" << f->name() << ".png\">";
+  m_t << " src=\"" << f->relPath() << f->name() << ".png\">";
   if (bDisplay)
     m_t << endl << "<p>" << endl;
 }
@@ -313,12 +331,21 @@ void HtmlDocVisitor::visit(DocIndexEntry *)
 // visitor functions for compound nodes
 //--------------------------------------
 
+
 void HtmlDocVisitor::visitPre(DocAutoList *l)
 {
   if (m_hide) return;
   if (l->isEnumList())
   {
-    m_t << "<ol>";
+    //
+    // Do list type based on depth:
+    // 1.
+    //   a.
+    //     i.
+    //       A. 
+    //         1. (repeat)...
+    //
+    m_t << "<ol type=" << types[l->depth() % NUM_HTML_LIST_TYPES] << ">";
   }
   else
   {
@@ -694,7 +721,7 @@ void HtmlDocVisitor::visitPre(DocImage *img)
       baseName=baseName.right(baseName.length()-i-1);
     }
     m_t << "<div align=\"center\">" << endl;
-    m_t << "<img src=\"" << img->name() << "\" alt=\"" 
+    m_t << "<img src=\"" << img->relPath() << img->name() << "\" alt=\"" 
       << baseName << "\"" << htmlAttribsToString(img->attribs()) << ">" << endl;
     if (img->hasCaption())
     {
@@ -728,7 +755,7 @@ void HtmlDocVisitor::visitPost(DocImage *img)
 void HtmlDocVisitor::visitPre(DocDotFile *df)
 {
   if (m_hide) return;
-  writeDotFile(df->file());
+  writeDotFile(df->file(),df->relPath());
   m_t << "<div align=\"center\">" << endl;
   if (df->hasCaption())
   { 
@@ -749,7 +776,7 @@ void HtmlDocVisitor::visitPost(DocDotFile *df)
 void HtmlDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
-  startLink(lnk->ref(),lnk->file(),lnk->anchor());
+  startLink(lnk->ref(),lnk->file(),lnk->relPath(),lnk->anchor());
 }
 
 void HtmlDocVisitor::visitPost(DocLink *) 
@@ -761,7 +788,10 @@ void HtmlDocVisitor::visitPost(DocLink *)
 void HtmlDocVisitor::visitPre(DocRef *ref)
 {
   if (m_hide) return;
-  if (!ref->file().isEmpty()) startLink(ref->ref(),ref->file(),ref->anchor());
+  if (!ref->file().isEmpty()) 
+  {
+    startLink(ref->ref(),ref->file(),ref->relPath(),ref->anchor());
+  }
   if (!ref->hasLinkText()) filter(ref->targetTitle());
 }
 
@@ -805,24 +835,24 @@ void HtmlDocVisitor::visitPost(DocSecRefList *)
   m_t << "</multicol>" << endl;
 }
 
-void HtmlDocVisitor::visitPre(DocLanguage *l)
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    pushEnabled();
-    m_hide = TRUE;
-  }
-}
-
-void HtmlDocVisitor::visitPost(DocLanguage *l) 
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    popEnabled();
-  }
-}
+//void HtmlDocVisitor::visitPre(DocLanguage *l)
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    pushEnabled();
+//    m_hide = TRUE;
+//  }
+//}
+//
+//void HtmlDocVisitor::visitPost(DocLanguage *l) 
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    popEnabled();
+//  }
+//}
 
 void HtmlDocVisitor::visitPre(DocParamSect *s)
 {
@@ -854,7 +884,25 @@ void HtmlDocVisitor::visitPost(DocParamSect *)
 void HtmlDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
-  m_t << "    <tr><td valign=top><em>";
+  m_t << "    <tr><td valign=\"top\">";
+  if (pl->direction()!=DocParamSect::Unspecified)
+  {
+    m_t << "<tt>[";
+    if (pl->direction()==DocParamSect::In)
+    {
+      m_t << "in";
+    }
+    else if (pl->direction()==DocParamSect::Out)
+    {
+      m_t << "out";
+    }
+    else if (pl->direction()==DocParamSect::InOut)
+    {
+      m_t << "in,out";
+    }
+    m_t << "]</tt>&nbsp;";
+  }
+  m_t << "</td><td valign=\"top\"><em>";
   QStrListIterator li(pl->parameters());
   const char *s;
   bool first=TRUE;
@@ -875,10 +923,21 @@ void HtmlDocVisitor::visitPost(DocParamList *)
 void HtmlDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
-  m_t << "<dl compact><dt><b><a class=\"el\" href=\"" 
-    << x->file() << Doxygen::htmlFileExtension << "#" << x->anchor() << "\">";
+  bool anonymousEnum = x->file()=="@";
+  if (!anonymousEnum)
+  {
+    m_t << "<dl compact><dt><b><a class=\"el\" href=\"" 
+        << x->relPath() << x->file() << Doxygen::htmlFileExtension 
+        << "#" << x->anchor() << "\">";
+  }
+  else 
+  {
+    m_t << "<dl compact><dt><b>";
+  }
   filter(x->title());
-  m_t << ":</a></b></dt><dd>";
+  m_t << ":";
+  if (!anonymousEnum) m_t << "</a>";
+  m_t << "</b></dt><dd>";
 }
 
 void HtmlDocVisitor::visitPost(DocXRefItem *)
@@ -890,7 +949,7 @@ void HtmlDocVisitor::visitPost(DocXRefItem *)
 void HtmlDocVisitor::visitPre(DocInternalRef *ref)
 {
   if (m_hide) return;
-  startLink(0,ref->file(),ref->anchor());
+  startLink(0,ref->file(),ref->relPath(),ref->anchor());
 }
 
 void HtmlDocVisitor::visitPost(DocInternalRef *) 
@@ -971,7 +1030,8 @@ void HtmlDocVisitor::filterQuotedCdataAttr(const char* str)
   }
 }
 
-void HtmlDocVisitor::startLink(const QString &ref,const QString &file,const QString &anchor)
+void HtmlDocVisitor::startLink(const QString &ref,const QString &file,
+                               const QString &relPath,const QString &anchor)
 {
   QCString *dest;
   if (!ref.isEmpty()) // link to entity imported via tag file
@@ -988,7 +1048,11 @@ void HtmlDocVisitor::startLink(const QString &ref,const QString &file,const QStr
   m_t << "href=\"";
   if (!ref.isEmpty())
   {
-    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << *dest << "/";
+    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << relPath << *dest << "/";
+  }
+  else
+  {
+    m_t << relPath;
   }
   if (!file.isEmpty()) m_t << file << Doxygen::htmlFileExtension;
   if (!anchor.isEmpty()) m_t << "#" << anchor;
@@ -1013,7 +1077,7 @@ void HtmlDocVisitor::popEnabled()
   delete v;
 }
 
-void HtmlDocVisitor::writeDotFile(const QString &fileName)
+void HtmlDocVisitor::writeDotFile(const QString &fileName,const QString &relPath)
 {
   QString baseName=fileName;
   int i;
@@ -1025,10 +1089,10 @@ void HtmlDocVisitor::writeDotFile(const QString &fileName)
   writeDotGraphFromFile(fileName,outDir,baseName,BITMAP);
   QString mapName = baseName+".map";
   QString mapFile = fileName+".map";
-  m_t << "<img src=\"" << baseName << "." 
+  m_t << "<img src=\"" << relPath << baseName << "." 
     << Config_getEnum("DOT_IMAGE_FORMAT") << "\" alt=\""
     << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QString imap = getDotImageMapFromFile(fileName,outDir);
+  QString imap = getDotImageMapFromFile(fileName,outDir,relPath.data());
   m_t << "<map name=\"" << mapName << "\">" << imap << "</map>" << endl;
 }
 
