@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.cpp,v 1.56 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,8 @@
 #include "htmldocvisitor.h"
 #include "index.h"
 #include "pagedef.h"
+#include "debug.h"
+#include "dirdef.h"
 
 // #define GROUP_COLOR "#ff8080"
 
@@ -41,77 +43,144 @@
 #define DBG_HTML(x) 
 
 static const char *defaultStyleSheet = 
-"H1 {\n"
-"	text-align: center;\n"
-"	font-family: Arial, Helvetica, sans-serif;\n"
-"}\n"
-"H2 {\n"
+"BODY,H1,H2,H3,H4,H5,H6,P,CENTER,TD,TH,UL,DL,DIV {\n"
 "	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
 "}\n"
+"BODY,TD {\n"
+"       font-size: 90%;\n"
+"}\n"
+"H1 {\n"
+"	text-align: center;\n"
+"       font-size: 160%;\n"
+"}\n"
+"H2 {\n"
+"       font-size: 120%;\n"
+"}\n"
+"H3 {\n"
+"       font-size: 110%;\n"
+"}\n"
 "CAPTION { font-weight: bold }\n"
-"DIV.qindex { width: 100%;\n"
-"             background-color: #eeeeff;\n"
-"             border: 4px solid #eeeeff;\n"
-"             text-align: center;\n"
-"             margin-bottom: 2px\n" 
+"DIV.qindex {\n"
+"	width: 100%;\n"
+"	background-color: #eeeeff;\n"
+"	border: 1px solid #b0b0b0;\n"
+"	text-align: center;\n"
+"	margin: 2px;\n"
+"	padding: 2px;\n"
+"	line-height: 140%;\n"
+"}\n"
+"DIV.nav {\n"
+"	width: 100%;\n"
+"	background-color: #eeeeff;\n"
+"	border: 1px solid #b0b0b0;\n"
+"	text-align: center;\n"
+"	margin: 2px;\n"
+"	padding: 2px;\n"
+"	line-height: 140%;\n"
+"}\n"
+"A.qindex {\n"
+"       text-decoration: none;\n"
+"       font-weight: bold;\n"
+"       color: #1A419D;\n"
+"}\n"
+"A.qindex:visited {\n"
+"       text-decoration: none;\n"
+"       font-weight: bold;\n"
+"       color: #1A419D\n"
+"}\n"
+"A.qindex:hover {\n"
+"	text-decoration: none;\n"
+"	background-color: #ddddff;\n"
+"}\n"
+"A.qindexHL {\n"
+"	text-decoration: none;\n"
+"	font-weight: bold;\n"
+"	background-color: #6666cc;\n"
+"	color: #ffffff;\n"
+"	border: 1px double #9295C2;\n"
+"}\n"
+"A.qindexHL:hover {\n"
+"	text-decoration: none;\n"
+"	background-color: #6666cc;\n"
+"	color: #ffffff;\n"
 "}\n"
-"A.qindex { text-decoration: none; font-weight: bold; color: #0000ee }\n"
-"A.qindex:visited { text-decoration: none; font-weight: bold; color: #0000ee }\n"
-"A.qindex:hover { text-decoration: none; background-color: #ddddff }\n"
-"A.qindexHL { text-decoration: none; font-weight: bold;\n"
-"             background-color: #6666cc;\n"
-"             color: #ffffff\n"
-"           }\n"
-"A.qindexHL:hover { text-decoration: none; background-color: #6666cc; color: #ffffff }\n"
 "A.qindexHL:visited { text-decoration: none; background-color: #6666cc; color: #ffffff }\n"
 "A.el { text-decoration: none; font-weight: bold }\n"
 "A.elRef { font-weight: bold }\n"
-"A.code { text-decoration: none; font-weight: normal; color: #4444ee }\n"
-"A.codeRef { font-weight: normal; color: #4444ee }\n"
+"A.code:link { text-decoration: none; font-weight: normal; color: #0000FF}\n"
+"A.code:visited { text-decoration: none; font-weight: normal; color: #0000FF}\n"
+"A.codeRef:link { font-weight: normal; color: #0000FF}\n"
+"A.codeRef:visited { font-weight: normal; color: #0000FF}\n"
 "A:hover { text-decoration: none; background-color: #f2f2ff }\n"
 "DL.el { margin-left: -1cm }\n"
-"DIV.fragment {\n"
-"	width: 98%;\n"
+".fragment {\n"
+"       font-family: monospace\n"
+"}\n"
+"PRE.fragment {\n"
 "	border: 1px solid #CCCCCC;\n"
 "	background-color: #f5f5f5;\n"
-"	padding-left: 4px;\n"
-"	margin: 4px;\n"
+"	margin-top: 4px;\n"
+"	margin-bottom: 4px;\n"
+"	margin-left: 2px;\n"
+"	margin-right: 8px;\n"
+"	padding-left: 6px;\n"
+"	padding-right: 6px;\n"
+"	padding-top: 4px;\n"
+"	padding-bottom: 4px;\n"
 "}\n"
+//"DIV.fragment {\n"
+//"       font-family: monospace\n"
+//"	border: 1px solid #CCCCCC;\n"
+//"	background-color: #f5f5f5;\n"
+//"	padding: 6px;\n"
+//"}\n"
 "DIV.ah { background-color: black; font-weight: bold; color: #ffffff; margin-bottom: 3px; margin-top: 3px }\n"
-"TD.md { background-color: #f2f2ff; font-weight: bold; }\n"
-"TD.mdname1 { background-color: #f2f2ff; font-weight: bold; color: #602020; }\n"
-"TD.mdname { background-color: #f2f2ff; font-weight: bold; color: #602020; width: 600px; }\n"
-"DIV.groupHeader { margin-left: 16px; margin-top: 12px; margin-bottom: 6px; font-weight: bold }\n"
-"DIV.groupText { margin-left: 16px; font-style: italic; font-size: smaller }\n"
+"TD.md { background-color: #F4F4FB; font-weight: bold; }\n"
+"TD.mdPrefix {\n"
+"       background-color: #F4F4FB;\n"
+"       color: #606060;\n"
+"	font-size: 80%;\n"
+"}\n"
+"TD.mdname1 { background-color: #F4F4FB; font-weight: bold; color: #602020; }\n"
+"TD.mdname { background-color: #F4F4FB; font-weight: bold; color: #602020; width: 600px; }\n"
+"DIV.groupHeader {\n"
+"       margin-left: 16px;\n"
+"       margin-top: 12px;\n"
+"       margin-bottom: 6px;\n"
+"       font-weight: bold;\n"
+"}\n"
+"DIV.groupText { margin-left: 16px; font-style: italic; font-size: 90% }\n"
 "BODY {\n"
 "	background: white;\n"
 "	color: black;\n"
 "	margin-right: 20px;\n"
 "	margin-left: 20px;\n"
 "}\n"
-"TD.indexkey { \n"
-"   background-color: #eeeeff; \n"
-"   font-weight: bold; \n"
-"   padding-right  : 10px; \n"
-"   padding-top    : 2px; \n"
-"   padding-left   : 10px; \n"
-"   padding-bottom : 2px; \n"
-"   margin-left    : 0px; \n"
-"   margin-right   : 0px; \n"
-"   margin-top     : 2px; \n"
-"   margin-bottom  : 2px  \n"
+"TD.indexkey {\n"
+"	background-color: #eeeeff;\n"
+"	font-weight: bold;\n"
+"	padding-right  : 10px;\n"
+"	padding-top    : 2px;\n"
+"	padding-left   : 10px;\n"
+"	padding-bottom : 2px;\n"
+"	margin-left    : 0px;\n"
+"	margin-right   : 0px;\n"
+"	margin-top     : 2px;\n"
+"	margin-bottom  : 2px;\n"
+"	border: 1px solid #CCCCCC;\n"
 "}\n"
-"TD.indexvalue { \n"
-"   background-color: #eeeeff; \n"
-"   font-style: italic; \n"
-"   padding-right  : 10px; \n"
-"   padding-top    : 2px; \n"
-"   padding-left   : 10px; \n"
-"   padding-bottom : 2px; \n"
-"   margin-left    : 0px; \n"
-"   margin-right   : 0px; \n"
-"   margin-top     : 2px; \n"
-"   margin-bottom  : 2px  \n"
+"TD.indexvalue {\n"
+"	background-color: #eeeeff;\n"
+"	font-style: italic;\n"
+"	padding-right  : 10px;\n"
+"	padding-top    : 2px;\n"
+"	padding-left   : 10px;\n"
+"	padding-bottom : 2px;\n"
+"	margin-left    : 0px;\n"
+"	margin-right   : 0px;\n"
+"	margin-top     : 2px;\n"
+"	margin-bottom  : 2px;\n"
+"	border: 1px solid #CCCCCC;\n"
 "}\n"
 "TR.memlist {\n"
 "   background-color: #f0f0f0; \n"
@@ -128,16 +197,16 @@ static const char *defaultStyleSheet =
 "SPAN.charliteral   { color: #008080 }\n"
 ".mdTable {\n"
 "	border: 1px solid #868686;\n"
-"	background-color: #f2f2ff;\n"
+"	background-color: #F4F4FB;\n"
 "}\n"
 ".mdRow {\n"
-"	padding: 8px 20px;\n"
+"	padding: 8px 10px;\n"
 "}\n"
 ".mdescLeft {\n"
-"	font-size: smaller;\n"
-"	font-family: Arial, Helvetica, sans-serif;\n"
+"       padding: 0px 8px 4px 8px;\n"
+"	font-size: 80%;\n"
+"	font-style: italic;\n"
 "	background-color: #FAFAFA;\n"
-"	padding-left: 8px;\n"
 "	border-top: 1px none #E0E0E0;\n"
 "	border-right: 1px none #E0E0E0;\n"
 "	border-bottom: 1px none #E0E0E0;\n"
@@ -145,18 +214,15 @@ static const char *defaultStyleSheet =
 "	margin: 0px;\n"
 "}\n"
 ".mdescRight {\n"
-"	font-size: smaller;\n"
-"	font-family: Arial, Helvetica, sans-serif;\n"
+"       padding: 0px 8px 4px 8px;\n"
+"	font-size: 80%;\n"
 "	font-style: italic;\n"
 "	background-color: #FAFAFA;\n"
-"	padding-left: 4px;\n"
 "	border-top: 1px none #E0E0E0;\n"
 "	border-right: 1px none #E0E0E0;\n"
 "	border-bottom: 1px none #E0E0E0;\n"
 "	border-left: 1px none #E0E0E0;\n"
 "	margin: 0px;\n"
-"	padding-bottom: 0px;\n"
-"	padding-right: 8px;\n"
 "}\n"
 ".memItemLeft {\n"
 "	padding: 1px 0px 0px 8px;\n"
@@ -165,38 +231,91 @@ static const char *defaultStyleSheet =
 "	border-right-width: 1px;\n"
 "	border-bottom-width: 1px;\n"
 "	border-left-width: 1px;\n"
-"	border-top-style: solid;\n"
 "	border-top-color: #E0E0E0;\n"
 "	border-right-color: #E0E0E0;\n"
 "	border-bottom-color: #E0E0E0;\n"
 "	border-left-color: #E0E0E0;\n"
+"	border-top-style: solid;\n"
 "	border-right-style: none;\n"
 "	border-bottom-style: none;\n"
 "	border-left-style: none;\n"
 "	background-color: #FAFAFA;\n"
-"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
-"	font-size: 12px;\n"
+"	font-size: 80%;\n"
 "}\n"
 ".memItemRight {\n"
+"	padding: 1px 8px 0px 8px;\n"
+"	margin: 4px;\n"
+"	border-top-width: 1px;\n"
+"	border-right-width: 1px;\n"
+"	border-bottom-width: 1px;\n"
+"	border-left-width: 1px;\n"
+"	border-top-color: #E0E0E0;\n"
+"	border-right-color: #E0E0E0;\n"
+"	border-bottom-color: #E0E0E0;\n"
+"	border-left-color: #E0E0E0;\n"
+"	border-top-style: solid;\n"
+"	border-right-style: none;\n"
+"	border-bottom-style: none;\n"
+"	border-left-style: none;\n"
+"	background-color: #FAFAFA;\n"
+"	font-size: 80%;\n"
+"}\n"
+".memTemplItemLeft {\n"
 "	padding: 1px 0px 0px 8px;\n"
 "	margin: 4px;\n"
 "	border-top-width: 1px;\n"
 "	border-right-width: 1px;\n"
 "	border-bottom-width: 1px;\n"
 "	border-left-width: 1px;\n"
-"	border-top-style: solid;\n"
 "	border-top-color: #E0E0E0;\n"
 "	border-right-color: #E0E0E0;\n"
 "	border-bottom-color: #E0E0E0;\n"
 "	border-left-color: #E0E0E0;\n"
+"	border-top-style: none;\n"
 "	border-right-style: none;\n"
 "	border-bottom-style: none;\n"
 "	border-left-style: none;\n"
 "	background-color: #FAFAFA;\n"
-"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
-"	font-size: 13px;\n"
+"	font-size: 80%;\n"
 "}\n"
-".search     { color: #0000ee;\n"
+".memTemplItemRight {\n"
+"	padding: 1px 8px 0px 8px;\n"
+"	margin: 4px;\n"
+"	border-top-width: 1px;\n"
+"	border-right-width: 1px;\n"
+"	border-bottom-width: 1px;\n"
+"	border-left-width: 1px;\n"
+"	border-top-color: #E0E0E0;\n"
+"	border-right-color: #E0E0E0;\n"
+"	border-bottom-color: #E0E0E0;\n"
+"	border-left-color: #E0E0E0;\n"
+"	border-top-style: none;\n"
+"	border-right-style: none;\n"
+"	border-bottom-style: none;\n"
+"	border-left-style: none;\n"
+"	background-color: #FAFAFA;\n"
+"	font-size: 80%;\n"
+"}\n"
+".memTemplParams {\n"
+"	padding: 1px 0px 0px 8px;\n"
+"	margin: 4px;\n"
+"	border-top-width: 1px;\n"
+"	border-right-width: 1px;\n"
+"	border-bottom-width: 1px;\n"
+"	border-left-width: 1px;\n"
+"	border-top-color: #E0E0E0;\n"
+"	border-right-color: #E0E0E0;\n"
+"	border-bottom-color: #E0E0E0;\n"
+"	border-left-color: #E0E0E0;\n"
+"	border-top-style: solid;\n"
+"	border-right-style: none;\n"
+"	border-bottom-style: none;\n"
+"	border-left-style: none;\n"
+"       color: #606060;\n"
+"	background-color: #FAFAFA;\n"
+"	font-size: 80%;\n"
+"}\n"
+".search     { color: #003399;\n"
 "              font-weight: bold;\n"
 "}\n"
 "FORM.search {\n"
@@ -209,8 +328,27 @@ static const char *defaultStyleSheet =
 "               background-color: #eeeeff;\n"
 "}\n"
 "TD.tiny      { font-size: 75%;\n"
+"}\n"
+"a {\n"
+"	color: #252E78;\n"
+"}\n"
+"a:visited {\n"
+"	color: #3D2185;\n"
+"}\n"
+".dirtab { padding: 4px;\n"
+"          border-collapse: collapse;\n"
+"          border: 1px solid #b0b0b0;\n"
+"}\n"
+"TH.dirtab { background: #eeeeff;\n"
+"            font-weight: bold;\n"
+"}\n"
+"HR { height: 1px;\n"
+"     border: none;\n"
+"     border-top: 1px solid black;\n"
 "}\n";
 
+
+
 static QCString g_header;
 static QCString g_footer;
 
@@ -239,8 +377,17 @@ void HtmlGenerator::init()
     exit(1);
   }
   writeLogo(dname);
-  if (!Config_getString("HTML_HEADER").isEmpty()) g_header=fileToString(Config_getString("HTML_HEADER"));
-  if (!Config_getString("HTML_FOOTER").isEmpty()) g_footer=fileToString(Config_getString("HTML_FOOTER"));
+  if (!Config_getString("HTML_HEADER").isEmpty()) 
+  {
+    g_header=fileToString(Config_getString("HTML_HEADER"));
+    //printf("g_header='%s'\n",g_header.data());
+  }
+  if (!Config_getString("HTML_FOOTER").isEmpty()) 
+  {
+    g_footer=fileToString(Config_getString("HTML_FOOTER"));
+    //printf("g_footer='%s'\n",g_footer.data());
+  }
+  createSubDirs(d);
 }
 
 void HtmlGenerator::writeStyleSheetFile(QFile &file)
@@ -249,8 +396,15 @@ void HtmlGenerator::writeStyleSheetFile(QFile &file)
   t << defaultStyleSheet;
 }
 
-static void writeDefaultHeaderFile(QTextStream &t, const char *title)
+static void writeDefaultHeaderFile(QTextStream &t, const char *title,
+                                   const char *relPath,bool usePathCmd)
 {
+  QString relPathStr;
+  if (usePathCmd) 
+    relPathStr="$relpath$";
+  else
+    relPathStr=relPath;
+
   t << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n"
     "<html><head>" 
     "<meta http-equiv=\"Content-Type\" content=\"text/html;charset=" 
@@ -262,7 +416,7 @@ static void writeDefaultHeaderFile(QTextStream &t, const char *title)
   t << "href=\"";
   if (Config_getString("HTML_STYLESHEET").isEmpty())
   {
-    t << "doxygen.css";
+    t << relPathStr << "doxygen.css";
   }
   else
   {
@@ -272,7 +426,7 @@ static void writeDefaultHeaderFile(QTextStream &t, const char *title)
     {
       err("Error: user specified HTML style sheet file does not exist!\n");
     }
-    t << cssfi.fileName();
+    t << relPathStr << cssfi.fileName();
   }
   t << "\" rel=\"stylesheet\" type=\"text/css\">\n"
     "</head><body>\n";
@@ -285,7 +439,7 @@ void HtmlGenerator::writeHeaderFile(QFile &file)
 #if QT_VERSION >= 200
   t.setEncoding(QTextStream::Latin1);
 #endif
-  writeDefaultHeaderFile(t,"$title");
+  writeDefaultHeaderFile(t,"$title",relativePathToRoot(0),TRUE);
 }
 
 void HtmlGenerator::writeFooterFile(QFile &file)
@@ -293,9 +447,9 @@ void HtmlGenerator::writeFooterFile(QFile &file)
   QTextStream t(&file);
   t << "<hr size=\"1\"><address style=\"align: right;\"><small>\n";
   t << theTranslator->trGeneratedAt( "$datetime", "$projectname" );
-  t << " <a href=\"http://www.doxygen.org/index.html\">\n"
+  t << "&nbsp;<a href=\"http://www.doxygen.org/index.html\">"
     << "<img src=\"doxygen.png\" alt=\"doxygen\" " 
-    << "align=\"middle\" border=0>\n"
+    << "align=\"middle\" border=\"0\">"
     << "</a> $doxygenversion";
   t << "</small></address>\n"
     << "</body>\n"
@@ -309,6 +463,8 @@ void HtmlGenerator::startFile(const char *name,const char *,
   //printf("HtmlGenerator::startFile(%s)\n",name);
   QCString fileName=name;
   lastTitle=title;
+  relPath = relativePathToRoot(fileName);
+
   if (fileName.right(Doxygen::htmlFileExtension.length())!=Doxygen::htmlFileExtension) 
   {
     fileName+=Doxygen::htmlFileExtension;
@@ -329,11 +485,11 @@ void HtmlGenerator::startFile(const char *name,const char *,
   lastFile = fileName;
   if (g_header.isEmpty()) 
   {
-    writeDefaultHeaderFile(t,dispTitle);
+    writeDefaultHeaderFile(t,dispTitle,relPath,FALSE);
   }
   else
   {
-    t << substituteKeywords(g_header,convertToHtml(lastTitle));
+    t << substituteKeywords(g_header,convertToHtml(dispTitle),relPath);
   }
   t << "<!-- " << theTranslator->trGeneratedBy() << " Doxygen " 
     << versionString << " -->" << endl;
@@ -368,7 +524,8 @@ void HtmlGenerator::startFile(const char *name,const char *,
 //  t << "</a> &nbsp; ";
 //}
 
-static void writePageFooter(QTextStream &t,const QCString lastTitle)
+static void writePageFooter(QTextStream &t,const QCString &lastTitle,
+                            const QCString relPath)
 {
   if (g_footer.isEmpty())
   {
@@ -377,21 +534,31 @@ static void writePageFooter(QTextStream &t,const QCString lastTitle)
         dateToString(TRUE),
         Config_getString("PROJECT_NAME")
         );
-    t << endl << "<a href=\"http://www.doxygen.org/index.html\">";
-    t << endl << "<img src=\"doxygen.png\" alt=\"doxygen\" " 
-      << "align=\"middle\" border=0 > " << endl << 
-      "</a>" << versionString <<" ";
-    t << "</small></address>\n</body>\n</html>\n";
+    t << "&nbsp;" << endl << "<a href=\"http://www.doxygen.org/index.html\">";
+    t << endl << "<img src=\"" << relPath << "doxygen.png\" alt=\"doxygen\" " 
+      << "align=\"middle\" border=\"0\">" << "</a> " << versionString << " ";
+    t << "</small></address>";
+    if (Debug::isFlagSet(Debug::Validate))
+    {
+      t << "<p><a href=\"http://validator.w3.org/check/referer\">"
+           "<img border=\"0\" src=\"http://www.w3.org/Icons/valid-html401\""
+           " height=\"31\" width=\"88\" alt=\"This page is Valid HTML 4.01 "
+           "Transitional!\"></a><a href=\"http://jigsaw.w3.org/css-validator/\">"
+           "<img style=\"border:0;width:88px;height:31px\" "
+           "src=\"http://jigsaw.w3.org/css-validator/images/vcss\" "
+           "alt=\"This page uses valid CSS!\"></a></p>";
+    }
+    t << "\n</body>\n</html>\n";
   }
   else
   {
-    t << substituteKeywords(g_footer,convertToHtml(lastTitle));
+    t << substituteKeywords(g_footer,convertToHtml(lastTitle),relPath);
   }
 }
 
 void HtmlGenerator::writeFooter()
 {
-  writePageFooter(t,lastTitle);
+  writePageFooter(t,lastTitle,relPath);
 }
 
 void HtmlGenerator::endFile()
@@ -450,7 +617,7 @@ void HtmlGenerator::writeStyleInfo(int part)
 void HtmlGenerator::startDoxyAnchor(const char *,const char *,
                                     const char *anchor, const char *name)
 {
-  t << "<a class=\"anchor\" name=\"" << anchor << "\" doxytag=\"" << name << "\" ></a>";
+  t << "<a class=\"anchor\" name=\"" << anchor << "\" doxytag=\"" << name << "\"></a>";
 }
 
 void HtmlGenerator::endDoxyAnchor(const char *,const char *)
@@ -506,10 +673,6 @@ void HtmlGenerator::writeIndexItem(const char *ref,const char *f,
   {
     t << "</b>";
   }
-  //if (Config_getBool("GENERATE_HTMLHELP") && f)
-  //{
-  //  htmlHelp->addItem(name,((QCString)f)+htmlFileExtension);
-  //}
 }
 
 void HtmlGenerator::writeStartAnnoItem(const char *,const char *f,
@@ -520,10 +683,6 @@ void HtmlGenerator::writeStartAnnoItem(const char *,const char *f,
   t << "<a class=\"el\" href=\"" << f << Doxygen::htmlFileExtension << "\">";
   docify(name);
   t << "</a> ";
-  //if (Config_getBool("GENERATE_HTMLHELP") && f)
-  //{
-  //  htmlHelp->addItem(name, ((QCString)f)+htmlFileExtension);
-  //}
 }
 
 void HtmlGenerator::writeObjectLink(const char *ref,const char *f,
@@ -544,7 +703,11 @@ void HtmlGenerator::writeObjectLink(const char *ref,const char *f,
   t << "href=\"";
   if (ref)
   {
-    if ((dest=Doxygen::tagDestinationDict[ref])) t << *dest << "/";
+    if ((dest=Doxygen::tagDestinationDict[ref])) t << relPath << *dest << "/";
+  }
+  else
+  {
+    t << relPath;
   }
   if (f) t << f << Doxygen::htmlFileExtension;
   if (anchor) t << "#" << anchor;
@@ -571,7 +734,11 @@ void HtmlGenerator::writeCodeLink(const char *ref,const char *f,
   t << "href=\"";
   if (ref)
   {
-    if ((dest=Doxygen::tagDestinationDict[ref])) t << *dest << "/";
+    if ((dest=Doxygen::tagDestinationDict[ref])) t << relPath << *dest << "/";
+  }
+  else
+  {
+    t << relPath;
   }
   if (f) t << f << Doxygen::htmlFileExtension;
   if (anchor) t << "#" << anchor;
@@ -584,7 +751,7 @@ void HtmlGenerator::writeCodeLink(const char *ref,const char *f,
 void HtmlGenerator::startTextLink(const char *f,const char *anchor)
 {
   t << "<a href=\"";
-  if (f)   t << f << Doxygen::htmlFileExtension;
+  if (f)   t << relPath << f << Doxygen::htmlFileExtension;
   if (anchor) t << "#" << anchor;
   t << "\">"; 
 }
@@ -736,11 +903,11 @@ void HtmlGenerator::endClassDiagram(ClassDiagram &d,
                                 const char *fileName,const char *name)
 {
   t << "\n<p><center><img src=\""
-    << fileName << ".png\" usemap=\"#" << name << "_map\""
+    << relPath << fileName << ".png\" usemap=\"#" << name << "_map\""
     << " border=\"0\" alt=\"\"></center>" << endl
     << "<map name=\"" << name << "_map\">" << endl;
 
-  d.writeImage(t,dir,fileName);
+  d.writeImage(t,dir,relPath,fileName);
 }
 
 
@@ -780,9 +947,10 @@ void HtmlGenerator::startMemberItem(int annoType)
     t << "<tr>";
     switch(annoType)
     {
-      case 0:  t << "<td class=\"memItemLeft\" nowrap align=right valign=top>"; break;
+      case 0:  t << "<td class=\"memItemLeft\" nowrap align=\"right\" valign=\"top\">"; break;
       case 1:  t << "<td class=\"memItemLeft\" nowrap>"; break;
-      default: t << "<td class=\"memItemLeft\" nowrap valign=top>"; break;
+      case 2:  t << "<td class=\"memItemLeft\" nowrap valign=\"top\">"; break;
+      default: t << "<td class=\"memTemplParams\" nowrap colspan=\"2\">"; break;
     }
   }
   else
@@ -801,13 +969,27 @@ void HtmlGenerator::endMemberItem()
   t << endl; 
 }
 
+void HtmlGenerator::startMemberTemplateParams()
+{
+}
 
-void HtmlGenerator::insertMemberAlign() 
+void HtmlGenerator::endMemberTemplateParams()
+{
+  if (Config_getBool("HTML_ALIGN_MEMBERS"))
+  {
+    t << "</td></tr>" << endl;
+    t << "<tr><td class=\"memTemplItemLeft\" nowrap align=\"right\" valign=\"top\">";
+  }
+}
+
+
+void HtmlGenerator::insertMemberAlign(bool templ) 
 { 
   DBG_HTML(t << "<!-- insertMemberAlign -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "&nbsp;</td><td class=\"memItemRight\" valign=bottom>"; 
+    QCString className = templ ? "memTemplItemRight" : "memItemRight";
+    t << "&nbsp;</td><td class=\"" << className << "\" valign=\"bottom\">"; 
   }
 }
 
@@ -829,11 +1011,11 @@ void HtmlGenerator::endMemberDescription()
   DBG_HTML(t << "<!-- endMemberDescription -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "<br><br></td></tr>" << endl; 
+    t << "<br></td></tr>" << endl; 
   }
   else
   {
-    t << "<br><br></dl>";
+    t << "<br></dl>";
   }
 }
 
@@ -842,7 +1024,7 @@ void HtmlGenerator::startMemberSections()
   DBG_HTML(t << "<!-- startMemberSections -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "<table border=0 cellpadding=0 cellspacing=0>" << endl;
+    t << "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">" << endl;
     // HTML is not recursively decomposable, sorry
     t << "<tr><td></td></tr>" << endl;
   }
@@ -862,7 +1044,7 @@ void HtmlGenerator::startMemberHeader()
   DBG_HTML(t << "<!-- startMemberHeader -->" << endl)
   if (Config_getBool("HTML_ALIGN_MEMBERS"))
   {
-    t << "<tr><td colspan=2><br><h2>";
+    t << "<tr><td colspan=\"2\"><br><h2>";
   }
   else
   {
@@ -886,7 +1068,7 @@ void HtmlGenerator::endMemberHeader()
 void HtmlGenerator::startMemberSubtitle()
 {
   DBG_HTML(t << "<!-- startMemberSubtitle -->" << endl)
-  if (Config_getBool("HTML_ALIGN_MEMBERS")) t << "<tr><td colspan=2>";
+  if (Config_getBool("HTML_ALIGN_MEMBERS")) t << "<tr><td colspan=\"2\">";
 }
 
 void HtmlGenerator::endMemberSubtitle()
@@ -931,7 +1113,7 @@ void HtmlGenerator::startMemberDoc(const char *,const char *,const char *,const
 { 
   DBG_HTML(t << "<!-- startMemberDoc -->" << endl;)
   t << "<p>" << endl;
-  t << "<table class=\"mdTable\" width=\"100%\" cellpadding=\"2\" cellspacing=\"0\">" << endl;
+  t << "<table class=\"mdTable\" cellpadding=\"2\" cellspacing=\"0\">" << endl;
   t << "  <tr>" << endl;
   t << "    <td class=\"mdRow\">" << endl; 
   t << "      <table cellpadding=\"0\" cellspacing=\"0\" border=\"0\">" << endl;
@@ -941,7 +1123,7 @@ void HtmlGenerator::startMemberDocPrefixItem()
 {
   DBG_HTML(t << "<!-- startMemberDocPrefixItem -->" << endl;)
   t << "        <tr>" << endl;
-  t << "          <td class=\"md\" colspan=\"4\">" << endl; 
+  t << "          <td class=\"mdPrefix\" colspan=\"4\">" << endl; 
 }
 
 void HtmlGenerator::endMemberDocPrefixItem()
@@ -951,26 +1133,33 @@ void HtmlGenerator::endMemberDocPrefixItem()
   t << "        </tr>" << endl;
 }
 
-void HtmlGenerator::startMemberDocName()
+void HtmlGenerator::startMemberDocName(bool align)
 {
   DBG_HTML(t << "<!-- startMemberDocName -->" << endl;)
   t << "        <tr>" << endl;
-  t << "          <td class=\"md\" nowrap valign=\"top\"> ";
+  t << "          <td class=\"md\" nowrap valign=\"top\"";
+  if (align) t << " align=\"right\"";
+  t << ">";
 }
 
 void HtmlGenerator::endMemberDocName()
 {
   DBG_HTML(t << "<!-- endMemberDocName -->" << endl;)
+  t << "          </td>" << endl;
+}
+
+void HtmlGenerator::startParameterList(bool openBracket)
+{
+  DBG_HTML(t << "<!-- startParameterList -->" << endl;)
+  t << "          <td class=\"md\" valign=\"top\">";
+  if (openBracket)
+  {
+    t << "(&nbsp;";
+  }
   t << "</td>" << endl;
 }
 
-void HtmlGenerator::startParameterList()
-{
-  DBG_HTML(t << "<!-- startParameterList -->" << endl;)
-  t << "          <td class=\"md\" valign=\"top\">(&nbsp;</td>" << endl;
-}
-
-void HtmlGenerator::startParameterType(bool first)
+void HtmlGenerator::startParameterType(bool first,const char *key)
 {
   if (first)
   {
@@ -981,8 +1170,10 @@ void HtmlGenerator::startParameterType(bool first)
   {
     DBG_HTML(t << "<!-- startParameterType -->" << endl;)
     t << "        <tr>" << endl;
-    t << "          <td></td>" << endl;
-    t << "          <td></td>" << endl;
+    t << "          <td class=\"md\" nowrap align=\"right\">";
+    if (key) t << key;
+    t << "</td>" << endl;
+    t << "          <td class=\"md\"></td>" << endl;
     t << "          <td class=\"md\" nowrap>";
   }
 }
@@ -1004,7 +1195,7 @@ void HtmlGenerator::startParameterName(bool oneArgOnly)
   t << "\" nowrap>"; //&nbsp;";
 }
 
-void HtmlGenerator::endParameterName(bool last,bool emptyList)
+void HtmlGenerator::endParameterName(bool last,bool emptyList,bool closeBracket)
 {
   DBG_HTML(t << "<!-- endParameterName -->" << endl;)
   if (last)
@@ -1012,7 +1203,9 @@ void HtmlGenerator::endParameterName(bool last,bool emptyList)
     if (emptyList)
     {
       t << "          </td>" << endl;
-      t << "          <td class=\"md\" valign=\"top\">&nbsp;)&nbsp;</td>" << endl;
+      t << "          <td class=\"md\" valign=\"top\">";
+      if (closeBracket) t << "&nbsp;)";
+      t << "&nbsp;</td>" << endl;
       t << "          <td class=\"md\" nowrap>";
     }
     else
@@ -1020,8 +1213,10 @@ void HtmlGenerator::endParameterName(bool last,bool emptyList)
       t << "</td>" << endl;
       t << "        </tr>" << endl;
       t << "        <tr>" << endl;
-      t << "          <td></td>" << endl;
-      t << "          <td class=\"md\">)&nbsp;</td>" << endl;
+      t << "          <td class=\"md\"></td>" << endl;
+      t << "          <td class=\"md\">";
+      if (closeBracket) t << ")";
+      t << "&nbsp;</td>" << endl;
       t << "          <td class=\"md\" colspan=\"2\">";
     }
   }
@@ -1039,10 +1234,13 @@ void HtmlGenerator::endParameterList()
   t << "        </tr>" << endl;
 }
 
-void HtmlGenerator::endMemberDoc()     
+void HtmlGenerator::endMemberDoc(bool hasArgs)     
 { 
   DBG_HTML(t << "<!-- endMemberDoc -->" << endl;)
-  t << endl;
+  if (!hasArgs)
+  {
+    t << "        </tr>" << endl;
+  }
   t << "      </table>" << endl;
   t << "    </td>" << endl;
   t << "  </tr>" << endl;
@@ -1055,7 +1253,7 @@ void HtmlGenerator::startDotGraph()
 
 void HtmlGenerator::endDotGraph(DotClassGraph &g)
 {
-  g.writeGraph(t,BITMAP,Config_getString("HTML_OUTPUT"));
+  g.writeGraph(t,BITMAP,dir,relPath);
 }
 
 void HtmlGenerator::startInclDepGraph()
@@ -1064,21 +1262,41 @@ void HtmlGenerator::startInclDepGraph()
 
 void HtmlGenerator::endInclDepGraph(DotInclDepGraph &g)
 {
-  g.writeGraph(t,BITMAP,Config_getString("HTML_OUTPUT"));
+  g.writeGraph(t,BITMAP,dir,relPath);
 }
 
+
+void HtmlGenerator::startGroupCollaboration()
+{
+}
+
+void HtmlGenerator::endGroupCollaboration(DotGroupCollaboration &g)
+{
+  g.writeGraph(t,BITMAP,dir,relPath);
+}
+
+
 void HtmlGenerator::startCallGraph()
 {
 }
 
 void HtmlGenerator::endCallGraph(DotCallGraph &g)
 {
-  g.writeGraph(t,BITMAP,Config_getString("HTML_OUTPUT"));
+  g.writeGraph(t,BITMAP,dir,relPath);
+}
+
+void HtmlGenerator::startDirDepGraph()
+{
+}
+
+void HtmlGenerator::endDirDepGraph(DotDirDeps &g)
+{
+  g.writeGraph(t,BITMAP,dir,relPath);
 }
 
 void HtmlGenerator::writeGraphicalHierarchy(DotGfxHierarchyTable &g)
 {
-  g.writeGraph(t,Config_getString("HTML_OUTPUT"));
+  g.writeGraph(t,dir);
 }
 
 void HtmlGenerator::startMemberGroupHeader(bool)
@@ -1118,7 +1336,7 @@ void HtmlGenerator::startIndent()
   
   //t << "<div class=\"in\">" << endl; 
 
-  t << "<table cellspacing=5 cellpadding=0 border=0>\n"
+  t << "<table cellspacing=\"5\" cellpadding=\"0\" border=\"0\">\n"
        "  <tr>\n"
        "    <td>\n"
        "      &nbsp;\n"
@@ -1209,7 +1427,8 @@ void HtmlGenerator::printDoc(DocNode *n)
 }
 
 static void startQuickIndexItem(QTextStream &t,const char *l,
-                                bool hl,bool compact,bool &first)
+                                bool hl,bool compact,bool &first,
+                                const QCString &relPath)
 {
   if (!first && compact) t << " | ";
   first=FALSE;
@@ -1222,7 +1441,7 @@ static void startQuickIndexItem(QTextStream &t,const char *l,
   {
     t << "<a class=\"qindex\" ";
   }
-  t << "href=\"" << l << "\">";
+  t << "href=\"" << relPath << l << "\">";
 }
 
 static void endQuickIndexItem(QTextStream &t)
@@ -1235,7 +1454,8 @@ static QCString fixSpaces(const QCString &s)
   return substitute(s," ","&nbsp;");
 }
 
-static void writeDefaultQuickLinks(QTextStream &t,bool compact,HighlightedItem hli)
+static void writeDefaultQuickLinks(QTextStream &t,bool compact,
+                                   HighlightedItem hli,const QCString &relPath)
 {
   bool first=TRUE;
   if (compact) 
@@ -1249,18 +1469,19 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,HighlightedItem h
 
   if (Config_getBool("SEARCHENGINE"))
   {
-    t << "  <form class=\"search\" action=\"search.php\" method=\"get\">\n";
+    t << "  <form class=\"search\" action=\"" << relPath 
+      << "search.php\" method=\"get\">\n";
   }
 
   if (Config_getBool("GENERATE_TREEVIEW"))
   {
     startQuickIndexItem(t,"main"+Doxygen::htmlFileExtension,
-                        hli==HLI_Main,compact,first);
+                        hli==HLI_Main,compact,first,relPath);
   }
   else
   {
     startQuickIndexItem(t,"index"+Doxygen::htmlFileExtension,
-                        hli==HLI_Main,compact,first);
+                        hli==HLI_Main,compact,first,relPath);
   }
   t << fixSpaces(theTranslator->trMainPage());
   endQuickIndexItem(t);
@@ -1268,14 +1489,14 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,HighlightedItem h
   if (documentedGroups>0)
   {
     startQuickIndexItem(t,"modules"+Doxygen::htmlFileExtension,
-                        hli==HLI_Modules,compact,first);
+                        hli==HLI_Modules,compact,first,relPath);
     t << fixSpaces(theTranslator->trModules());
     endQuickIndexItem(t);
   } 
   if (documentedNamespaces>0)
   {
     startQuickIndexItem(t,"namespaces"+Doxygen::htmlFileExtension,
-                        hli==HLI_Namespaces,compact,first);
+                        hli==HLI_Namespaces,compact,first,relPath);
     if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
     {
       t << fixSpaces(theTranslator->trPackages());
@@ -1289,7 +1510,7 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,HighlightedItem h
   if (hierarchyClasses>0)
   {
     startQuickIndexItem(t,"hierarchy"+Doxygen::htmlFileExtension,
-                           hli==HLI_Hierarchy,compact,first);
+                           hli==HLI_Hierarchy,compact,first,relPath);
     t << fixSpaces(theTranslator->trClassHierarchy());
     endQuickIndexItem(t);
   } 
@@ -1298,54 +1519,61 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,HighlightedItem h
     if (Config_getBool("ALPHABETICAL_INDEX"))
     {
       startQuickIndexItem(t,"classes"+Doxygen::htmlFileExtension,
-                          hli==HLI_Classes,compact,first);
+                          hli==HLI_Classes,compact,first,relPath);
       t << fixSpaces(theTranslator->trAlphabeticalList());
       endQuickIndexItem(t);
     }
     startQuickIndexItem(t,"annotated"+Doxygen::htmlFileExtension,
-                        hli==HLI_Annotated,compact,first);
+                        hli==HLI_Annotated,compact,first,relPath);
     t << fixSpaces(theTranslator->trCompoundList());
     endQuickIndexItem(t);
   } 
+  if (Config_getBool("SHOW_DIRECTORIES") && documentedDirs>0)
+  {
+    startQuickIndexItem(t,"dirs"+Doxygen::htmlFileExtension,
+                        hli==HLI_Directories,compact,first,relPath);
+    t << fixSpaces(theTranslator->trDirectories());
+    endQuickIndexItem(t);
+  } 
   if (documentedHtmlFiles>0)
   {
     startQuickIndexItem(t,"files"+Doxygen::htmlFileExtension,
-                        hli==HLI_Files,compact,first);
+                        hli==HLI_Files,compact,first,relPath);
     t << fixSpaces(theTranslator->trFileList());
     endQuickIndexItem(t);
   } 
   if (documentedNamespaceMembers[NMHL_All]>0)
   {
     startQuickIndexItem(t,"namespacemembers"+Doxygen::htmlFileExtension,
-                        hli==HLI_NamespaceMembers,compact,first);
+                        hli==HLI_NamespaceMembers,compact,first,relPath);
     t << fixSpaces(theTranslator->trNamespaceMembers());
     endQuickIndexItem(t);
   }
   if (documentedClassMembers[CMHL_All]>0)
   {
     startQuickIndexItem(t,"functions"+Doxygen::htmlFileExtension,
-                        hli==HLI_Functions,compact,first);
+                        hli==HLI_Functions,compact,first,relPath);
     t << fixSpaces(theTranslator->trCompoundMembers());
     endQuickIndexItem(t);
   } 
   if (documentedFileMembers[FMHL_All]>0)
   {
     startQuickIndexItem(t,"globals"+Doxygen::htmlFileExtension,
-                        hli==HLI_Globals,compact,first);
+                        hli==HLI_Globals,compact,first,relPath);
     t << fixSpaces(theTranslator->trFileMembers());
     endQuickIndexItem(t);
   } 
   if (indexedPages>0)
   {
     startQuickIndexItem(t,"pages"+Doxygen::htmlFileExtension,
-                        hli==HLI_Pages,compact,first);
+                        hli==HLI_Pages,compact,first,relPath);
     t << fixSpaces(theTranslator->trRelatedPages());
     endQuickIndexItem(t);
   } 
   if (Doxygen::exampleSDict->count()>0)
   {
     startQuickIndexItem(t,"examples"+Doxygen::htmlFileExtension,
-                        hli==HLI_Examples,compact,first);
+                        hli==HLI_Examples,compact,first,relPath);
     t << fixSpaces(theTranslator->trExamples());
     endQuickIndexItem(t);
   } 
@@ -1385,7 +1613,7 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,HighlightedItem h
 
 void HtmlGenerator::writeQuickLinks(bool compact,HighlightedItem hli)
 {
-  writeDefaultQuickLinks(t,compact,hli);
+  writeDefaultQuickLinks(t,compact,hli,relPath);
 }
 
 void HtmlGenerator::writeSearchPage()
@@ -1397,19 +1625,25 @@ void HtmlGenerator::writeSearchPage()
     if (f.open(IO_WriteOnly))
     {
       QTextStream t(&f);
+#if QT_VERSION >= 200
+      t.setEncoding(QTextStream::Latin1);
+#endif
       if (g_header.isEmpty()) 
       {
-        writeDefaultHeaderFile(t,"Search");
+        writeDefaultHeaderFile(t,theTranslator->trSearch().data(),0,FALSE);
       }
       else
       {
-        t << substituteKeywords(g_header,"Search");
+        t << substituteKeywords(g_header,"Search","");
       }
       t << "<!-- " << theTranslator->trGeneratedBy() << " Doxygen " 
         << versionString << " -->" << endl;
-      writeDefaultQuickLinks(t,TRUE,HLI_Search);
+      if (!Config_getBool("DISABLE_INDEX")) 
+      { 
+        writeDefaultQuickLinks(t,TRUE,HLI_Search,"");
+      }
 
-      t << "<?php \n\n";
+      t << "\n<?php\n\n";
       t << "function search_results()\n";
       t << "{\n";
       t << "  return \"" << theTranslator->trSearchResultsTitle() << "\";\n";
@@ -1433,13 +1667,13 @@ void HtmlGenerator::writeSearchPage()
       t << "\n";
       t << "function report_matches()\n";
       t << "{\n";
-      t << " return \"" << theTranslator->trSearchMatches() << " \";\n";
+      t << "  return \"" << theTranslator->trSearchMatches() << " \";\n";
       t << "}\n";
       t << "\n";
       t << search_script;
       t << "\n";
       t << "?>\n";
-      writePageFooter(t,"Search");
+      writePageFooter(t,"Search","");
     }
   }
 }
