@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,6 +21,9 @@
 #include "qtbc.h"
 #include "outputgen.h"
 
+#define PREFRAG_START "<div class=\"fragment\"><pre class=\"fragment\">"
+#define PREFRAG_END   "</pre></div>"
+
 class QFile;
 
 class HtmlGenerator : public OutputGenerator
@@ -97,6 +100,8 @@ class HtmlGenerator : public OutputGenerator
     void endAnonTypeScope(int) {}
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams();
+    void endMemberTemplateParams();
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -105,15 +110,15 @@ class HtmlGenerator : public OutputGenerator
     void startMemberGroup();
     void endMemberGroup(bool);
 
-    void insertMemberAlign();
+    void insertMemberAlign(bool);
     void startMemberDescription();
     void endMemberDescription();
 
     void writeRuler()    { t << "<hr>"; }
     void writeAnchor(const char *,const char *name) 
                          { t << "<a name=\"" << name <<"\"></a>"; }
-    void startCodeFragment() { t << "<div class=\"fragment\"><pre>"; }
-    void endCodeFragment()   { t << "</pre></div>"; } 
+    void startCodeFragment() { t << PREFRAG_START; }
+    void endCodeFragment()   { t << PREFRAG_END; } 
     void writeLineNumber(const char *,const char *,const char *,int);
     void startCodeLine() { col=0; }
     void endCodeLine()   { codify("\n"); }
@@ -128,7 +133,7 @@ class HtmlGenerator : public OutputGenerator
     void lineBreak() { t << "<br>" << endl; }
     void writeChar(char c);
     void startMemberDoc(const char *,const char *,const char *,const char *);
-    void endMemberDoc(); 
+    void endMemberDoc(bool); 
     void startDoxyAnchor(const char *fName,const char *manName,
                          const char *anchor,const char *name);
     void endDoxyAnchor(const char *fName,const char *anchor);
@@ -169,11 +174,11 @@ class HtmlGenerator : public OutputGenerator
     void writeNonBreakableSpace(int);
     
     void startDescTable()
-    { t << "<table border=0 cellspacing=2 cellpadding=0>" << endl; }
+    { t << "<table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">" << endl; }
     void endDescTable()
     { t << "</table>" << endl; }
     void startDescTableTitle()
-    { t << "<tr><td valign=top><em>"; }
+    { t << "<tr><td valign=\"top\"><em>"; }
     void endDescTableTitle()
     { t << "</em>&nbsp;</td>"; }
     void startDescTableData()
@@ -185,23 +190,27 @@ class HtmlGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &g);
     void startInclDepGraph();
     void endInclDepGraph(DotInclDepGraph &g);
+    void startGroupCollaboration();
+    void endGroupCollaboration(DotGroupCollaboration &g);
     void startCallGraph();
     void endCallGraph(DotCallGraph &g);
+    void startDirDepGraph();
+    void endDirDepGraph(DotDirDeps &g);
     void writeGraphicalHierarchy(DotGfxHierarchyTable &g);
 
     void startTextBlock(bool) {}
-    void endTextBlock() {}
+    void endTextBlock(bool) {}
     void lastIndexPage() {}
 
     void startMemberDocPrefixItem();
     void endMemberDocPrefixItem();
-    void startMemberDocName();
+    void startMemberDocName(bool);
     void endMemberDocName();
-    void startParameterType(bool first);
+    void startParameterType(bool first,const char *key);
     void endParameterType();
     void startParameterName(bool);
-    void endParameterName(bool last,bool emptyList);
-    void startParameterList();
+    void endParameterName(bool last,bool emptyList,bool closeBracket);
+    void startParameterList(bool);
     void endParameterList();
 
     void startFontClass(const char *s) { t << "<span class=\"" << s << "\">"; }
@@ -214,6 +223,7 @@ class HtmlGenerator : public OutputGenerator
   private:
     QCString lastTitle;
     QCString lastFile;
+    QCString relPath;
 
     HtmlGenerator &operator=(const HtmlGenerator &g);
     HtmlGenerator(const HtmlGenerator &g);
