@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -15,7 +15,7 @@
  * input used in their production; they are not affected by this license.
  *
  */
-
+#include <qfileinfo.h> 
 #include "latexdocvisitor.h"
 #include "docparser.h"
 #include "language.h"
@@ -79,8 +79,10 @@ QString LatexDocVisitor::escapeMakeIndexChars(const char *s)
 }
 
 
-LatexDocVisitor::LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci) 
-  : DocVisitor(DocVisitor_Latex), m_t(t), m_ci(ci), m_insidePre(FALSE), m_insideItem(FALSE), m_hide(FALSE) 
+LatexDocVisitor::LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci,
+                                 bool insideTabbing) 
+  : DocVisitor(DocVisitor_Latex), m_t(t), m_ci(ci), m_insidePre(FALSE), 
+    m_insideItem(FALSE), m_hide(FALSE), m_insideTabbing(insideTabbing) 
 {
 }
 
@@ -249,15 +251,16 @@ void LatexDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::Code: 
       m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
       parseCode(m_ci,s->context(),s->text().latin1(),s->isExample(),s->exampleFile());
-      m_t << "\\end{verbatim}\\normalsize" << endl; 
+      m_t << "\\end{verbatim}\n\\normalsize" << endl; 
       break;
     case DocVerbatim::Verbatim: 
       m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
       m_t << s->text();
-      m_t << "\\end{verbatim}\\normalsize" << endl; 
+      m_t << "\\end{verbatim}\n\\normalsize" << endl; 
       break;
     case DocVerbatim::HtmlOnly: 
     case DocVerbatim::XmlOnly: 
+    case DocVerbatim::ManOnly: 
       /* nothing */ 
       break;
     case DocVerbatim::LatexOnly: 
@@ -294,7 +297,7 @@ void LatexDocVisitor::visit(DocVerbatim *s)
 void LatexDocVisitor::visit(DocAnchor *anc)
 {
   if (m_hide) return;
-  m_t << "\\label{" << anc->anchor() << "}" << endl;
+  m_t << "\\label{" << anc->file() << "_" << anc->anchor() << "}" << endl;
   if (!anc->file().isEmpty() && Config_getBool("PDF_HYPERLINKS")) 
   {
     m_t << "\\hypertarget{" << anc->file() << "_" << anc->anchor() 
@@ -307,10 +310,19 @@ void LatexDocVisitor::visit(DocInclude *inc)
   if (m_hide) return;
   switch(inc->type())
   {
+    case DocInclude::IncWithLines:
+      { 
+         m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
+         QFileInfo cfi( inc->file() );
+         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
+         m_t << "\\end{verbatim}\n\\normalsize" << endl; 
+      }
+      break;    
     case DocInclude::Include: 
       m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
       parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile());
-      m_t << "\\end{verbatim}\\normalsize" << endl; 
+      m_t << "\\end{verbatim}\n\\normalsize" << endl; 
       break;
     case DocInclude::DontInclude: 
       break;
@@ -319,7 +331,7 @@ void LatexDocVisitor::visit(DocInclude *inc)
     case DocInclude::VerbInclude: 
       m_t << "\n\n\\footnotesize\\begin{verbatim}"; 
       m_t << inc->text();
-      m_t << "\\end{verbatim}\\normalsize" << endl; 
+      m_t << "\\end{verbatim}\n\\normalsize" << endl; 
       break;
   }
 }
@@ -344,7 +356,7 @@ void LatexDocVisitor::visit(DocIncOperator *op)
   if (op->isLast())  
   {
     popEnabled();
-    if (!m_hide) m_t << "\\end{verbatim}\\normalsize" << endl; 
+    if (!m_hide) m_t << "\\end{verbatim}\n\\normalsize" << endl; 
   }
   else
   {
@@ -526,7 +538,7 @@ void LatexDocVisitor::visitPre(DocSection *s)
   }
   m_t << "\\" << getSectionName(s->level()) << "{";
   filter(s->title());
-  m_t << "}\\label{" << s->anchor() << "}" << endl;
+  m_t << "}\\label{" << s->file() << "_" << s->anchor() << "}" << endl;
 }
 
 void LatexDocVisitor::visitPost(DocSection *) 
@@ -810,7 +822,7 @@ void LatexDocVisitor::visitPre(DocSecRefItem *)
 void LatexDocVisitor::visitPost(DocSecRefItem *ref) 
 {
   if (m_hide) return;
-  m_t << "}{\\ref{" << ref->anchor() << "}}{}" << endl;
+  m_t << "}{\\ref{" << ref->file() << "_" << ref->anchor() << "}}{}" << endl;
 }
 
 void LatexDocVisitor::visitPre(DocSecRefList *)
@@ -829,24 +841,24 @@ void LatexDocVisitor::visitPost(DocSecRefList *)
   m_t << "\\normalsize" << endl;
 }
 
-void LatexDocVisitor::visitPre(DocLanguage *l)
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    pushEnabled();
-    m_hide = TRUE;
-  }
-}
-
-void LatexDocVisitor::visitPost(DocLanguage *l) 
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    popEnabled();
-  }
-}
+//void LatexDocVisitor::visitPre(DocLanguage *l)
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    pushEnabled();
+//    m_hide = TRUE;
+//  }
+//}
+//
+//void LatexDocVisitor::visitPost(DocLanguage *l) 
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    popEnabled();
+//  }
+//}
 
 void LatexDocVisitor::visitPre(DocParamSect *s)
 {
@@ -878,7 +890,25 @@ void LatexDocVisitor::visitPost(DocParamSect *)
 void LatexDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
-  m_t << "\\item[{\\em ";
+  m_t << "\\item[";
+  if (pl->direction()!=DocParamSect::Unspecified)
+  {
+    m_t << "\\mbox{";
+    if (pl->direction()==DocParamSect::In)
+    {
+      m_t << "$\\leftarrow$";
+    }
+    else if (pl->direction()==DocParamSect::Out)
+    {
+      m_t << "$\\rightarrow$";
+    }
+    else if (pl->direction()==DocParamSect::InOut)
+    {
+      m_t << "$\\leftrightarrow$";
+    }
+    m_t << "} ";
+  }
+  m_t << "{\\em ";
   QStrListIterator li(pl->parameters());
   const char *s;
   bool first=TRUE;
@@ -900,10 +930,11 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
   m_t << "\\begin{Desc}" << endl;
+  bool anonymousEnum = x->file()=="@";
   m_t << "\\item[";
-  if (Config_getBool("PDF_HYPERLINKS"))
+  if (Config_getBool("PDF_HYPERLINKS") && !anonymousEnum)
   {
-    m_t << "\\hyperlink{" << x->file() << "_" << x->anchor() << "}{";
+    m_t << "\\hyperlink{" << stripPath(x->file()) << "_" << x->anchor() << "}{";
   }
   else
   {
@@ -951,7 +982,7 @@ void LatexDocVisitor::visitPost(DocText *)
 
 void LatexDocVisitor::filter(const char *str)
 { 
-  filterLatexString(m_t,str,FALSE,m_insidePre,m_insideItem);
+  filterLatexString(m_t,str,m_insideTabbing,m_insidePre,m_insideItem);
 }
 
 void LatexDocVisitor::startLink(const QString &ref,const QString &file,const QString &anchor)
@@ -959,7 +990,7 @@ void LatexDocVisitor::startLink(const QString &ref,const QString &file,const QSt
   if (ref.isEmpty() && Config_getBool("PDF_HYPERLINKS"))
   {
     m_t << "\\hyperlink{";
-    if (!file.isEmpty()) m_t << file;
+    if (!file.isEmpty()) m_t << stripPath(file);
     if (!file.isEmpty() && !anchor.isEmpty()) m_t << "_";
     if (!anchor.isEmpty()) m_t << anchor;
     m_t << "}{";
@@ -976,7 +1007,8 @@ void LatexDocVisitor::endLink(const QString &ref,const QString &file,const QStri
   m_t << "}";
   if (ref.isEmpty() && !Config_getBool("PDF_HYPERLINKS"))
   {
-    m_t << "{\\rm ("; filter(theTranslator->trPageAbbreviation());
+    m_t << "{\\rm ("; 
+    filter(theTranslator->trPageAbbreviation());
     m_t << "\\,\\pageref{" << file;
     if (!anchor.isEmpty()) m_t << "_" << anchor;
     m_t << "})}";
