@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -25,6 +25,7 @@
 #include "dot.h"
 #include "util.h"
 #include "message.h"
+#include <qfileinfo.h> 
 
 ManDocVisitor::ManDocVisitor(QTextStream &t,BaseCodeDocInterface &ci) 
   : DocVisitor(DocVisitor_Man), m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE), m_firstCol(TRUE),
@@ -166,6 +167,7 @@ void ManDocVisitor::visit(DocStyleChange *s)
       {
         m_insidePre=FALSE;
         if (!m_firstCol) m_t << endl;
+        m_t << ".fi" << endl;
         m_t << ".PP" << endl;
         m_firstCol=TRUE;
       }
@@ -186,6 +188,7 @@ void ManDocVisitor::visit(DocVerbatim *s)
       m_t << ".nf" << endl;
       parseCode(m_ci,s->context(),s->text().latin1(),s->isExample(),s->exampleFile());
       if (!m_firstCol) m_t << endl;
+      m_t << ".fi" << endl;
       m_t << ".PP" << endl;
       m_firstCol=TRUE;
       break;
@@ -195,9 +198,13 @@ void ManDocVisitor::visit(DocVerbatim *s)
       m_t << ".nf" << endl;
       m_t << s->text();
       if (!m_firstCol) m_t << endl;
+      m_t << ".fi" << endl;
       m_t << ".PP" << endl;
       m_firstCol=TRUE;
       break;
+    case DocVerbatim::ManOnly: 
+      m_t << s->text(); 
+      break;
     case DocVerbatim::HtmlOnly: 
     case DocVerbatim::XmlOnly: 
     case DocVerbatim::LatexOnly: 
@@ -217,12 +224,27 @@ void ManDocVisitor::visit(DocInclude *inc)
   if (m_hide) return;
   switch(inc->type())
   {
+    case DocInclude::IncWithLines:
+      { 
+         if (!m_firstCol) m_t << endl;
+         m_t << ".PP" << endl;
+         m_t << ".nf" << endl;
+         QFileInfo cfi( inc->file() );
+         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
+         if (!m_firstCol) m_t << endl;
+         m_t << ".fi" << endl;
+         m_t << ".PP" << endl;
+         m_firstCol=TRUE;
+      }
+      break;
     case DocInclude::Include: 
       if (!m_firstCol) m_t << endl;
       m_t << ".PP" << endl;
       m_t << ".nf" << endl;
       parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile());
       if (!m_firstCol) m_t << endl;
+      m_t << ".fi" << endl;
       m_t << ".PP" << endl;
       m_firstCol=TRUE;
       break;
@@ -236,6 +258,7 @@ void ManDocVisitor::visit(DocInclude *inc)
       m_t << ".nf" << endl;
       m_t << inc->text();
       if (!m_firstCol) m_t << endl;
+      m_t << ".fi" << endl;
       m_t << ".PP" << endl;
       m_firstCol=TRUE;
       break;
@@ -270,6 +293,7 @@ void ManDocVisitor::visit(DocIncOperator *op)
     if (!m_hide)
     {
       if (!m_firstCol) m_t << endl;
+      m_t << ".fi" << endl;
       m_t << ".PP" << endl;
       m_firstCol=TRUE;
     }
@@ -436,6 +460,8 @@ void ManDocVisitor::visitPre(DocSimpleList *)
 {
   if (m_hide) return;
   m_indent+=2;
+  if (!m_firstCol) m_t << endl;
+  m_t << ".PD 0" << endl;
 }
 
 void ManDocVisitor::visitPost(DocSimpleList *)
@@ -482,12 +508,15 @@ void ManDocVisitor::visitPre(DocHtmlList *)
 {
   if (m_hide) return;
   m_indent+=2;
+  if (!m_firstCol) m_t << endl;
+  m_t << ".PD 0" << endl;
 }
 
 void ManDocVisitor::visitPost(DocHtmlList *) 
 {
   if (m_hide) return;
   m_indent-=2;
+  if (!m_firstCol) m_t << endl;
   m_t << ".PP" << endl;
 }
 
@@ -529,6 +558,7 @@ void ManDocVisitor::visitPost(DocHtmlListItem *)
 //{
 //  m_insidePre=FALSE;
 //  if (!m_firstCol) m_t << endl;
+//  m_t << ".fi" << endl;
 //  m_t << ".PP" << endl;
 //  m_firstCol=TRUE;
 //}
@@ -714,27 +744,28 @@ void ManDocVisitor::visitPost(DocSecRefList *)
 {
   if (m_hide) return;
   m_indent-=2;
+  if (!m_firstCol) m_t << endl;
   m_t << ".PP" << endl;
 }
 
-void ManDocVisitor::visitPre(DocLanguage *l)
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    pushEnabled();
-    m_hide = TRUE;
-  }
-}
-
-void ManDocVisitor::visitPost(DocLanguage *l) 
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    popEnabled();
-  }
-}
+//void ManDocVisitor::visitPre(DocLanguage *l)
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    pushEnabled();
+//    m_hide = TRUE;
+//  }
+//}
+//
+//void ManDocVisitor::visitPost(DocLanguage *l) 
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    popEnabled();
+//  }
+//}
 
 void ManDocVisitor::visitPre(DocParamSect *s)
 {
