@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.15 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -93,7 +93,7 @@ class ManGenerator : public OutputGenerator
     void endMemberSections() {}
     void startMemberHeader();
     void endMemberHeader();
-    void insertMemberAlign() {}
+    void insertMemberAlign(bool) {}
     void startMemberSubtitle() {}
     void endMemberSubtitle() {}
     void writeListItem();
@@ -103,6 +103,8 @@ class ManGenerator : public OutputGenerator
     void endAnonTypeScope(int);
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams() {}
+    void endMemberTemplateParams() {}
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -135,7 +137,7 @@ class ManGenerator : public OutputGenerator
     void lineBreak() { t << "\n.br" << endl; }
     void writeChar(char c);
     void startMemberDoc(const char *,const char *,const char *,const char *);
-    void endMemberDoc();
+    void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *) {}
     void startCodeAnchor(const char *) {}
@@ -227,12 +229,16 @@ class ManGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &) {}
     void startInclDepGraph() {}
     void endInclDepGraph(DotInclDepGraph &) {}
+    void startGroupCollaboration() {}
+    void endGroupCollaboration(DotGroupCollaboration &) {}
     void startCallGraph() {}
     void endCallGraph(DotCallGraph &) {}
+    void startDirDepGraph() {} 
+    void endDirDepGraph(DotDirDeps &) {}
     void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
 
     void startTextBlock(bool) {}
-    void endTextBlock() {}
+    void endTextBlock(bool) {}
     void lastIndexPage() {}
 
     void startMemberDocPrefixItem() {}
@@ -242,7 +248,7 @@ class ManGenerator : public OutputGenerator
     void startParameterType(bool,const char *) {}
     void endParameterType() {}
     void startParameterName(bool) {}
-    void endParameterName(bool,bool) {}
+    void endParameterName(bool,bool,bool) {}
     void startParameterList(bool) {}
     void endParameterList() {}
 
