@@ -2,7 +2,7 @@
  *
  * $Id: membergroup.cpp,v 1.19 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -81,7 +81,9 @@ void MemberGroup::insertMember(MemberDef *md)
   GroupDef *gd;
   if (firstMd && (gd=firstMd->getGroupDef()))
   {
-    md->setGroupDef(gd, firstMd->getGroupPri(), firstMd->getGroupFileName(), firstMd->getGroupStartLine(), firstMd->getGroupHasDocs());
+    md->setGroupDef(gd, firstMd->getGroupPri(), 
+                    firstMd->getGroupFileName(), firstMd->getGroupStartLine(), 
+                    firstMd->getGroupHasDocs());
     gd->insertMember(md);
   }
 }
@@ -138,17 +140,22 @@ void MemberGroup::distributeMemberGroupDocumentation()
 {
   //printf("MemberGroup::distributeMemberGroupDocumentation() %s\n",grpHeader.data());
   MemberDef *md=memberList->first();
-  if (md && !(md->documentation().isEmpty() && md->briefDescription().isEmpty()))
+  if (md && !(md->documentation().isEmpty() && 
+              md->briefDescription().isEmpty() && 
+              md->inbodyDocumentation().isEmpty()
+             )
+     )
   {
     //printf("First member %s has documentation!\n",md->name().data());
     MemberDef *omd=memberList->next();
     while (omd)
     {
-      if (omd->documentation().isEmpty() && omd->briefDescription().isEmpty())
+      if (omd->documentation().isEmpty() && omd->briefDescription().isEmpty() && omd->inbodyDocumentation().isEmpty())
       {
         //printf("Copying documentation to member %s\n",omd->name().data());
         omd->setBriefDescription(md->briefDescription(),md->briefFile(),md->briefLine());
         omd->setDocumentation(md->documentation(),md->docFile(),md->docLine());
+        omd->setInbodyDocumentation(md->inbodyDocumentation(),md->inbodyFile(),md->inbodyLine());
       }
       omd=memberList->next();
     }
