@@ -2,7 +2,7 @@
  *
  * $Id: memberlist.cpp,v 1.35 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -76,7 +76,8 @@ void MemberList::countDecMembers()
                                        m_funcCnt++,m_numDecMembers++; 
                                      break;
         case MemberDef::Enumeration: m_enumCnt++,m_numDecMembers++; break;
-        case MemberDef::EnumValue:   m_enumValCnt++,m_numDecMembers++; break;
+        case MemberDef::EnumValue:   //m_enumValCnt++,m_numDecMembers++; 
+                                     break;
         case MemberDef::Typedef:     m_typeCnt++,m_numDecMembers++; break;
         case MemberDef::Prototype:   m_protoCnt++,m_numDecMembers++; break;
         case MemberDef::Define:      if (Config_getBool("EXTRACT_ALL") || 
@@ -92,7 +93,7 @@ void MemberList::countDecMembers()
       }
     }
   }
-  if (memberGroupList /*&& countSubGroups*/)
+  if (memberGroupList)
   {
     MemberGroupListIterator mgli(*memberGroupList);
     MemberGroup *mg;
@@ -227,7 +228,6 @@ void MemberList::writePlainDeclarations(OutputList &ol,
               ol.startMemberItem(0);
               ol.writeString("enum ");
               ol.insertMemberAlign();
-              //ol+=typeDecl; // append the enum values.
               md->writeEnumDeclaration(ol,cd,nd,fd,gd);
               ol.endMemberItem();
               if (!md->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
@@ -243,20 +243,11 @@ void MemberList::writePlainDeclarations(OutputList &ol,
                 if (md->isDetailedSectionLinkable())
                 {
                   ol.disableAllBut(OutputGenerator::Html);
-                  //ol.endEmphasis();
                   ol.docify(" ");
-                  if (md->getGroupDef()!=0 && gd==0) // forward link to group
-                  {
-                    ol.startTextLink(md->getOutputFileBase(),
-                                     md->anchor());
-                  }
-                  else
-                  {
-                    ol.startTextLink(0,md->anchor());
-                  }
+                  ol.startTextLink(md->getOutputFileBase(),
+                                   md->anchor());
                   ol.parseText(theTranslator->trMore());
                   ol.endTextLink();
-                  //ol.startEmphasis();
                   ol.enableAll();
                 }
                 ol.endMemberDescription();
@@ -286,14 +277,14 @@ void MemberList::writePlainDeclarations(OutputList &ol,
     {
       if (md->fromAnonymousScope() && !md->anonymousDeclShown())
       {
+        md->setFromAnonymousScope(FALSE);
         //printf("anonymous compound members\n");
         if (md->isBriefSectionVisible())
         {
           if (first) ol.startMemberList(),first=FALSE;
-          md->setFromAnonymousScope(FALSE);
           md->writeDeclaration(ol,cd,nd,fd,gd,m_inGroup);
-          md->setFromAnonymousScope(TRUE);
         }
+        md->setFromAnonymousScope(TRUE);
       }
     }
   }
@@ -309,10 +300,10 @@ void MemberList::writeDeclarations(OutputList &ol,
              const char *title,const char *subtitle
              /*, bool inGroup,bool countSubGroups*/)
 {
-  //printf("MemberList::writeDeclaration(title=`%s',subtitle=`%s')\n",title,subtitle);
   //printf("----- writeDeclaration() ----\n");
   countDecMembers(); // count member not in group
   if (numDecMembers()==0) return;
+  //printf("MemberList::writeDeclaration(title=`%s',subtitle=`%s')=%d\n",title,subtitle,numDecMembers());
   if (title) 
   {
     ol.startMemberHeader();
@@ -323,7 +314,7 @@ void MemberList::writeDeclarations(OutputList &ol,
   {
     //printf("subtitle=`%s'\n",subtitle);
     ol.startMemberSubtitle();
-    ol.parseDoc("<generated>",1,0,0,subtitle,FALSE,FALSE);
+    ol.parseDoc("<generated>",-1,0,0,subtitle,FALSE,FALSE);
     ol.endMemberSubtitle();
   }
 
@@ -347,7 +338,7 @@ void MemberList::writeDeclarations(OutputList &ol,
       {
         //printf("Member group has docs!\n");
         ol.startMemberGroupDocs();
-        ol.parseDoc("<generated>",1,0,0,mg->documentation()+"\n",FALSE,FALSE);
+        ol.parseDoc("<generated>",-1,0,0,mg->documentation()+"\n",FALSE,FALSE);
         ol.endMemberGroupDocs();
       }
       ol.startMemberGroup();
