@@ -2,7 +2,7 @@
  *
  * $Id: namespacedef.cpp,v 1.27 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,11 +29,19 @@
 #include "searchindex.h"
 
 NamespaceDef::NamespaceDef(const char *df,int dl,
-                           const char *name,const char *lref) : 
+                           const char *name,const char *lref,
+                           const char *fName) : 
    Definition(df,dl,name)
 {
-  fileName="namespace";
-  fileName+=name;
+  if (fName)
+  {
+    fileName = stripExtension(fName);
+  }
+  else
+  {
+    fileName="namespace";
+    fileName+=name;
+  }
   classSDict = new ClassSDict(17);
   namespaceSDict = new NamespaceSDict(17);
   m_innerCompounds = new SDict<Definition>(17);
@@ -42,6 +50,7 @@ NamespaceDef::NamespaceDef(const char *df,int dl,
   setReference(lref);
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
+  visited=FALSE;
 }
 
 NamespaceDef::~NamespaceDef()
@@ -109,7 +118,7 @@ void NamespaceDef::insertClass(ClassDef *cd)
 {
   if (classSDict->find(cd->name())==0)
   {
-    if (Config_getBool("SORT_MEMBER_DOCS"))
+    if (Config_getBool("SORT_BRIEF_DOCS"))
       classSDict->inSort(cd->name(),cd);
     else
       classSDict->append(cd->name(),cd);
@@ -145,28 +154,40 @@ void NamespaceDef::insertMember(MemberDef *md)
   switch(md->memberType())
   {
     case MemberDef::Variable:     
-      decVarMembers.append(md);
+      if (Config_getBool("SORT_BRIEF_DOCS"))
+        decVarMembers.inSort(md);
+      else
+        decVarMembers.append(md);
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docVarMembers.inSort(md); 
       else
         docVarMembers.append(md);
       break;
     case MemberDef::Function: 
-      decFuncMembers.append(md);
+      if (Config_getBool("SORT_BRIEF_DOCS"))
+        decFuncMembers.inSort(md);
+      else
+        decFuncMembers.append(md);
       if (Config_getBool("SORT_MEMBER_DOCS"))    
         docFuncMembers.inSort(md); 
       else
         docFuncMembers.append(md);
       break;
     case MemberDef::Typedef:      
-      decTypedefMembers.append(md);
+      if (Config_getBool("SORT_BRIEF_DOCS"))
+        decTypedefMembers.inSort(md);
+      else
+        decTypedefMembers.append(md);
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docTypedefMembers.inSort(md); 
       else
         docTypedefMembers.append(md);
       break;
     case MemberDef::Enumeration:  
-      decEnumMembers.append(md);
+      if (Config_getBool("SORT_BRIEF_DOCS"))
+        decEnumMembers.inSort(md);
+      else
+        decEnumMembers.append(md);
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docEnumMembers.inSort(md); 
       else
@@ -175,14 +196,20 @@ void NamespaceDef::insertMember(MemberDef *md)
     case MemberDef::EnumValue:    
       break;
     case MemberDef::Prototype:    
-      decProtoMembers.append(md);
+      if (Config_getBool("SORT_BRIEF_DOCS"))
+        decProtoMembers.inSort(md);
+      else
+        decProtoMembers.append(md);
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docProtoMembers.inSort(md); 
       else
         docProtoMembers.append(md);
       break;
     case MemberDef::Define:       
-      decDefineMembers.append(md);
+      if (Config_getBool("SORT_BRIEF_DOCS"))
+        decDefineMembers.inSort(md);
+      else
+        decDefineMembers.append(md);
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docDefineMembers.inSort(md); 
       else
@@ -246,25 +273,29 @@ void NamespaceDef::writeDetailedDocumentation(OutputList &ol)
   
 void NamespaceDef::writeDocumentation(OutputList &ol)
 {
-  QCString pageTitle=displayName()+" Namespace Reference";
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
-  startTitle(ol,getOutputFileBase());
-  //ol.docify(pageTitle);
+  QCString pageTitle;
   if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
   {
-    ol.parseText(theTranslator->trPackage(displayName()));
+    pageTitle = theTranslator->trPackage(displayName());
   }
   else
   {
-    ol.parseText(theTranslator->trNamespaceReference(displayName()));
+    pageTitle = theTranslator->trNamespaceReference(displayName());
   }
+  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  if (getOuterScope()!=Doxygen::globalScope)
+  {
+    writeNavigationPath(ol);
+  }
+  startTitle(ol,getOutputFileBase());
+  ol.parseText(pageTitle);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),displayName());
   
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
@@ -290,6 +321,9 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
     ol.startTextLink(0,"_details");
     ol.parseText(theTranslator->trMore());
     ol.endTextLink();
+    ol.enableAll();
+    ol.disableAllBut(OutputGenerator::Man);
+    ol.newParagraph();
     ol.popGeneratorState();
   }
   ol.disable(OutputGenerator::Man);
@@ -300,7 +334,9 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
   ol.endTextBlock();
   
   ol.startMemberSections();
-  classSDict->writeDeclaration(ol);
+  classSDict->writeDeclaration(ol,0,0,TRUE);
+
+  namespaceSDict->writeDeclaration(ol,TRUE);
 
   /* write user defined member groups */
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
@@ -378,21 +414,28 @@ void NamespaceDef::addUsingDirective(NamespaceDef *nd)
   }
 }
 
-void NamespaceDef::addUsingDeclaration(ClassDef *cd)
+void NamespaceDef::addUsingDeclaration(Definition *d)
 {
   if (usingDeclList==0)
   {
-    usingDeclList = new ClassSDict;
+    usingDeclList = new SDict<Definition>(17);
   }
-  if (usingDeclList->find(cd->qualifiedName())==0)
+  if (usingDeclList->find(d->qualifiedName())==0)
   {
-    usingDeclList->append(cd->qualifiedName(),cd);
+    usingDeclList->append(d->qualifiedName(),d);
   }
 }
 
 QCString NamespaceDef::getOutputFileBase() const 
 { 
-  return convertNameToFile(fileName); 
+  if (isReference())
+  {
+    return fileName;
+  }
+  else
+  {
+    return convertNameToFile(fileName); 
+  }
 }
 
 Definition *NamespaceDef::findInnerCompound(const char *n)
@@ -459,8 +502,8 @@ void NamespaceDef::combineUsingRelations()
       // add used classes of namespace nd to this namespace
       if (nd->getUsedClasses())
       {
-        ClassSDict::Iterator cli(*nd->getUsedClasses());
-        ClassDef *ucd;
+        SDict<Definition>::Iterator cli(*nd->getUsedClasses());
+        Definition *ucd;
         for (cli.toFirst();(ucd=cli.current());++cli)
         {
           //printf("Adding class %s to the using list of %s\n",cd->qualifiedName().data(),qualifiedName().data());
@@ -471,3 +514,59 @@ void NamespaceDef::combineUsingRelations()
   }
 }
 
+void NamespaceSDict::writeDeclaration(OutputList &ol,bool localName)
+{
+  if (count()==0) return;
+  // write list of namespaces
+  ol.startMemberHeader();
+  bool javaOpt = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
+  if (javaOpt)
+  {
+    ol.parseText(theTranslator->trPackages());
+  }
+  else
+  {
+    ol.parseText(theTranslator->trNamespaces());
+  }
+  ol.endMemberHeader();
+  ol.startMemberList();
+  SDict<NamespaceDef>::Iterator ni(*this);
+  NamespaceDef *nd;
+  for (ni.toFirst();(nd=ni.current());++ni)
+  {
+    ol.startMemberItem(0);
+    if (javaOpt)
+    {
+      ol.docify("package ");
+    }
+    else
+    {
+      ol.docify("namespace ");
+    }
+    ol.insertMemberAlign();
+    QCString name;
+    if (localName)
+    {
+      name = nd->localName();
+    }
+    else
+    {
+      name = nd->displayName();
+    }
+    ol.writeObjectLink(nd->getReference(),nd->getOutputFileBase(),0,name);
+    if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+    {
+      Doxygen::tagFile << "    <namespace>" << convertToXML(nd->name()) << "</namespace>" << endl;
+    }
+    ol.endMemberItem();
+    if (!nd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
+    {
+      ol.startMemberDescription();
+      ol.parseDoc(nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE);
+      ol.endMemberDescription();
+      ol.newParagraph();
+    }
+  }
+  ol.endMemberList();
+}
+
