@@ -2,7 +2,7 @@
  *
  * $Id: namespacedef.h,v 1.18 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -38,7 +38,8 @@ class NamespaceDef : public Definition
 {
   public:
     NamespaceDef(const char *defFileName,int defLine,
-                 const char *name,const char *ref=0);
+                 const char *name,const char *ref=0,
+                 const char *refFile=0);
    ~NamespaceDef();
     DefType definitionType() { return TypeNamespace; }
     QCString getOutputFileBase() const;
@@ -55,8 +56,8 @@ class NamespaceDef : public Definition
     int countMembers();
     void addUsingDirective(NamespaceDef *nd);
     NamespaceSDict *getUsedNamespaces() const { return usingDirList; }
-    void addUsingDeclaration(ClassDef *cd);
-    ClassSDict *getUsedClasses() const { return usingDeclList; }
+    void addUsingDeclaration(Definition *def);
+    SDict<Definition> *getUsedClasses() const { return usingDeclList; }
     void combineUsingRelations();
     QCString displayName() const;
     
@@ -118,7 +119,7 @@ class NamespaceDef : public Definition
 
 
     NamespaceSDict *usingDirList;
-    ClassSDict *usingDeclList;
+    SDict<Definition> *usingDeclList;
     SDict<Definition> *m_innerCompounds;
 
     MemberList allMemberList;
@@ -162,6 +163,7 @@ class NamespaceSDict : public SDict<NamespaceDef>
                     ((NamespaceDef *)item2)->name()
                    );
     }
+    void writeDeclaration(OutputList &ol,bool localName=FALSE);
 };
 
 
