@@ -2,7 +2,7 @@
  *
  * $Id: outputgen.h,v 1.48 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -30,9 +30,12 @@ class ClassDiagram;
 class DotClassGraph;
 class DotInclDepGraph;
 class DotCallGraph;
+class DotDirDeps;
 class DotGfxHierarchyTable;
+class DotGroupCollaboration;
 class DocNode;
 class MemberDef;
+class GroupDef;
 
 /*! \brief Output interface for code parser. 
  */
@@ -307,16 +310,18 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endAnonTypeScope(int) = 0;
     virtual void startMemberItem(int) = 0;
     virtual void endMemberItem() = 0;
+    virtual void startMemberTemplateParams() = 0;
+    virtual void endMemberTemplateParams() = 0;
     virtual void startMemberGroupHeader(bool) = 0;
     virtual void endMemberGroupHeader() = 0;
     virtual void startMemberGroupDocs() = 0;
     virtual void endMemberGroupDocs() = 0;
     virtual void startMemberGroup() = 0;
     virtual void endMemberGroup(bool) = 0;
-    virtual void insertMemberAlign() = 0;
+    virtual void insertMemberAlign(bool) = 0;
     virtual void startMemberDoc(const char *,const char *,
                                 const char *,const char *) = 0;
-    virtual void endMemberDoc() = 0;
+    virtual void endMemberDoc(bool) = 0;
     virtual void startDoxyAnchor(const char *fName,const char *manName,
                                  const char *anchor,const char *name) = 0;
     virtual void endDoxyAnchor(const char *fileName,const char *anchor) = 0;
@@ -335,24 +340,28 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endDotGraph(DotClassGraph &g) = 0;
     virtual void startInclDepGraph() = 0;
     virtual void endInclDepGraph(DotInclDepGraph &g) = 0;
+    virtual void startGroupCollaboration() = 0;
+    virtual void endGroupCollaboration(DotGroupCollaboration &g) = 0;
     virtual void startCallGraph() = 0;
     virtual void endCallGraph(DotCallGraph &g) = 0;
+    virtual void startDirDepGraph() = 0;
+    virtual void endDirDepGraph(DotDirDeps &g) = 0;
     virtual void writeGraphicalHierarchy(DotGfxHierarchyTable &g) = 0;
     //virtual void startQuickIndexItem(const char *s,const char *l) = 0;
     //virtual void endQuickIndexItem() = 0;
     virtual void writeQuickLinks(bool compact,HighlightedItem hli) = 0;
     virtual void startTextBlock(bool) = 0;
-    virtual void endTextBlock() = 0;
+    virtual void endTextBlock(bool) = 0;
     virtual void lastIndexPage() = 0;
     virtual void startMemberDocPrefixItem() = 0;
     virtual void endMemberDocPrefixItem() = 0;
-    virtual void startMemberDocName() = 0;
+    virtual void startMemberDocName(bool) = 0;
     virtual void endMemberDocName() = 0;
-    virtual void startParameterType(bool) = 0;
+    virtual void startParameterType(bool,const char *) = 0;
     virtual void endParameterType() = 0;
     virtual void startParameterName(bool) = 0;
-    virtual void endParameterName(bool,bool) = 0;
-    virtual void startParameterList() = 0;
+    virtual void endParameterName(bool,bool,bool) = 0;
+    virtual void startParameterList(bool) = 0;
     virtual void endParameterList() = 0;
 
   protected:
