@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -232,7 +232,7 @@ void PerlModOutput::iaddQuoted(const char *s)
   }
 }
   
-inline void PerlModOutput::iaddField(const char *s)
+void PerlModOutput::iaddField(const char *s)
 {
   continueBlock();
   m_stream->add(s);
@@ -367,8 +367,8 @@ public:
   void visitPost(DocSecRefItem *);
   void visitPre(DocSecRefList *);
   void visitPost(DocSecRefList *);
-  void visitPre(DocLanguage *);
-  void visitPost(DocLanguage *);
+  //void visitPre(DocLanguage *);
+  //void visitPost(DocLanguage *);
   void visitPre(DocParamSect *);
   void visitPost(DocParamSect *);
   void visitPre(DocParamList *);
@@ -619,6 +619,7 @@ void PerlModDocVisitor::visit(DocVerbatim *s)
     return;
   case DocVerbatim::Verbatim:	type = "preformatted"; break;
   case DocVerbatim::HtmlOnly:	type = "htmlonly"; break;
+  case DocVerbatim::ManOnly:	type = "manonly"; break;
   case DocVerbatim::LatexOnly:	type = "latexonly"; break;
   case DocVerbatim::XmlOnly:	type = "xmlonly"; break;
   case DocVerbatim::Dot:	type = "dot"; break;
@@ -641,6 +642,18 @@ void PerlModDocVisitor::visit(DocInclude *inc)
   const char *type = 0;
   switch(inc->type())
   {
+  case DocInclude::IncWithLines:
+  #if 0
+      { 
+         m_t << "<div class=\"fragment\"><pre>";
+         QFileInfo cfi( inc->file() );
+         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
+         m_t << "</pre></div>"; 
+      }
+      break;
+  #endif
+    return;
   case DocInclude::Include:
 #if 0
     m_output.add("<programlisting>");
@@ -1113,16 +1126,16 @@ void PerlModDocVisitor::visitPost(DocSecRefList *)
 #endif
 }
 
-void PerlModDocVisitor::visitPre(DocLanguage *l)
-{
-  openItem("language");
-  m_output.addFieldQuotedString("id", l->id());
-}
-
-void PerlModDocVisitor::visitPost(DocLanguage *)
-{
-  closeItem();
-}
+//void PerlModDocVisitor::visitPre(DocLanguage *l)
+//{
+//  openItem("language");
+//  m_output.addFieldQuotedString("id", l->id());
+//}
+//
+//void PerlModDocVisitor::visitPost(DocLanguage *)
+//{
+//  closeItem();
+//}
 
 void PerlModDocVisitor::visitPre(DocParamSect *s)
 {
@@ -1887,11 +1900,11 @@ void PerlModGenerator::generatePerlModForGroup(GroupDef *gd)
     m_output.closeList();
   }
 
-  NamespaceList *nl = gd->getNamespaces();
+  NamespaceSDict *nl = gd->getNamespaces();
   if (nl)
   {
     m_output.openList("namespaces");
-    NamespaceListIterator nli(*nl);
+    NamespaceSDict::Iterator nli(*nl);
     NamespaceDef *nd;
     for (nli.toFirst();(nd=nli.current());++nli)
       m_output.openHash()
