@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -141,6 +141,7 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::Code: printf("<code>"); break;
         case DocVerbatim::Verbatim: printf("<verbatim>"); break;
         case DocVerbatim::HtmlOnly: printf("<htmlonly>"); break;
+        case DocVerbatim::ManOnly: printf("<manonly>"); break;
         case DocVerbatim::LatexOnly: printf("<latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("<xmlonly>"); break;
         case DocVerbatim::Dot: printf("<dot>"); break;
@@ -151,6 +152,7 @@ class PrintDocVisitor : public DocVisitor
         case DocVerbatim::Code: printf("</code>"); break;
         case DocVerbatim::Verbatim: printf("</verbatim>"); break;
         case DocVerbatim::HtmlOnly: printf("</htmlonly>"); break;
+        case DocVerbatim::ManOnly: printf("</manonly>"); break;
         case DocVerbatim::LatexOnly: printf("</latexonly>"); break;
         case DocVerbatim::XmlOnly: printf("</xmlonly>"); break;
         case DocVerbatim::Dot: printf("</dot>"); break;
@@ -168,6 +170,7 @@ class PrintDocVisitor : public DocVisitor
       switch(inc->type())
       {
         case DocInclude::Include: printf("include"); break;
+        case DocInclude::IncWithLines: printf("incwithlines"); break;
         case DocInclude::DontInclude: printf("dontinclude"); break;
         case DocInclude::HtmlInclude: printf("htmlinclude"); break;
         case DocInclude::VerbInclude: printf("verbinclude"); break;
@@ -531,16 +534,16 @@ class PrintDocVisitor : public DocVisitor
       indent_post();
       printf("</secreflist>\n");
     }
-    void visitPre(DocLanguage *l)
-    {
-      indent_pre();
-      printf("<language id=%s>\n",l->id().data());
-    }
-    void visitPost(DocLanguage *) 
-    {
-      indent_post();
-      printf("</language>\n");
-    }
+    //void visitPre(DocLanguage *l)
+    //{
+    //  indent_pre();
+    //  printf("<language id=%s>\n",l->id().data());
+    //}
+    //void visitPost(DocLanguage *) 
+    //{
+    //  indent_post();
+    //  printf("</language>\n");
+    //}
     void visitPre(DocParamList *pl)
     {
       indent_pre();
