@@ -2,7 +2,7 @@
  *
  * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2004 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -106,9 +106,11 @@ class RTFGenerator : public OutputGenerator
     void endAnonTypeScope(int) {}
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams() {}
+    void endMemberTemplateParams() {}
     //void memberGroupSpacing(bool) {}
     //void memberGroupSeparator() {}
-    void insertMemberAlign() {}
+    void insertMemberAlign(bool) {}
 
     void writeRuler() { rtfwriteRuler_thin(); }
 	
@@ -134,7 +136,7 @@ class RTFGenerator : public OutputGenerator
     void endDescItem();
     void lineBreak();
     void startMemberDoc(const char *,const char *,const char *,const char *);
-    void endMemberDoc();
+    void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *);
     void startCodeAnchor(const char *) {};
@@ -223,8 +225,12 @@ class RTFGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &);
     void startInclDepGraph();
     void endInclDepGraph(DotInclDepGraph &);
+    void startGroupCollaboration();
+    void endGroupCollaboration(DotGroupCollaboration &g);
     void startCallGraph();
     void endCallGraph(DotCallGraph &);
+    void startDirDepGraph();
+    void endDirDepGraph(DotDirDeps &g);
     void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
 
     void startMemberGroupHeader(bool);
@@ -235,7 +241,7 @@ class RTFGenerator : public OutputGenerator
     void endMemberGroup(bool);
     
     void startTextBlock(bool dense);
-    void endTextBlock();
+    void endTextBlock(bool);
     void lastIndexPage();
 
     void startMemberDocPrefixItem() {}
@@ -245,7 +251,7 @@ class RTFGenerator : public OutputGenerator
     void startParameterType(bool,const char *) {}
     void endParameterType() {}
     void startParameterName(bool) {}
-    void endParameterName(bool,bool) {}
+    void endParameterName(bool,bool,bool) {}
     void startParameterList(bool) {}
     void endParameterList() {}
 
@@ -282,14 +288,15 @@ class RTFGenerator : public OutputGenerator
     int  m_listLevel; // // RTF does not really have a addative indent...manually set list level.
     bool m_omitParagraph; // should a the next paragraph command be ignored?
     int  m_numCols; // number of columns in a table
+    QCString relPath;
 
     void beginRTFDocument();
     void beginRTFChapter();
     void beginRTFSection();
-    void rtfwriteRuler_doubleline() { t << "{\\pard\\widctlpar\\brdrb\\brdrdb\\brdrw15\\brsp20 \\adjustright \\par}" << endl; };
-    void rtfwriteRuler_emboss() { t << "{\\pard\\widctlpar\\brdrb\\brdremboss\\brdrw15\\brsp20 \\adjustright \\par}" << endl; };
-    void rtfwriteRuler_thick() { t << "{\\pard\\widctlpar\\brdrb\\brdrs\\brdrw75\\brsp20 \\adjustright \\par}" << endl; };
-    void rtfwriteRuler_thin() { t << "{\\pard\\widctlpar\\brdrb\\brdrs\\brdrw5\\brsp20 \\adjustright \\par}" << endl; };
+    void rtfwriteRuler_doubleline();
+    void rtfwriteRuler_emboss();
+    void rtfwriteRuler_thick();
+    void rtfwriteRuler_thin();
     void writeRTFReference(const char *label);
     char *getMultiByte(int c);
 };
