@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -11,11 +11,14 @@
  * input used in their production; they are not affected by this license.
  *
  * Brazilian Portuguese version by
- *   Fabio "FJTC" Jun Takada Chino <chino@icmc.usp.br>
- *      http://www.icmc.sc.usp.br/~chino
- *   Version: 1.3 (2003/05/01)
+ *   Fabio "FJTC" Jun Takada Chino <jun-chino at uol.com.br>
+ *   Version: 1.3.8 (2004/06/30)
  *
  * History:
+ * 	 1.3.9
+ *		- Updated to Doxygen 1.3.9
+ * 	 1.3.8
+ *		- Updated to Doxygen 1.3.8
  *   1.3.3:
  *      - Updated to Doxygen 1.3.3
  *   1.3.2:
@@ -31,7 +34,7 @@
 #ifndef TRANSLATOR_BR_H
 #define TRANSLATOR_BR_H
 
-class TranslatorBrazilian: public Translator
+class TranslatorBrazilian : public Translator
 {
   public:
 
@@ -634,6 +637,8 @@ class TranslatorBrazilian: public Translator
         case ClassDef::Struct:     result+=" Estrutura "; break;
         case ClassDef::Union:      result+=" Unio "; break;
         case ClassDef::Interface:  result+=" Interface "; break;
+        case ClassDef::Protocol:   result+=" Protocol "; break; // translate me!
+        case ClassDef::Category:   result+=" Category "; break; // translate me!
         case ClassDef::Exception:  result+=" Exceo "; break;
       }
       result+=(QCString)clName;
@@ -790,6 +795,8 @@ class TranslatorBrazilian: public Translator
         case ClassDef::Struct:     result+="estrutura "; break;
         case ClassDef::Union:      result+="unio "; break;
         case ClassDef::Interface:  result+="interface "; break;
+        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+        case ClassDef::Category:   result+="category "; break; // translate me!
         case ClassDef::Exception:  result+="exceo "; break;
       }
       result+=" foi gerada a partir ";
@@ -1531,5 +1538,64 @@ class TranslatorBrazilian: public Translator
     {
       return "Resultados:";
     }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return  "Cdigo-Fonte de " + filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Hierarquia de Diretrios"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Documentao do Directrio"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Diretrios"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Esta Hierarquia de Diretrios est parcialmente ordenada (ordem alfabtica)"; }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    {
+        QCString result = "Referncia do diretrio ";
+     	result += dirName;
+     	return result;
+    }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Diretrio" : "diretrio"));
+      if (!singular) result+="s";
+      return result; 
+    }
 };
 #endif
