@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,8 @@
 #ifndef TRANSLATOR_CZ_H
 #define TRANSLATOR_CZ_H
 
-
+// 
+//
 // The first translation from English to Czech was started by
 // Vlastimil Havran (1999--2000). The prototype version of Czech strings 
 // with diacritics was implemented by Petr Prikryl (prikrylp@skil.cz), 
@@ -125,7 +126,11 @@
 // 2002/10/15 - The new trEvents() and trEventDocumentation() implemented.
 // 2003/04/28 - Five new methods "since 1.3" implemented.
 // 2003/06/10 - Two new methods "since 1.3.1" implemented.
-// 2003/08/13 - Four new "since 1.3.3" implemented. 
+// 2003/08/13 - Four new methods "since 1.3.3" implemented. 
+// 2004/02/26 - trLegendDocs() updated.
+// 2004/02/27 - Text inside the trCallGraph() corrected.
+// 2004/06/16 - The new method "since 1.3.8" implemented. 
+// 2004/09/14 - The new methods "since 1.3.9" implemented. 
 
 // Todo
 // ----
@@ -763,6 +768,8 @@ class TranslatorCzech : public Translator
         case ClassDef::Struct:     result+="struktury "; break;
         case ClassDef::Union:      result+="unie "; break;
         case ClassDef::Interface:  result+="rozhran "; break;
+        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+        case ClassDef::Category:   result+="category "; break; // translate me!
         case ClassDef::Exception:  result+="vjimky "; break;
       }
       result+=clName;
@@ -933,6 +940,8 @@ class TranslatorCzech : public Translator
         case ClassDef::Struct:     result+="tuto strukturu (struct)"; break;
         case ClassDef::Union:      result+="tuto unii (union)"; break;
         case ClassDef::Interface:  result+="toto rozhran"; break;
+        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+        case ClassDef::Category:   result+="category "; break; // translate me!
         case ClassDef::Exception:  result+="tuto vjimku"; break;
       }
       result+=" byla generovna z ";
@@ -1180,8 +1189,6 @@ class TranslatorCzech : public Translator
         "/*! Tda, u kter dolo k oezn grafu. Vztah ddinosti "
         "je skryt. */\n"
         "class Truncated : public Invisible { };\n\n"
-        "/* Tda, kter nen dokumentovna komenti programu doxygen. */\n"
-        "class Undocumented { };\n\n"
         "/*! Bzov tda ddn veejn (public inheritance). */\n"
         "class PublicBase : public Truncated { };\n\n"
         "/*! Bzov tda, pouit pro chrnn ddn "
@@ -1190,6 +1197,10 @@ class TranslatorCzech : public Translator
         "/*! Bzov tda, vyuit pro privtn ddn "
         "(private inheritance). */\n"
         "class PrivateBase { };\n\n"
+        "/* Tda, kter nen dokumentovna komenti programu doxygen. */\n"
+        "class Undocumented { };\n\n"
+        "/*! ablona tdy. */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Tda, kter je vyuvna tdou Inherited. */\n"
         "class Used { };\n\n"
         "/*! Odvozen tda, kter rznm zpsobem dd z vce bzovch "
@@ -1197,7 +1208,8 @@ class TranslatorCzech : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -1219,7 +1231,7 @@ class TranslatorCzech : public Translator
             "strukturu nebo tdu, pro kterou\n"
             "nejsou zobrazeny vechny vztahy ddinosti nebo obsaen. "
             "Graf je oezn v ppad, kdy jej\n"
-            "nen mon umstit do vymezench hranic.\n"
+            "nen mon umstit do vymezenho prostoru.\n"
         "</ul>\n"
         "ipky (tj. hrany grafu) maj nsledujc vznam:\n"
         "<ul>\n"
@@ -1234,6 +1246,10 @@ class TranslatorCzech : public Translator
             "nebo kdy je pouvna jinou tdou. Je oznaena identifiktorem "
             "jedn nebo vce promnch, pes kter\n"
             "je tda nebo struktura zpstupnna.\n"
+        "<li>lut ipka kreslen rkovan vyjaduje vztah mezi instanc ablony " 
+            "a ablonou tdy, na zklad kter byla\n"
+            "instance ablony vytvoena. V popisu ipky jsou uvedeny  pslun"
+            " parametry ablony.\n"
         "</ul>\n");
         
         return decode(result);
@@ -1593,7 +1609,7 @@ class TranslatorCzech : public Translator
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
     {
-      return decode("Graf voln tto funkce:");
+      return decode("Graf voln pro tuto funkci:");
     }
    
 //////////////////////////////////////////////////////////////////////////
@@ -1646,6 +1662,71 @@ class TranslatorCzech : public Translator
     {
       return decode("Nalezen slova:");
     }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return decode("Zdrojov soubor ") + filename;
+    }
+    
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return decode("Hierarchie adres"); }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return decode("Dokumentace k adresm"); }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return decode("Adrese"); }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { 
+        return decode("Nsledujc hierarchie adres je zhruba, "
+                      "ale ne pln, azena podle abecedy:"); 
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { 
+        QCString result = "Reference k adresi "; 
+        result += dirName; 
+        return decode(result); 
+    }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+        QCString result((first_capital ? "Adres" : "adres"));
+        if ( ! singular) 
+            result += "e";
+        return decode(result); 
+    }
 };
 
 #endif // TRANSLATOR_CZ_H
