@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -79,7 +79,23 @@
 //
 //   2003/09/11 Jens Seidel (jensseidel@users.sourceforge.net)
 //    - Updated for "new since 1.3.1" version
-//   
+//  
+//   2003/09/24 Jens Seidel (jensseidel@users.sourceforge.net)
+//    - Updated a few strings which changed in CVS revision 1.22
+//      ("compound" vs. "class")
+//    
+//   2004/08/01 Jens Seidel (jensseidel@users.sourceforge.net)
+//    - Updated for "new since 1.3.8" version
+//    
+//   2004/09/19 Jens Seidel (jensseidel@users.sourceforge.net)
+//    - Updated for "new since 1.3.9" version
+//    
+//   2004/09/25 Jens Seidel (jensseidel@users.sourceforge.net)
+//    - changed "Typendefinitionen" to "Typdefinitionen" in
+//      trFileMembersDescription() and trTypedefs()
+//    - added a dash after (file, ...) names and in front of description
+//    - changed "Eigenschaften" to "Propertys" (yeah, not ..."ies")
+//    
 //   Todo:
 //    - see FIXME
 
@@ -152,7 +168,7 @@ class TranslatorGerman : public Translator
 
     /*! this is the text of a link put after brief descriptions. */
     virtual QCString trMore() 
-    { return "Mehr..."; }
+    { return "Mehr ..."; }
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
@@ -213,7 +229,7 @@ class TranslatorGerman : public Translator
       }
       else
       {
-        return "bersicht";
+        return "Auflistung der Klassen";
       }
     }
     
@@ -223,7 +239,7 @@ class TranslatorGerman : public Translator
 
     /*! This is put above each page as a link to the list of all verbatim headers */
     virtual QCString trHeaderFiles()
-    { return "Auflistung der Header-Dateien"; }
+    { return "Header-Dateien"; }
 
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
@@ -234,7 +250,7 @@ class TranslatorGerman : public Translator
       }
       else
       {
-        return "Datenstruktur-Elemente";
+        return "Klassen-Elemente";
       }
     }
 
@@ -334,7 +350,7 @@ class TranslatorGerman : public Translator
       if (!extractAll) result+="dokumentierten ";
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        result+="Funktionen, Variablen, Makros, Aufzhlungen und Typendefinitionen";
+        result+="Funktionen, Variablen, Makros, Aufzhlungen und Typdefinitionen";
       }
       else
       {
@@ -392,9 +408,11 @@ class TranslatorGerman : public Translator
      * annotated compound index.
      */
     virtual QCString trCompoundIndex()
-    /* No difference if "OPTIMIZE_OUTPUT_FOR_C" is set! */
     {
-	    return "Datenstruktur-Verzeichnis";
+      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+	return "Datenstruktur-Verzeichnis";
+      else
+        return "Klassen-Verzeichnis";
     }
 
     /*! This is used in LaTeX as the title of the chapter with the
@@ -462,7 +480,7 @@ class TranslatorGerman : public Translator
      *  list of typedefs
      */
     virtual QCString trTypedefs()
-    { return "Typendefinitionen"; }
+    { return "Typdefinitionen"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of enumerations
@@ -504,7 +522,7 @@ class TranslatorGerman : public Translator
      *  of documentation blocks for typedefs
      */
     virtual QCString trTypedefDocumentation()
-    { return "Dokumentation der benutzerdefinerten Typen"; }
+    { return "Dokumentation der benutzerdefinierten Typen"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for enumeration types
@@ -541,7 +559,7 @@ class TranslatorGerman : public Translator
       }
       else
       {
-        return "bersicht";
+        return "Klassen";
       }
     }
 
@@ -664,6 +682,8 @@ class TranslatorGerman : public Translator
         case ClassDef::Struct: result+="Struktur"; break;
         case ClassDef::Union:  result+="Varianten"; break;
         case ClassDef::Interface:  result+="Schnittstellen"; break;
+        case ClassDef::Protocol:  result+="Protocol"; break; // translate me!
+        case ClassDef::Category:  result+="Category"; break; // translate me!
         case ClassDef::Exception:  result+="Ausnahmen"; break;
       }
       result+="referenz";
@@ -674,7 +694,7 @@ class TranslatorGerman : public Translator
     virtual QCString trFileReference(const char *fileName)
     {
       QCString result=fileName;
-      result+=" Dateireferenz";
+      result+="-Dateireferenz";
       return result;
     }
 
@@ -682,7 +702,7 @@ class TranslatorGerman : public Translator
     virtual QCString trNamespaceReference(const char *namespaceName)
     {
       QCString result=namespaceName;
-      result+=" Namensbereichsreferenz";
+      result+="-Namensbereichsreferenz";
       return result;
     }
     
@@ -830,6 +850,8 @@ class TranslatorGerman : public Translator
         case ClassDef::Struct:     result+=" Struktur"; break;
         case ClassDef::Union:      result+=" Variante"; break;
         case ClassDef::Interface:  result+=" Schnittstelle"; break;
+        case ClassDef::Protocol:   result+=" Protocol"; break; // translate me!
+        case ClassDef::Category:   result+=" Category"; break; // translate me!
         case ClassDef::Exception:  result+=" Ausnahme"; break;
       }
       result+=" wurde erzeugt aufgrund der Datei";
@@ -1201,13 +1223,13 @@ class TranslatorGerman : public Translator
     /*! Used as a section header for IDL properties */
     virtual QCString trProperties()
     {
-      return "Eigenschaften";
+      return "Propertys";
     }
 
     /*! Used as a section header for IDL property documentation */
     virtual QCString trPropertyDocumentation()
     {
-      return "Dokumentation der Eigenschaften";
+      return "Dokumentation der Propertys";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1594,6 +1616,64 @@ class TranslatorGerman : public Translator
     {
       return "Treffer:";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return filename + " Quellcode";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Verzeichnishierarchie"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Verzeichnisdokumentation"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Verzeichnisse"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Diese Verzeichnishierarchie ist -mit Einschrnkungen- "
+	     "alphabetisch sortiert:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=dirName; result+="-Verzeichnisreferenz"; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool, bool singular)
+    { 
+      QCString result("Verzeichnis");
+      if (!singular) result+="se";
+      return result; 
+    }
+
 };
 
 #endif
