@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,15 +21,29 @@
   *
   * Extended, revised and updated by
   * kos Kiss  <akiss@users.sourceforge.net>
+  *
+  * Further extended, revised and updated by
+  * Tamsi Ferenc <tf551@hszk.bme.hu>
   */
 
 #ifndef TRANSLATOR_HU_H
 #define TRANSLATOR_HU_H
 
-#include "translator.h"
-
 class TranslatorHungarian : public Translator
 {
+  private:
+    const char * zed(char c)
+    {
+        switch (c & ~('a' ^ 'A')) {
+            case 'B': case 'C': case 'D': case 'F': case 'G':
+            case 'H': case 'J': case 'K': case 'L': case 'M':
+            case 'N': case 'P': case 'Q': case 'R': case 'S':
+            case 'T': case 'V': case 'W': case 'X': case 'Z':
+                return "  ";
+            default:
+                return "z ";
+        }
+    }
   public:
 
     // --- Language control methods -------------------
@@ -110,12 +124,9 @@ class TranslatorHungarian : public Translator
     QCString trIncludingInheritedMembers()
     { return " osztly tagjainak teljes listja, az rklt tagokkal egytt."; }
     
-    /*! this is put at the author sections at the bottom of man pages.
-     *  parameter s is name of the project name.
-     */
     QCString trGeneratedAutomatically(const char *s)
     { QCString result="Ezt a dokumentcit a Doxygen ksztette ";
-      if (s) result+=(QCString)" a(z) "+s+(QCString)" projekthez";
+      if (s) result+=(QCString)" a" + zed(s[0])+s+(QCString)" projekthez";
       result+=" a forrskdbl."; 
       return result;
     }
@@ -512,7 +523,7 @@ class TranslatorHungarian : public Translator
     /*! this text is put before a class diagram */
     QCString trClassDiagram(const char *clName)
     {
-      return (QCString)"A(z) "+clName+" osztly szrmazsi diagramja:";
+      return (QCString)"A"+zed(clName[0])+clName+" osztly szrmazsi diagramja:";
     }
     
     /*! this text is generated when the \\internal command is used. */
@@ -835,12 +846,12 @@ class TranslatorHungarian : public Translator
     /*! this text is put before a collaboration diagram */
     QCString trCollaborationDiagram(const char *clName)
     {
-      return (QCString)"A(z) "+clName+" osztly egyttmkdsi diagramja:";
+      return (QCString)"A"+zed(clName[0])+clName+" osztly egyttmkdsi diagramja:";
     }
     /*! this text is put before an include dependency graph */
     QCString trInclDepGraph(const char *fName)
     {
-      return (QCString)"A(z) "+fName+" defincis fjl fggsi grfja:";
+      return (QCString)"A"+zed(fName[0])+fName+" defincis fjl fggsi grfja:";
     }
     /*! header that is put before the list of constructor/destructors. */
     QCString trConstructorDocumentation()
@@ -1504,6 +1515,63 @@ class TranslatorHungarian : public Translator
       return "Tallatok:";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return filename + " Forrsfjl";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Knyvtrhierarchia"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Knyvtrak dokumentcija"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Knyvtrak"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Majdnem (de nem teljesen) betrendbe szedett "
+             "knyvtrhierarchia:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=dirName; result+=" knyvtrreferencia"; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool /*singular*/)
+    { 
+      QCString result((first_capital ? "Knyvtr" : "knyvtr"));
+      //if (singular) result+="y"; else result+="ies";
+      return result; 
+    }
+
 };
 
 #endif
