@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,6 +19,8 @@
  *
  * Revision history
  *
+ *  2004/09: translated new items used since version 1.3.9
+ *  2004/06: translated new items used since version 1.3.8
  *  2003/11: translated new items used since version 1.3.3
  *  2003/06: translated new items used since version 1.3.1
  *  2003/04: translated new items used since version 1.3
@@ -644,6 +646,8 @@ class TranslatorItalian : public Translator
         case ClassDef::Struct: result+="la struct "; break;
         case ClassDef::Union:  result+="la union "; break;
         case ClassDef::Interface:  result+="l'interfaccia "; break;
+        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+        case ClassDef::Category:   result+="category "; break; // translate me!
         case ClassDef::Exception:  result+="exception "; break;
       }
       result+=(QCString)clName;
@@ -803,6 +807,8 @@ class TranslatorItalian : public Translator
         case ClassDef::Struct:     result+="struct"; break;
         case ClassDef::Union:      result+="union"; break;
         case ClassDef::Interface:  result+="interfaccia"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="exception"; break;
       }
       result+="  stata generata a partire ";
@@ -1500,6 +1506,62 @@ class TranslatorItalian : public Translator
       return "Corrispondenze:";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return " File sorgente " + filename ;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Gerarchia delle directory"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Documentazione delle directory"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Directory"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Questa gerarchia di directory  ordinata "
+        "approssimativamente, ma non completamente, in ordine alfabetico:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result="Riferimenti per la directory "; result+=dirName; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool)
+    {
+      QCString result((first_capital ? "Directory" : "directory"));
+      return result;
+    }
+
 };
 
 #endif
