@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,8 +18,64 @@
 #ifndef TRANSLATOR_KR_H
 #define TRANSLATOR_KR_H
 
-class TranslatorKorean : public TranslatorAdapter_1_3
+/*! 
+ When defining a translator class for the new language, follow
+ the description in the documentation.  One of the steps says
+ that you should copy the translator_en.h (this) file to your
+ translator_xx.h new file.  Your new language should use the
+ Translator class as the base class.  This means that you need to
+ implement exactly the same (pure virtual) methods as the
+ TranslatorEnglish does.  Because of this, it is a good idea to
+ start with the copy of TranslatorEnglish and replace the strings
+ one by one.
+
+ It is not necessary to include "translator.h" or
+ "translator_adapter.h" here.  The files are included in the
+ language.cpp correctly.  Not including any of the mentioned
+ files frees the maintainer from thinking about whether the
+ first, the second, or both files should be included or not, and
+ why.  This holds namely for localized translators because their
+ base class is changed occasionaly to adapter classes when the
+ Translator class changes the interface, or back to the
+ Translator class (by the local maintainer) when the localized
+ translator is made up-to-date again.
+*/
+
+/*
+  ʱ ۾:  ryk
+                TODO ּ  11/22/01, doxygen  1.2.11  ֽ  ϴ.
+  ֱ : Astromaker(http://ngps.net/)
+               gpgiki(http://www.gpgstudy.com/gpgiki/)
+ */
+ 
+//
+//	Update:
+//
+// 2004.12.22 (SooYoung Jung: jung5000@gmail.com)
+//	- LaTex and RTF were not generated correctly.
+// 	  Corrected trRTFansicp and trRTFCharSet.
+// 	  It was wrong.
+// 	- Adapting 1.3.9 and added "new since 1.3.9"
+//	- ؼ ߸ κ ҳ ־ .. 
+//
+ 
+
+class TranslatorKorean : public TranslatorAdapter_1_3_9
 {
+ private:
+  /*! The decode() can change euc into sjis */
+  inline QCString decode(const QCString & sInput)
+  {
+    if (Config_getBool("USE_WINDOWS_ENCODING"))
+    {
+      return JapaneseEucToSjis(sInput);
+    }
+    else
+    {
+      return sInput;
+    }
+  }
+  	
   public:
 
     // --- Language control methods -------------------
@@ -51,7 +107,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     {
         // I'm not sure what this should be.
         // When I figure it out, I'll update this.
-        return "";
+		//see http://www.ktug.or.kr/jsboard/read.php?table=operate&no=4422&page=1
+		return "\\usepackage{hfont}\n";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -77,26 +134,25 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return " Ÿ ȭ"; }
-    
+
     /*! header that is put before the list of enumerations. */
     virtual QCString trMemberEnumerationDocumentation()
     { return "  ȭ"; }
-    
+
     /*! header that is put before the list of member functions. */
     virtual QCString trMemberFunctionDocumentation()
     { return " Լ ȭ"; }
-    
+
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
-    {
+    { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-          // TODO: This need to be translated. -ryk11/22/01.
-          return "  ȭ"; 
+          return "  ȭ";
       }
       else
       {
-          return "  ȭ"; 
+          return "  ȭ";
       }
     }
 
@@ -119,7 +175,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! this is the remainder of the sentence after the class name */
     virtual QCString trIncludingInheritedMembers()
     { return ", ӹ   "; }
-    
+
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
@@ -133,11 +189,11 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! put after an enum name in the list of all members */
     virtual QCString trEnumName()
     { return " ̸"; }
-    
+
     /*! put after an enum value in the list of all members */
     virtual QCString trEnumValue()
     { return " "; }
-    
+
     /*! put after an undocumented member in the list of all members */
     virtual QCString trDefinedIn()
     { return " "; }
@@ -149,11 +205,11 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      */
     virtual QCString trModules()
     { return ""; }
-    
+
     /*! This is put above each page as a link to the class hierarchy */
     virtual QCString trClassHierarchy()
     { return "Ŭ 뵵"; } // "Ŭ " or "Ŭ зü"
-    
+
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
@@ -164,10 +220,9 @@ class TranslatorKorean : public TranslatorAdapter_1_3
         }
         else
         {
-            //TODO: This needs to be translated. -ryk11/22/01.
             return "ձ(Ŭ, ü, ü)";
         }
-    } 
+    }
     
     /*! This is put above each page as a link to the list of documented files */
     virtual QCString trFileList()
@@ -182,7 +237,6 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
-            // TODO: This need to be translated. -ryk11/22/01.
             return "ձ(Ŭ, ü, ü) ";
         }
         else
@@ -197,7 +251,6 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
-            // TODO: This needs to be translated. -ryk11/22/01.
             return " ";
         }
         else
@@ -236,7 +289,6 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
-            // TODO: This needs to be translated. -ryk11/22/01.
             return "    Ŭ, "
                 "ü, ü, ̽ Դϴ.";
         }
@@ -257,17 +309,17 @@ class TranslatorKorean : public TranslatorAdapter_1_3
       }
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-          // TODO: This need to be translated. -ryk11/22/01.
           result+="ũ  Ŭ  ";
       }
       else
       {
           result+="ũ  Ŭ  ";
       }
-      if (extractAll) 
+
+      if (extractAll)
           result+="   Ŭ ȭ ϴ.";
-      else 
-          result+="Ϸ  Ŭ:";            
+      else
+          result+="Ϸ  Ŭ:";
       return result;
     }
 
@@ -277,9 +329,9 @@ class TranslatorKorean : public TranslatorAdapter_1_3
       QCString result=" ȭ  Ͽ  Դϴ. ";
       if (!extractAll) result+="ȭ ";
       result+="ũ    ";
-      if (extractAll) 
+      if (extractAll)
         result+="    ȭ ϴ.";
-      else 
+      else
         result+="׵ ִ Ϸ ϴ.";
       return result;
     }
@@ -301,12 +353,12 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     { return "   Դϴ."; }
 
     /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
+     * description is given.
      */
     virtual QCString trNoDescriptionAvailable()
     { return "  ϴ."; }
-    
-    // index titles (the project name is prepended for these) 
+
+    // index titles (the project name is prepended for these)
 
 
     /*! This is used in HTML as the title of index.html. */
@@ -334,7 +386,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! This is used in LaTeX as the title of the chapter with the
      * list of all files.
      */
-    virtual QCString trFileIndex() 
+    virtual QCString trFileIndex()
     { return " "; }
 
     /*! This is used in LaTeX as the title of the chapter containing
@@ -370,8 +422,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return ""; }
-    
-    /*! This is used in the documentation of a file as a header before the 
+
+    /*! This is used in the documentation of a file as a header before the
      *  list of defines
      */
     virtual QCString trDefines()
@@ -412,7 +464,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      */
     virtual QCString trEnumerationValues()
     { return " "; }
-    
+
     /*! This is used in the documentation of a file before the list of
      *  documentation blocks for defines
      */
@@ -459,13 +511,22 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  the list of links to documented compounds
      */
     virtual QCString trCompounds()
-    { return "ձ"; }
+    { 
+      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      {
+        return "Data Structures"; 
+      }
+      else
+      {
+        return "Classes"; 
+      }
+    }
 
     /*! This is used in the standard footer of each page and indicates when 
      *  the page was generated 
      */
     virtual QCString trGeneratedAt(const char *date,const char *projName)
-    { 
+    {
       QCString result="";
       if (projName) result+=(QCString)projName+" ȭ. ";
       result += "Ͻ : " +(QCString)date+" by";
@@ -523,7 +584,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! this text is generated when the \\exception command is used. */
     virtual QCString trExceptions()
     { return ""; }
-    
+
     /*! this text is used in the title page of a LaTeX document. */
     virtual QCString trGeneratedBy()
     { return "  "; }
@@ -549,7 +610,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  friends of a class
      */
     virtual QCString trFriends()
-    { return "friend"; }
+    { return "Friends"; }
     
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990405
@@ -560,7 +621,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      */
     virtual QCString trRelatedFunctionDocumentation()
     { return "friend, ׸ õ Լ ȭ"; }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990425
 //////////////////////////////////////////////////////////////////////////
@@ -578,8 +639,11 @@ class TranslatorKorean : public TranslatorAdapter_1_3
         case ClassDef::Struct:     result+=" ü"; break;
         case ClassDef::Union:      result+=" ü"; break;
         case ClassDef::Interface:  result+=" ̽"; break;
+        case ClassDef::Protocol:   result+=" protocol"; break; // translate me!
+        case ClassDef::Category:   result+=" category"; break; // translate me!
         case ClassDef::Exception:  result+=" "; break;
       }
+      if (isTemplate) result+=" ø";
       result+=" ";
       return result;
     }
@@ -588,7 +652,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     virtual QCString trFileReference(const char *fileName)
     {
       QCString result=fileName;
-      result+="  "; 
+      result+="  ";
       return result;
     }
 
@@ -599,7 +663,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
       result+=" namespace ";
       return result;
     }
-    
+
     virtual QCString trPublicMembers()
     { return "public ޼ҵ"; }
     virtual QCString trPublicSlots()
@@ -620,7 +684,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     { return "private slots"; }
     virtual QCString trStaticPrivateMembers()
     { return "static private ޼ҵ"; }
-    
+
     /*! this function is used to produce a comma-separated list of items.
      *  use generateMarker(i) to indicate where item i should be put.
      */
@@ -688,9 +752,9 @@ class TranslatorKorean : public TranslatorAdapter_1_3
       QCString result="  ";
       if (!extractAll) result+="ȭ ";
       result+="namespace  Դϴ. ";
-      if (extractAll) 
+      if (extractAll)
         result+="   ȭ ";
-      else 
+      else
         result+="ִ namespace ";
       result+="ũ ֽϴ.";
       return result;
@@ -715,7 +779,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  namespaces in a file.
      */
     virtual QCString trNamespaces()
-    { return "namespace"; }
+    { return "Namespaces"; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990728
@@ -735,6 +799,8 @@ class TranslatorKorean : public TranslatorAdapter_1_3
         case ClassDef::Struct:     result+="ü"; break;
         case ClassDef::Union:      result+="ü"; break;
         case ClassDef::Interface:  result+="̽"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+=""; break;
       }
       result+="  ȭ  ";
@@ -811,7 +877,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
     {
-      return " & Ҹ ȭ"; 
+      return " & Ҹ ȭ";
     }
     /*! Used in the file documentation to point to the corresponding sources. */
     virtual QCString trGotoSourceCode()
@@ -841,7 +907,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! Text shown before a multi-line variable/enum initialization */
     virtual QCString trInitialValue()
     {
-      return "ʱȭ";
+      return "ʱⰪ";
     }
     /*! Text used the source code in the file index */
     virtual QCString trCode()
@@ -871,50 +937,50 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     
     virtual QCString trNote()
     {
-        return "Ʈ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "Ʈ";
     }
     virtual QCString trPublicTypes()
     {
-        return "public Ÿ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "public Ÿ";
     }
     virtual QCString trPublicAttribs()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-          return "Data ʵ"; // TODO: Need to be translated. -ryk11/22/01.
+          return "Data ʵ";
       }
       else
       {
-          return "public Ӽ"; // TODO: Need to be translated. -ryk11/22/01.
+          return "public Ӽ";
       }
     }
     virtual QCString trStaticPublicAttribs()
     {
-        return "static public Ӽ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "static public Ӽ";
     }
     virtual QCString trProtectedTypes()
     {
-        return "protected Ÿ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "protected Ÿ";
     }
     virtual QCString trProtectedAttribs()
     {
-        return "protected Ӽ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "protected Ӽ";
     }
     virtual QCString trStaticProtectedAttribs()
     {
-        return "static protected Ӽ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "static protected Ӽ";
     }
     virtual QCString trPrivateTypes()
     {
-        return "private Ÿ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "private Ÿ";
     }
     virtual QCString trPrivateAttribs()
     {
-        return "private Ӽ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "private Ӽ";
     }
     virtual QCString trStaticPrivateAttribs()
     {
-        return "static private Ӽ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "static private Ӽ";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -924,12 +990,12 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! Used as a marker that is put before a \\todo item */
     virtual QCString trTodo()
     {
-        return "Todo"; // TODO: Need to be translated. -ryk11/22/01.
+        return "Todo";
     }
     /*! Used as the header of the todo list */
     virtual QCString trTodoList()
     {
-        return "Todo "; // TODO: Need to be translated. -ryk11/22/01.
+        return "Todo ";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -938,15 +1004,15 @@ class TranslatorKorean : public TranslatorAdapter_1_3
 
     virtual QCString trReferencedBy()
     {
-        return "ϴ "; // TODO: Need to be translated. -ryk11/22/01.
+        return "ϴ ";
     }
     virtual QCString trRemarks()
     {
-        return ""; // TODO: Need to be translated. -ryk11/22/01.
+        return "";
     }
     virtual QCString trAttention()
     {
-        return ""; // TODO: Need to be translated. -ryk11/22/01.
+        return "";
     }
     virtual QCString trInclByDepGraph()
     {
@@ -966,7 +1032,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! title of the graph legend page */
     virtual QCString trLegendTitle()
     {
-        return "׷ "; // TODO: Need to be translated. -ryk11/22/01.
+        return "";
     }
     /*! page explaining how the dot graph's should be interpreted 
      *  The %A in the text below are to prevent link to classes called "A".
@@ -1013,7 +1079,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
         //"is set to 240 this will result in the following graph:"
         "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
         "<p>\n"
-		"ڽ  Ѵ.\n"
+		"ڵ  Ѵ.\n"
         //"The boxes in the above graph have the following meaning:\n"
         "<ul>\n"
 		"<li>% ڴ ׷  ü Ŭ Ѵ.\n"
@@ -1045,7 +1111,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
         //"by another class. The arrow is labeled with the variable(s) "
         //"through which the pointed class or struct is accessible.\n"
 		"<li>%  ȭǥ ø νϽ ø Ŭ Ÿ. "
-		" ȭǥ   νϽ ø Ű Ÿ.\n" 
+		" ȭǥ   νϽ ø Ű Ÿ.\n"
         //"<li>%A yellow dashed arrow denotes a relation between a template instance and "
         //"the template class it was instantiated from. The arrow is labeled with "
         //"the template parameters of the instance.\n"
@@ -1054,7 +1120,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! text for the link to the legend page */
     virtual QCString trLegend()
     {
-        return ""; // TODO: Need to be translated. -ryk11/22/01.
+        return "";
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1064,12 +1130,12 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! Used as a marker that is put before a test item */
     virtual QCString trTest()
     {
-        return "׽Ʈ"; // TODO: Need to be translated. -ryk11/22/01.
+        return "׽Ʈ";
     }
     /*! Used as the header of the test list */
     virtual QCString trTestList()
     {
-        return "׽Ʈ "; // TODO: Need to be translated. -ryk11/22/01.
+        return "׽Ʈ ";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1196,7 +1262,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      */
     virtual QCString trRTFansicp()
     {
-        return "1252";
+      return "949";
     }
     
 
@@ -1205,7 +1271,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      */
     virtual QCString trRTFCharSet()
     {
-      return "0";
+      return "129";
     }
 
     /*! Used as header RTF general index */
@@ -1219,7 +1285,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  of the category.
      */
     virtual QCString trClass(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "Ŭ" : "Ŭ"));
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1230,7 +1296,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  of the category.
      */
     virtual QCString trFile(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "" : ""));
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1252,7 +1318,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  of the category.
      */
     virtual QCString trGroup(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "׷" : "׷"));
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1263,7 +1329,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  of the category.
      */
     virtual QCString trPage(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "" : ""));
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1274,7 +1340,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  of the category.
      */
     virtual QCString trMember(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "" : ""));
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1285,7 +1351,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      *  of the category.
      */
     virtual QCString trField(bool first_capital, bool singular)
-    { 
+    {
       QCString result((first_capital ? "ʵ" : "ʵ"));
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1309,7 +1375,7 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! This text is generated when the \\author command is used and
      *  for the author section in man pages. */
     virtual QCString trAuthor(bool first_capital, bool singular)
-    {                                                                         
+    {
       QCString result((first_capital ? "ۼ" : "ۼ"));
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1396,36 +1462,36 @@ class TranslatorKorean : public TranslatorAdapter_1_3
     /*! Used as a heading for a list of Java class types with package scope.
      */
     virtual QCString trPackageTypes()
-    { 
-      return "Ű Ÿ";
+    {
+        return "Ű ŸԵ"; //"Package Types";
     }
     /*! Used as a heading for a list of Java class functions with package 
      * scope. 
      */
     virtual QCString trPackageMembers()
-    { 
-      return "Ű Լ";
+    {
+        return "Ű Լ"; //"Package Functions";
     }
     /*! Used as a heading for a list of static Java class functions with 
      *  package scope.
      */
     virtual QCString trStaticPackageMembers()
-    { 
-      return " Ű Լ";
+    {
+        return " Ű Լ"; //"Static Package Functions";
     }
     /*! Used as a heading for a list of Java class variables with package 
      * scope.
      */
     virtual QCString trPackageAttribs()
-    { 
-      return "Ű Ӽ";
+    {
+        return "Ű Ӽ"; //"Package Attributes";
     }
     /*! Used as a heading for a list of static Java class variables with 
      * package scope.
      */
     virtual QCString trStaticPackageAttribs()
-    { 
-      return " Ű Ӽ";
+    {
+        return " Ű Ӽ"; //"Static Package Attributes";
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1437,12 +1503,128 @@ class TranslatorKorean : public TranslatorAdapter_1_3
      */
     virtual QCString trAll()
     {
-      return "All";
+        return "";
     }
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
     {
-      return " Լ ȣ¸ Ÿ ׷Դϴ.";
+        return "  Լ  ȣ ׷Դϴ:";
+        //"Here is the call graph for this function:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+        return "˻: "; //"Search for";
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+        return "˻ ";//"Search Results";
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+        if (numDocuments==0)
+        {
+            //return "Sorry, no documents matching your query.";
+            return "˼մϴ. ǿ ġϴ  ϴ.";
+        }
+        else if (numDocuments==1)
+        {
+            //return "Found <b>1</b> document matching your query.";
+            return "ǿ ġϴ <b>1</b>  ãҽϴ.";
+        }
+        else
+        {
+            //return "Found <b>$num</b> documents matching your query. "
+            //    "Showing best matches first.";
+            return "ǿ ġϴ <b>$num</b>  ãҽϴ. "
+                "ó    ġϴ Դϴ.";
+        }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return ":";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return filename + " ҽ ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "丮 "; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "丮 "; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "丮"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return " 丮  ĺ  ĵǾֽϴ. ( )";
+             
+             
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=dirName; result+=" 丮 "; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool /*first_capital*/, bool /*singular*/)
+    { 
+      // QCString result((first_capital ? "Director" : "director"));
+      // if (singular) result+="y"; else result+="ies";
+      
+      // return result; 
+      return "";
     }
 
 };
