@@ -2,7 +2,7 @@
  *
  * $Id: translator_ro.h,v 1.3 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -659,6 +659,8 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
         case ClassDef::Struct:     result+="structura"; break;
         case ClassDef::Union:      result+="uniunea"; break;
         case ClassDef::Interface:  result+="interfaa"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="excepia"; break;
       }
 	  if (isTemplate) result+=" (Template) ";
@@ -819,6 +821,8 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
         case ClassDef::Struct:     result+="structur"; break;
         case ClassDef::Union:      result+="uniune"; break;
         case ClassDef::Interface:  result+="interfa"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="excepie"; break;
       }
       result+=" a fost generat din fiier";
