@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,9 +18,10 @@
 #ifndef TRANSLATOR_SR_H
 #define TRANSLATOR_SR_H
 
-// translation by Dejan D. M. Milosavljevic <dmilos@email.com>;<dmilosx@ptt.yu>  
+// translation by Dejan D. M. Milosavljevic <dmilos@email.com>;<dmilosx@ptt.yu>;<office@ddmrm.com>
+// // 10x 2 Ivana Miletic for gramatical consutation.
 
-class TranslatorSerbian : public TranslatorAdapter_1_3_3
+class TranslatorSerbian : public Translator
 {                                
 private:
    QCString decode(const QCString& sInput)
@@ -79,15 +80,15 @@ private:
 
     /*! used in the compound documentation before a list of related functions. */
     virtual QCString trRelatedFunctions()
-    { return "Povezane funkcije"; }  
+    { return decode( "Povezane funkcije" ); }  
 
     /*! subscript for the related functions. */
     virtual QCString trRelatedSubscript()
-    { return decode( "(To nisu funkcije lanice.)" ); } // tj. metode
+    { return decode( "(To nisu funkcije lanice.)" ); } 
 
     /*! header that is put before the detailed description of files, classes and namespaces. */
     virtual QCString trDetailedDescription()
-    { return decode( "Detaljno objanjenje" ); }
+    { return decode( "Opirnije objanjenje" ); } // detalj je francuska rec.
 
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
@@ -139,22 +140,22 @@ private:
      */
     virtual QCString trGeneratedAutomatically(const char *s)
     { QCString result="Napravljeno automatski Doxygen-om";
-      if (s) result+=(QCString)" za "+s;
+      if( s ) result+=(QCString)" za " + s;
       result+=" od izvornog koda."; 
-      return result;
+      return decode( result );
     }
 
     /*! put after an enum name in the list of all members */
     virtual QCString trEnumName()
-    { return "ime enum-a "; }
+    { return decode( "ime enum-a " ); }
     
     /*! put after an enum value in the list of all members */
     virtual QCString trEnumValue()
-    { return "vrednost enum-a"; }
+    { return decode( "vrednost enum-a" ); }
     
     /*! put after an undocumented member in the list of all members */
     virtual QCString trDefinedIn()
-    { return "definisano u"; }
+    { return decode( "definisano u" ); }
 
     // quick reference sections
 
@@ -162,32 +163,32 @@ private:
      *  compounds or files (see the \\group command).
      */
     virtual QCString trModules()
-    { return "Moduli"; }
+    { return decode( "Moduli" ); }
     
     /*! This is put above each page as a link to the class hierarchy */
     virtual QCString trClassHierarchy()
-    { return "Stablo klasa"; }
+    { return decode( "Stablo klasa" ); }
     
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Sve strukture";
+        return decode( "Sve strukture" );
       }
       else
       {
-        return "Sve klase"; 
+        return decode( "Sve klase" ); 
       }
     }
     
     /*! This is put above each page as a link to the list of documented files */
     virtual QCString trFileList()
-    { return "Spisak datoteka"; }
+    { return decode( "Spisak datoteka" ); }
 
     /*! This is put above each page as a link to the list of all verbatim headers */
     virtual QCString trHeaderFiles()
-    { return "Zaglavlja"; }
+    { return decode( "Zaglavlja" ); }
 
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
@@ -207,11 +208,11 @@ private:
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-       return decode("lanovi datoteke"); 
+       return decode( "lanovi datoteke" ); 
       }
       else
       {
-       return decode("lanovi datoteke"); 
+       return decode( "lanovi datoteke" ); 
       }
     }
 
@@ -306,7 +307,7 @@ private:
       
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        result+="funkcija, promenjiva, makro zamena, enum-a, i typedef-va";
+        result+="funkcija, promenjiva, makro zamena, enum-ova, i typedef-ova";
       }
       else
       {
@@ -319,6 +320,7 @@ private:
         result+="datoteke u kojima se nalaze:";
       else 
         result+=" dokumentaciju:";
+
       return decode( result );
     }
 
@@ -328,7 +330,7 @@ private:
 
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
-    { return "Spisak primera:"; }
+    { return decode( "Spisak primera:" ); }
 
     /*! This is an introduction to the page with the list of related pages */
     virtual QCString trRelatedPagesDescription()
@@ -336,26 +338,26 @@ private:
 
     /*! This is an introduction to the page with the list of class/file groups */
     virtual QCString trModulesDescription()
-    { return "Spisak svih modula:"; }
+    { return decode( "Spisak svih modula:" ); }
 
     /*! This sentences is used in the annotated class/file lists if no brief
      * description is given. 
      */
     virtual QCString trNoDescriptionAvailable()
-    { return "Opis nije dostupan"; }
+    { return decode( "Opis nije dostupan" ); }
     
     // index titles (the project name is prepended for these) 
 
 
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
-    { return "Dokumentacija"; }
+    { return decode("Dokumentacija" ); }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * index of all groups.
      */
     virtual QCString trModuleIndex()
-    { return "Index modula"; }
+    { return decode( "Index modula" ); }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * class hierarchy.
@@ -382,13 +384,13 @@ private:
      * list of all files.
      */
     virtual QCString trFileIndex() 
-    { return "Indeks datoteka"; }
+    { return decode( "Indeks datoteka" ); }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all groups.
      */
     virtual QCString trModuleDocumentation()
-    { return "Dokumentacija modula"; }
+    { return decode( "Dokumentacija modula" ); }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all classes, structs and unions.
@@ -491,7 +493,7 @@ private:
      *  of documentation blocks for enumeration types
      */
     virtual QCString trEnumerationTypeDocumentation()
-    { return "Dokumetacija enum tipa"; }
+    { return "Dokumetacija enum-a"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for enumeration values
@@ -531,10 +533,10 @@ private:
      */
     virtual QCString trGeneratedAt(const char *date,const char *projName)
     { 
-      QCString result=(QCString)"Napravljeno "+date;
-      if (projName) result+=(QCString)" za "+projName;
+      QCString result=(QCString)"Napravljeno " + date;
+      if ( projName ) result+=(QCString)" za " + projName;
       result+=(QCString)" od";
-      return result;
+      return decode( result );
     }
     /*! This is part of the sentence used in the standard footer of each page.
      */
@@ -546,7 +548,7 @@ private:
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
     {
-      return decode( QCString("Dijagram nasleivanja za klasu ") + clName+":" );
+      return decode( QCString("Dijagram nasleivanja za klasu ") + clName + ":" );
     }
     
     /*! this text is generated when the \\internal command is used. */
@@ -563,11 +565,11 @@ private:
 
     /*! this text is generated when the \\bug command is used. */
     virtual QCString trBugsAndLimitations()
-    { return decode("Greke i ogranienja"); }
+    { return decode( "Greke i ogranienja" ); }
 
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
-    { return "Verzija"; }
+    { return "Verzija"; }    // inacica
 
     /*! this text is generated when the \\date command is used. */
     virtual QCString trDate()
@@ -607,7 +609,7 @@ private:
       QCString result="Spisak svih ";
       if (!extractAll) result+="dokumentovanih ";
       result+="prostora imena sa kratkim opisom:";
-      return result;
+      return decode( result );
     }
 
     /*! used in the class documentation as a header before the list of all
@@ -624,7 +626,7 @@ private:
      * related classes 
      */
     virtual QCString trRelatedFunctionDocumentation()
-    { return "Dokumentacija prijateljskih funkcija ili klasa"; }
+    { return decode( "Dokumentacija prijateljskih funkcija ili klasa" ); }
     
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990425
@@ -643,6 +645,8 @@ private:
         case ClassDef::Struct:     result+="strukture "; break;
         case ClassDef::Union:      result+="unije "; break;
         case ClassDef::Interface:  result+="interfejsa "; break;
+        case ClassDef::Protocol:   result+="protokola "; break; // grcka rec
+        case ClassDef::Category:   result+="kategorije "; break; // 
         case ClassDef::Exception:  result+="izuzetka "; break;
       }
       if (isTemplate) result += "ablona ";  
@@ -656,7 +660,7 @@ private:
     {
       QCString result = "Opis datoteke ";
       result += fileName; 
-      return result;
+      return decode( result );
     }
 
     /*! used as the title of the HTML page of a namespace */
@@ -801,6 +805,8 @@ private:
         case ClassDef::Struct:     result+="ove strukture"; break;
         case ClassDef::Union:      result+="ove unije"; break;
         case ClassDef::Interface:  result+="ovog interfejsa"; break;
+        case ClassDef::Protocol:   result+="ovog protokola"; break;
+        case ClassDef::Category:   result+="ove kategorije"; break;
         case ClassDef::Exception:  result+="ovog izuzetka"; break;
       }
       result+=" je napravljena iz ";
@@ -971,7 +977,7 @@ private:
     }
     virtual QCString trPrivateTypes()
     {
-      return "Privatni tipovi";
+      return decode( "Privatni tipovi" );
     }
     virtual QCString trPrivateAttribs()
     {
@@ -1011,7 +1017,7 @@ private:
     }
     virtual QCString trAttention()
     {
-      return decode("Panja");;
+      return decode( "Panja" );
     }
     virtual QCString trInclByDepGraph()
     {
@@ -1078,7 +1084,7 @@ private:
         "<ul>\n"
          "<li>Puni crni predstavlja strukturu ili klasu za koju je graf napravljen.\n"
          "<li>Sa crnom ivicom predstavlja dokumentovanu strukturu ili klasu.\n"
-         "<li>Sa sivom icivom predstavlja nedokumentovanu strukturu ili klasu.\n"
+         "<li>Sa sivom ivicom predstavlja nedokumentovanu strukturu ili klasu.\n"
          "<li>Sa crvenom ivicom predstavlja dokumentovanu strukturu ili klasu\n"
          "za koju nije prikazan graf nasleivanja/korienja. Graf je odseen "
          "ako ne stane unutar odreenih granica." 
@@ -1135,12 +1141,12 @@ private:
     /*! Used as a section header for IDL properties */
     virtual QCString trProperties()
     {
-      return "Osobine";
+      return decode( "Osobine" );
     }
     /*! Used as a section header for IDL property documentation */
     virtual QCString trPropertyDocumentation()
     {
-      return "Dokumentacija osobina";
+      return decode( "Dokumentacija osobina" );
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1150,7 +1156,7 @@ private:
     /*! Used for Java interfaces in the summary section of Java packages */
     virtual QCString trInterfaces()
     {
-      return "Interfejsi";
+      return "Interfejsi";  // Radna okruzenja. Ali to je dve reci.
     }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
@@ -1202,12 +1208,12 @@ private:
     /*! Used as a marker that is put before a \\bug item */
     virtual QCString trBug()
     {
-      return decode("Greka");;
+      return decode( "Greka" );
     }
     /*! Used as the header of the bug list */
     virtual QCString trBugList()
     {
-      return decode("Spisak greaka");;
+      return decode( "Spisak greaka" );
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1256,7 +1262,7 @@ private:
     /*! Used as header RTF general index */
     virtual QCString trRTFGeneralIndex()
     {
-      return decode("Sadraj");;
+      return decode( "Sadraj" );
     }
    
     /*! This is used for translation of the word that will possibly
@@ -1265,7 +1271,7 @@ private:
      */
     virtual QCString trClass(bool first_capital, bool singular)
     { 
-      QCString result((first_capital ? "Klas" : "klas"));
+      QCString result( (first_capital ? "Klas" : "klas") );
       result+= (singular ? "a" : "e");
       return result; 
     }
@@ -1358,7 +1364,7 @@ private:
     {                                                                         
       QCString result((first_capital ? "Autor" : "autor"));
       result+= (singular ? "" : "i");
-      return result; 
+      return decode( result ); 
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1369,7 +1375,7 @@ private:
      */
     virtual QCString trReferences()
     {
-      return "Koristi";
+      return decode( "Koristi" );
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1389,7 +1395,7 @@ private:
      */
     virtual QCString trImplementedInList(int numEntries)
     {
-      return "Definisano u " + trWriteList(numEntries) + "." ;
+      return decode( "Definisano u " + trWriteList(numEntries) + "." );
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1424,12 +1430,12 @@ private:
      */
     virtual QCString trEvents()
     {
-      return "Dogaaji";
+      return decode( "Dogaaji" );
     }
     /*! Header used for the documentation section of a class' events. */
     virtual QCString trEventDocumentation()
     {
-      return "Dokumentacija dogaaja";
+      return decode( "Dokumentacija dogaaja" );
     }
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3
@@ -1439,35 +1445,35 @@ private:
      */
     virtual QCString trPackageTypes()
     { 
-      return "Tipovi u Paketu";
+      return decode( "Tipovi u Paketu" );
     }
     /*! Used as a heading for a list of Java class functions with package 
      * scope. 
      */
     virtual QCString trPackageMembers()
     { 
-      return "Funkcije u paketu";
+      return decode( "Funkcije u paketu" );
     }
     /*! Used as a heading for a list of static Java class functions with 
      *  package scope.
      */
     virtual QCString trStaticPackageMembers()
     { 
-      return "Statike funkcije u paketu";  // Zajednicke funkcije u paketu
+      return decode( "Statike funkcije u paketu" );  // Zajednicke funkcije u paketu
     }
     /*! Used as a heading for a list of Java class variables with package 
      * scope.
      */
     virtual QCString trPackageAttribs()
     { 
-      return "Atributi u paketu"; // Clanovi u paketu
+      return decode( "Atributi u paketu" ); // Clanovi u paketu
     }
     /*! Used as a heading for a list of static Java class variables with 
      * package scope.
      */
     virtual QCString trStaticPackageAttribs()
     { 
-      return "Statiki atributi u paketu";  // Zajednicki clanovi u paketu
+      return decode( "Statiki atributi u paketu" );  // Zajednicki clanovi u paketu
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1479,21 +1485,133 @@ private:
      */
     virtual QCString trAll()
     {
-      return "Sve";
+      return decode( "Sve" );
     }
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
     {
-      return "Graf pozivanja finkcija:";
+      return decode( "Graf pozivanja funkcija:" );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return decode("Trai");
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return decode( "Rezultati pretraivanja" );
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return decode("Nema dokumenta koji odgovaraju vaem upitu");
+      }
+      else if (numDocuments==1)
+      { // 10x 2 Ivana Miletic 4 gramatical consutation.
+        return decode("Naen je <b>1</b> dokument koji odgovara vaem upitu.");
+      }
+    else if (numDocuments<5) 
+    {  // 10x 2 Ivana Miletic 4 gramatical consutation.
+      return decode("Naena su <b>$num</b> dokumenta koji odgovaraju vaem upitu."
+                    "Najbolji su prikazani prvi.");
+    }
+    else 
+    {  // 10x 2 Ivana Miletic 4 gramatical consutation.
+      return decode("Naeno je <b>$num</b> dokumenata koji odgovaraju vaem upitu."
+        "Najbolji su prikazani prvi.");
+    }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return decode( "Pronaeno:" );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return decode( "Izvorni kod datoteke " + filename ) ;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return decode( "Stablo direktorijuma" ); }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return decode( "Dokumentacija direktorijuma" ); }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return decode( "direktorijumi" ); }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return decode( "Stablo direktorijuma slozeno priblizno abecednim redom" );
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=dirName; result+="Opis direktorijuma"; return decode( result ); }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Direktorijum" : "direktorijum"));
+      if (!singular) result+="i"; 
+      return decode( result ); 
     }
 
  
 };
 
-// sh -  - shashavo
-// dj -  - djordje
-// ch -  - chasha
-// cc -  - cciccifu
-// zz -  - zzaba
+// sh -     - shashavo  (,)
+// dj -     - djordje
+// ch - ,  - chasha
+// cc -     - cciccifu
+// zz -     - zzaba     
 
 #endif
