@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,6 +26,7 @@
 #include <qlist.h>
 #include <qtextstream.h>
 #include <ctype.h>
+#include "sortdict.h"
 
 class ClassDef;
 class FileDef;
@@ -43,19 +44,20 @@ class GroupDef;
 class NamespaceSDict;
 class ClassList;
 class MemberGroupSDict;
-class Definition;
 struct TagInfo;
 class MemberNameInfoSDict;
 struct ListItemInfo;
 class PageDef;
 struct SectionInfo;
+class QDir;
+class Definition;
 
 //--------------------------------------------------------------------
 
 class TextGeneratorIntf
 {
   public:
-    virtual void writeString(const char *) const = 0;
+    virtual void writeString(const char *,bool) const = 0;
     virtual void writeBreak() const = 0;
     virtual void writeLink(const char *extRef,const char *file,
                       const char *anchor,const char *text
@@ -66,7 +68,7 @@ class TextGeneratorOLImpl : public TextGeneratorIntf
 {
   public:
     TextGeneratorOLImpl(OutputDocInterface &od);
-    void writeString(const char *s) const;
+    void writeString(const char *s,bool keepSpaces) const;
     void writeBreak() const;
     void writeLink(const char *extRef,const char *file,
                    const char *anchor,const char *text
@@ -83,7 +85,8 @@ void linkifyText(const TextGeneratorIntf &ol,
                  const char *name,
                  const char *text,
                  bool autoBreak=FALSE,
-                 bool external=TRUE
+                 bool external=TRUE,
+                 bool keepSpaces=FALSE
                 );
 void setAnchors(ClassDef *cd,char id,MemberList *ml,int groupId=-1);
 QCString fileToString(const char *name,bool filter=FALSE);
@@ -101,6 +104,7 @@ bool getDefs(const QCString &scopeName,
                     bool checkCV=FALSE
                    );
 
+QCString getFileFilter(const char* name);
 
 bool resolveRef(/* in */  const char *scName,
                 /* in */  const char *name,
@@ -128,7 +132,11 @@ void writePageRef(OutputDocInterface &od,const char *cn,const char *mn);
 bool matchArguments(ArgumentList *,ArgumentList *,
                            const char *cl=0,const char *ns=0,bool checkCV=TRUE,
                            NamespaceSDict *usingNamespaces=0,
-                           ClassSDict *usingClasses=0);
+                           SDict<Definition> *usingClasses=0);
+bool matchArguments2(Definition *srcScope,FileDef *srcFileScope,ArgumentList *srcAl,
+                     Definition *dstScope,FileDef *dstFileScope,ArgumentList *dstAl,
+                     bool checkCV
+                    );
 void mergeArguments(ArgumentList *,ArgumentList *,bool forceNameOverwrite=FALSE);
 QCString substituteClassNames(const QCString &s);
 QCString substitute(const char *s,const char *src,const char *dst);
@@ -138,7 +146,8 @@ ClassDef *getResolvedClass(Definition *scope,
                            FileDef *fileScope,
                            const char *key,
                            MemberDef **pTypeDef=0,
-                           QCString *pTemplSpec=0);
+                           QCString *pTemplSpec=0,
+                           bool mayBeUnlinkable=FALSE);
 NamespaceDef *getResolvedNamespace(const char *key);
 FileDef *findFileDef(const FileNameDict *fnDict,const char *n,
                 bool &ambig);
@@ -152,9 +161,10 @@ QCString generateMarker(int id);
 void writeExample(OutputList &ol,ExampleSDict *el);
 QCString stripAnonymousNamespaceScope(const QCString &s);
 QCString stripFromPath(const QCString &path);
+QCString stripFromIncludePath(const QCString &path);
 bool rightScopeMatch(const QCString &scope, const QCString &name);
 bool leftScopeMatch(const QCString &scope, const QCString &name);
-QCString substituteKeywords(const QCString &s,const char *title);
+QCString substituteKeywords(const QCString &s,const char *title,const QCString &relPath="");
 int getPrefixIndex(const QCString &name);
 QCString removeAnonymousScopes(const QCString &s);
 QCString replaceAnonymousScopes(const QCString &s);
@@ -184,7 +194,8 @@ QCString substituteTemplateArgumentsInString(
 ArgumentList *copyArgumentList(const ArgumentList *src);
 QList<ArgumentList> *copyArgumentLists(const QList<ArgumentList> *srcLists);
 QCString stripTemplateSpecifiersFromScope(const QCString &fullName,
-                                          bool parentOnly=TRUE);
+                                          bool parentOnly=TRUE,
+                                          QCString *lastScopeStripped=0);
 QCString resolveTypeDef(Definition *d,const QCString &name,
                         Definition **typedefContext=0);
 QCString mergeScopes(const QCString &leftScope,const QCString &rightScope);
@@ -209,8 +220,14 @@ QCString linkToText(const char *link,bool isFileName);
 QCString stripExtension(const char *fName);
 void replaceNamespaceAliases(QCString &scope,int i);
 int isAccessibleFrom(Definition *scope,FileDef *fileScope,Definition *item);
-int isAccessibleFrom(Definition *scope,FileDef *fileScope,Definition *item,
+int isAccessibleFromWithExpScope(Definition *scope,FileDef *fileScope,Definition *item,
                      const QCString &explicitScopePart);
+int computeQualifiedIndex(const QString &name);
+void addDirPrefix(QCString &fileName);
+QCString relativePathToRoot(const char *name);
+#define REL_PATH_TO_ROOT "../../"
+void createSubDirs(QDir &d);
+QCString stripPath(const char *s);
 
 #endif
 
