@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2005 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,6 +26,7 @@
 #include "dot.h"
 #include "message.h"
 #include "util.h"
+#include <qfileinfo.h> 
 
 XmlDocVisitor::XmlDocVisitor(QTextStream &t,BaseCodeDocInterface &ci) 
   : DocVisitor(DocVisitor_XML), m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE) 
@@ -124,25 +125,25 @@ void XmlDocVisitor::visit(DocStyleChange *s)
   switch (s->style())
   {
     case DocStyleChange::Bold:
-      if (s->enable()) m_t << "<bold>";      else m_t << "</bold> ";
+      if (s->enable()) m_t << "<bold>";      else m_t << "</bold>";
       break;
     case DocStyleChange::Italic:
-      if (s->enable()) m_t << "<emphasis>";     else m_t << "</emphasis> ";
+      if (s->enable()) m_t << "<emphasis>";     else m_t << "</emphasis>";
       break;
     case DocStyleChange::Code:
-      if (s->enable()) m_t << "<computeroutput>";   else m_t << "</computeroutput> ";
+      if (s->enable()) m_t << "<computeroutput>";   else m_t << "</computeroutput>";
       break;
     case DocStyleChange::Subscript:
-      if (s->enable()) m_t << "<subscript>";    else m_t << "</subscript> ";
+      if (s->enable()) m_t << "<subscript>";    else m_t << "</subscript>";
       break;
     case DocStyleChange::Superscript:
-      if (s->enable()) m_t << "<superscript>";    else m_t << "</superscript> ";
+      if (s->enable()) m_t << "<superscript>";    else m_t << "</superscript>";
       break;
     case DocStyleChange::Center:
-      if (s->enable()) m_t << "<center>"; else m_t << "</center> ";
+      if (s->enable()) m_t << "<center>"; else m_t << "</center>";
       break;
     case DocStyleChange::Small:
-      if (s->enable()) m_t << "<small>";  else m_t << "</small> ";
+      if (s->enable()) m_t << "<small>";  else m_t << "</small>";
       break;
     case DocStyleChange::Preformatted:
       if (s->enable()) 
@@ -152,7 +153,7 @@ void XmlDocVisitor::visit(DocStyleChange *s)
       }
       else 
       {
-        m_t << "</preformatted> ";
+        m_t << "</preformatted>";
         m_insidePre=FALSE;
       }
       break;
@@ -181,6 +182,11 @@ void XmlDocVisitor::visit(DocVerbatim *s)
       filter(s->text());
       m_t << "</htmlonly>";
       break;
+    case DocVerbatim::ManOnly: 
+      m_t << "<manonly>";
+      filter(s->text());
+      m_t << "</manonly>";
+      break;
     case DocVerbatim::LatexOnly: 
       m_t << "<latexonly>";
       filter(s->text());
@@ -208,6 +214,15 @@ void XmlDocVisitor::visit(DocInclude *inc)
   if (m_hide) return;
   switch(inc->type())
   {
+    case DocInclude::IncWithLines:
+      { 
+         m_t << "<programlisting>";
+         QFileInfo cfi( inc->file() );
+         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
+         m_t << "</programlisting>"; 
+      }
+      break;    
     case DocInclude::Include: 
       m_t << "<programlisting>";
       parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile());
@@ -430,7 +445,9 @@ void XmlDocVisitor::visitPost(DocSimpleListItem *)
 void XmlDocVisitor::visitPre(DocSection *s)
 {
   if (m_hide) return;
-  m_t << "<sect" << s->level() << " id=\"" << s->id() << "\">" << endl;
+  m_t << "<sect" << s->level() << " id=\"" << s->file();
+  if (!s->anchor().isEmpty()) m_t << "_1" << s->anchor();
+  m_t << "\">" << endl;
   m_t << "<title>";
   filter(s->title());
   m_t << "</title>" << endl;
@@ -694,17 +711,17 @@ void XmlDocVisitor::visitPost(DocSecRefList *)
   m_t << "</toclist>" << endl;
 }
 
-void XmlDocVisitor::visitPre(DocLanguage *l)
-{
-  if (m_hide) return;
-  m_t << "<language langid=\"" << l->id() << "\">";
-}
-
-void XmlDocVisitor::visitPost(DocLanguage *) 
-{
-  if (m_hide) return;
-  m_t << "</language>" << endl;
-}
+//void XmlDocVisitor::visitPre(DocLanguage *l)
+//{
+//  if (m_hide) return;
+//  m_t << "<language langid=\"" << l->id() << "\">";
+//}
+//
+//void XmlDocVisitor::visitPost(DocLanguage *) 
+//{
+//  if (m_hide) return;
+//  m_t << "</language>" << endl;
+//}
 
 void XmlDocVisitor::visitPre(DocParamSect *s)
 {
@@ -733,21 +750,43 @@ void XmlDocVisitor::visitPost(DocParamSect *)
 void XmlDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
+  m_t << "<parameteritem>" << endl;
+  m_t << "<parameternamelist>" << endl;
   QStrListIterator li(pl->parameters());
   const char *s;
   for (li.toFirst();(s=li.current());++li)
   {
-    m_t << "<parametername>";
+    m_t << "<parametername";
+    if (pl->direction()!=DocParamSect::Unspecified)
+    {
+      m_t << " direction=\"";
+      if (pl->direction()==DocParamSect::In)
+      {
+        m_t << "in";
+      }
+      else if (pl->direction()==DocParamSect::Out)
+      {
+        m_t << "out";
+      }
+      else if (pl->direction()==DocParamSect::InOut)
+      {
+        m_t << "inout";
+      }
+      m_t << "\"";
+    }
+    m_t << ">";
     filter(s);
     m_t << "</parametername>" << endl;
   }
+  m_t << "</parameternamelist>" << endl;
   m_t << "<parameterdescription>" << endl;
 }
 
 void XmlDocVisitor::visitPost(DocParamList *)
 {
   if (m_hide) return;
-  m_t << "</parameterdescription>";
+  m_t << "</parameterdescription>" << endl;
+  m_t << "</parameteritem>" << endl;
 }
 
 void XmlDocVisitor::visitPre(DocXRefItem *x)
